********************************************************************************
* DESCRIPTION: Prepares the random sample of SIPA administrative data from Argentina.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

*********************************************************************************************************
* Note:
* Variables (7): ID (employee = cuil_trab), gender, DOB (date of birth), lastyear, annual income, year, education
********************************************************************************************************

set more off
clear

// capture gtools, upgrade

********************************************************************************************************
*Macros and Paths
********************************************************************************************************
foreach dir in ///
	"/Users/adrenik/Dropbox/Research/GID_Argentina" ///
	"/Users/cm3594/Dropbox (CBS)/GID_Argentina" ///
	"/Users/cmoser/Dropbox (CBS)/GID_Argentina" ///
	"/data0/Dropbox/Research/GID_Argentina" ///
	{
	cap confirm file "`dir'"
	if !_rc global maindir ="`dir'"
}
global dir_input "${maindir}/Part_B/RandomSample/input"
global dir_random_sample    "${maindir}/Analysis_randomsample_final/"
global dir_log   "${maindir}/Analysis_randomsample_final/log"
global dir_output "${maindir}/Analysis_randomsample_final/dta"

cap n mkdir "${dir_random_sample}"
cap n mkdir "${dir_log}"
cap n mkdir "${dir_output}"

capture log close
log using "${dir_log}/Data_Prep.txt", replace text

*First and last year
global first_year = 1996
global last_year  = 2015

********************************************************************************************************
*If you want to use a random subsample (this is just to test the code)
********************************************************************************************************

global R = "N" /*Y=Yes N=No*/
if "$R" == "Y" global name = "Subsample"

********************************************************************************************************
* Convert Random Sample to one file per year with annual income data
********************************************************************************************************

**************************************
*Load original dataset
**************************************

use "${dir_input}/Muestra Longitudinal Empleo Registrado_13.dta", clear

**************************************
* Generate Unique identifying
* number for employee-job match.
**************************************

set seed 92

if "$R" == "Y"{ /*keep only a few observations to test the code using a subsample*/

    gen random = runiform()
    keep if random < 0.01
    drop random
}

gen double rel_lab = ide_trabajador*1000 + relacion
format rel_lab %20.0g
label var rel_lab "Worker-Job Match ID"

**************************************
*Homogeneize variable names
**************************************

*This is needed in order to run reshape
*The idea is to get rid of "_"
forvalues y = 96/99{

    rename tr_04`y' tr19`y'12

}

forvalues y = 0/9{

    rename tr_040`y' tr200`y'12
}

forvalues y = 10/15{

    rename tr_04`y' tr20`y'12

}

rename tr_anio_ini firm_start_date

**************************************
* Reshape the Data to long format
**************************************

greshape long rt tr, i(rel_lab) j(period) string verbose fast

**************************************
*Delete missing income observations
**************************************

drop if rt == .
compress

**************************************
*Fill in annual tr data
**************************************

*period is a string variable such as 199611 for year 1996 month 11

*Gen year
gen year = substr(period,1,4)
destring year, replace

*Gen month
gen month = substr(period,5,.)
destring month, replace

*Gen date
gen date = ym(year, month)
format date %tm

**************************************
*Rename and generate variables
**************************************

rename rt remuner_total
rename ide_trabajador id

* Gender
gen male     = 1 if sexo == 2
replace male = 0 if sexo == 1
drop sexo
drop if male == .

* Year of Birth/Death Variable
drop if fnac_anu == . /* indicated in the GID's instructions */
rename fnac_anu yob

gen yod = . /* Individuals with missing will be treated as they where still alive by the end of the sample */

**************************************
*Annual Income from monthly data
**************************************

keep id male yob yod remuner_total year

egen wage_inc = sum(remuner_total), by(id year)
drop remuner_total
bysort id year: keep if _n == 1

save "$dir_output/data_long.dta", replace

**************************************
*Var Labels
**************************************

label var id "Worker id"
label var yob "Year of birth"
label var yod "Year of death"
label var wage_inc "Total Annual Earnings"

**************************************
*Random education variable
**************************************

*Education variable: We randomize values btwn 1 and 4 (4 education levels)

bysort id: keep if _n == 1
gen educ = mod(_n-1,4) + 1 // Note: This randomly generates education level (1-4), meaning that all results related to education must be discarded!
keep id educ

save "$dir_output/random_educ.dta", replace

**************************************
*Save dataset
**************************************
use "$dir_output/data_long.dta", clear
merge m:1 id using "$dir_output/random_educ.dta", nogen keep(matched master)

save "$dir_output/data_long.dta", replace

erase "$dir_output/random_educ.dta"

// END OF THE CODE Data_Prep_RandomSample.do
