********************************************************************************
* DESCRIPTION: Validates cross-sectional (CS) and longitudinal (L) administrative data against houshold survey data.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************


*************************************************
******** DATA VALIDATION ************************
*************************************************

*** cross-sectional data validation
if $CS_datav == 1 {

	* load data
	use "${DTA_DIR}/eph_cleaned.dta", clear

	*** Identify panel information
		gen year = year(dofq(period))
		gen quarter = quarter(dofq(period))

		** keep only relevant years
		keep if inrange(year, ${year_min}, ${year_max})

		** Reorder and rename id to be chronological
		tostring workerid, gen(aux_id)
		gen length_id = length(aux_id) // maximum length = 6
		gen str1 aux_1 = "0"
		gen str2 aux_2 = "00"
		gen str3 aux_3 = "000"
		gen str4 aux_4 = "0000"
		gen str5 aux_5 = "00000"
		egen temp_id1 = concat(aux_5 aux_id) if length_id == 1
		egen temp_id2 = concat(aux_4 aux_id) if length_id == 2
		egen temp_id3 = concat(aux_3 aux_id) if length_id == 3
		egen temp_id4 = concat(aux_2 aux_id) if length_id == 4
		egen temp_id5 = concat(aux_1 aux_id) if length_id == 5
		replace aux_id = temp_id1 if length_id == 1
		replace aux_id = temp_id2 if length_id == 2
		replace aux_id = temp_id3 if length_id == 3
		replace aux_id = temp_id4 if length_id == 4
		replace aux_id = temp_id5 if length_id == 5
		drop temp*
		drop aux_1 aux_2 aux_3 aux_4 aux_5
		bys workerid: egen first_year = min(year)
		bys workerid: egen first_quarter = min(quarter)
		tostring first_year, replace
		tostring first_quarter, replace
		egen first_obs = concat(first_year first_quarter)
		egen new_id_temp = concat(first_obs aux_id)
		destring new_id_temp, replace
		egen new_id = group(new_id_temp)
		drop new_id_temp first_obs first_year first_quarter
		drop length_id aux_id
		rename new_id id

		** Create important variables: number of observations by id, by id-year, etc
		order id workerid
		sort id year quarter
		by id: gen nobs = _N // number of observations by id
		by id: gen index_id = _n
		egen id_year = group(id year)
		bys id_year: gen nobs_year = _N /// number of obs in each id-year level; maximum of 2 obs

		** Create season group variable: indicator in id-year level of observation structure
		create_season_group

	*** Methods to calculate the CS stats:
		** CS FIRST METHOD
		/// Consider any quarter in a year
		/// Consider as different ids if different quarter in a year
		/// Annualize only with the info of one quarter
		if $first_method == 1 {

		*** A. Number of obs in each quarter
			bys year quarter: gen obs_1 = _N
			label var obs_1 "number of total quarter obs"

		*** Drop if not formal in the individual-year obs
			replace labor_income = . if formal != 1 // Turn earnings to missing if not formal
			replace formal = 0 if labor_income == . // If earnings are missing, individuals are not formal employed in that obs
			drop if formal == 0 | public == 1
			keep if type_job == 3

		*** B. Observations after first restricton (employed privately in the formal sector)
			bys year quarter: gen obs_2 = _N
			label var obs_2 "obs restricting to formal sector"

		*** Create indicator for id, year, quarter level
			egen id_year_quarter = group(id year quarter)
			drop season_group

		*** Transform earnings in real terms
			merge m:1 year quarter using "${DTA_DIR}/arg_cpi_quarterly.dta", keep(master match) keepusing(cpi_q) nogen
			sum cpi_q if year == ${year_min}
			local cpi_${year_min} = r(mean)
			replace cpi_q = cpi_q/`cpi_${year_min}'
			rename cpi_q cpi
			gen labor_income_r = labor_income/cpi
			label var labor_income_r "Labor income (real ${year_min} ARS)"
			drop cpi

		*** Threshold
			** Merge dta with quarterly minimum wage value
			merge m:1 quarter year using "${DTA_DIR}/arg_min_wage_quarterly.dta", keep(master match) nogen
			rename min_wage_q mw

			** Find annual wage in terms of mw
			gen labor_income_mw = labor_income/mw
			bys id_year_quarter: gen annual_mw = labor_income_mw*12

			if $lower_thresh == 0 {
				drop if labor_income_mw < ${min_wage_mult}
			}
			else if $lower_thresh == 1 {
				merge m:1 quarter year using "${DTA_DIR}/arg_thresh_quarterly.dta", keep(master match) nogen
				drop date date_q
				drop if labor_income_r/thresh_q < ${thresh_mult}
				drop thresh_q
			}

			** C. Observations restricting to bottom threshold
			bys year quarter: gen obs_3 = _N
			label var obs_3 "obs restricting to bottom threshold"
			gen method = 1
			gen analysis_type = 1
			label var analysis_type "1 = data validation, 2 = complete analysis"
			obs_analysis

		*** Collapse information to individual & year & quarter level
			gen annual_earnings = labor_income_r*12
			label var annual_earnings "Annualized earnings (real ${year_min} ARS)"

			if $gtools gcollapse (mean) id age gender annual_earnings quarter weight year, by(id_year_quarter)
			else collapse (mean) id age gender annual_earnings quarter weight year, by(id_year_quarter)

			drop id
			rename id_year_quarter id

		*** Find residuals earnings, regressions run separated by gender & year
			gen ln_annual_earnings = log(annual_earnings)
			replace age = round(age)
			gen researn = .

				qui foreach yr of numlist $year_min(1)$year_max {
					reg ln_annual_earnings i.quarter i.age if gender == 1 & year == `yr' [aw=weight]
					predict temp_m if e(sample)== 1, residuals
					reg ln_annual_earnings i.quarter i.age if gender == 0 & year == `yr' [aw=weight]
					predict temp_f if e(sample)== 1, residuals
					replace researn = temp_m if year == `yr' & gender == 1
					replace researn = temp_f if year == `yr' & gender == 0
					drop temp*
				}
			*

		*** Find stats for earnings
			gen sec = 1
			gen data = 1
			label var data "1 = all analysis, 2 = by sector analysis"
			rename ln_annual_earnings logearn_datav_m1
			rename researn researn_datav_m1
			mystats "logearn_datav_m1"
			mystats "researn_datav_m1"

		*** Density figures
			if $kdensity_figs == 1 {
			kdensity_fig_2 "researn_datav_m1" ${year_min} "{&epsilon}{sub:it}" ${year_max}
			kdensity_fig_2 "logearn_datav_m1" ${year_min} "log y{sub:it}" ${year_max}
			}

		}

		** CS SECOND METHOD
		/// Consider any quarter or pair of quarters
		/// Regressions with indicator of quarters: example, (q1, x) , (x, q2), (q1, q2)
		if $second_method == 1 {

		*** A. Number of obs in each season group
			bys year season_group: gen obs_1 = _N
			label var obs_1 "number of total season_group obs"

		*** Drop if not formal in the individual-year obs
			replace labor_income = . if formal!= 1 // Turn earnings to missing if not formal
			replace labor_income = . if public == 1
			replace labor_income = . if type_job != 3
			replace formal = 0 if labor_income == . // If earnings are missing, individuals are not formal employed in that obs
			bys id_year: egen mean_earnings = mean(labor_income) // Average earnings in the quarters working in formal sector
			bys id_year: egen mean_formal = mean(formal)
			drop if mean_formal == 0

			** B. Observations after first restricton (employed privately in the formal sector in id-year level)
			bys year season_group: gen obs_2 = _N
			label var obs_2 "obs restricting to formal sector"

			bys id_year: gen nobs_formal = sum(formal)
			bys id_year: egen formal_quarters = max(nobs_formal) // Variable that identifies how many quarters (out of 2) individual worked at formal sector
			drop nobs_formal

		*** Threshold
			** Merge dta with quarterly minimum wage value
			merge m:1 quarter year using "${DTA_DIR}/arg_min_wage_quarterly.dta", keep(master match) nogen
			rename min_wage_q mw
			gen labor_income_mw = labor_income/mw
			gen annual_mw = .

			*** Transform earnings in real terms
			merge m:1 year quarter using "${DTA_DIR}/arg_cpi_quarterly.dta", keep(master match) keepusing(cpi_q) nogen
			sum cpi_q if year == ${year_min}
			local cpi_${year_min} = r(mean)
			replace cpi_q = cpi_q/`cpi_${year_min}'
			rename cpi_q cpi
			gen labor_income_r = labor_income/cpi
			label var labor_income_r "Labor income (real ${year_min} ARS)"
			drop cpi
			bys id_year: egen mean_earnings_r = mean(labor_income_r)

			** Find annual wage in terms of mw
			bys id_year: gen annual_mw_1 = sum(labor_income_mw) if nobs_year == 2
			replace annual_mw_1 = annual_mw_1*6 if nobs_year == 2
			bys id_year: egen annual_mw_aux = max(annual_mw_1) if nobs_year == 2
			replace annual_mw_1 = annual_mw_aux
			drop annual_mw_aux
			bys id_year: gen annual_mw_2 = labor_income_mw*12 if nobs_year == 1
			replace annual_mw = annual_mw_1 if nobs_year == 2
			replace annual_mw = annual_mw_2 if nobs_year == 1
			drop annual_mw_1 annual_mw_2

			bys id_year: egen mean_income_mw = mean(labor_income_mw)
			if $lower_thresh == 0 {
				drop if mean_income_mw < ${min_wage_mult}
			}
			if $lower_thresh == 1 {
				merge m:1 quarter year using "${DTA_DIR}/arg_thresh_quarterly.dta", keep(master match) nogen
				drop date date_q
				gen labor_income_mw_thres = labor_income_r/thresh_q
				drop thresh_q
				bys id_year: egen mean_income_mw_thres = mean(labor_income_mw_thres)
				drop labor_income_mw_thres
				drop if mean_income_mw_thres < ${thresh_mult}
				drop mean_income_mw_thres
			}

			** C. Observations after bottom threshold restriction (Average annual earnings >= ${min_wage_mult}*MW or >= ${thresh_mult}*threshold based on real MW in 1996)
			bys year season_group: gen obs_3 = _N
			label var obs_3 "obs restricting to bottom threshold"
			gen method = 2
			gen analysis_type = 1
			label var analysis_type "1 = data validation, 2 = complete"
			obs_analysis

		*** Find annual earnings
			gen annual_earnings = .
			replace annual_earnings = mean_earnings_r*formal_quarters*3*2 if nobs_year == 2
			replace annual_earnings = labor_income_r*12 if nobs_year == 1
			label var annual_earnings "Annualized earnings (real ${year_min} ARS)"
			sort id_year

		*** Collapse by id & year
			if $gtools gcollapse (mean) age gender labor_income annual_earnings season_group weight, by(id year)
			else collapse (mean) age gender labor_income annual_earnings season_group weight, by(id year)

		*** Find residuals earnings, regressions run separated by gender & year
			gen ln_annual_earnings = log(annual_earnings)
			replace age = round(age)
			gen researn = .

			qui foreach yr of numlist $year_min(1)$year_max {
				reg ln_annual_earnings i.season_group i.age if gender == 1 & year == `yr' [aw=weight]
				predict temp_m if e(sample)== 1, residuals
				reg ln_annual_earnings i.season_group i.age if gender == 0 & year == `yr' [aw=weight]
				predict temp_f if e(sample)== 1, residuals
				replace researn = temp_m if year == `yr' & gender == 1
				replace researn = temp_f if year == `yr' & gender == 0
				drop temp*
			}
			*

		*** Find stats for earnings
		gen sec = 1
		gen data = 1
		label var data "1 = all, 2 = by sector"
		rename ln_annual_earnings logearn_datav_m2
		rename researn researn_datav_m2
		mystats "logearn_datav_m2"
		mystats "researn_datav_m2"

		*** Density figures
		if $kdensity_figs == 1 {
			kdensity_fig_2 "researn_datav_m2" ${year_min} "{&epsilon}{sub:it}" ${year_max}
			kdensity_fig_2 "logearn_datav_m2" ${year_min} "log y{sub:it}" ${year_max}
		}
	}
}


*** longitudinal data validation
if $L_datav == 1 {

use "${DTA_DIR}/eph_cleaned.dta", clear

	*** Identify panel information
		gen year = year(dofq(period))
		gen quarter = quarter(dofq(period))

		** keep only relevant years
		keep if inrange(year, ${year_min}, ${year_max})

		** tabulate number of observations per worker
		by workerid: gen nobs = _N
		tab nobs

		** Reorder and rename id to be chronological
		tostring workerid, gen(aux_id)
		gen length_id = length(aux_id) // maximum length = 6
		gen aux_1 = "0"
		gen aux_2 = "00"
		gen aux_3 = "000"
		gen aux_4 = "0000"
		gen aux_5 = "00000"
		egen temp_id1 = concat(aux_5 aux_id) if length_id == 1
		egen temp_id2 = concat(aux_4 aux_id) if length_id == 2
		egen temp_id3 = concat(aux_3 aux_id) if length_id == 3
		egen temp_id4 = concat(aux_2 aux_id) if length_id == 4
		egen temp_id5 = concat(aux_1 aux_id) if length_id == 5
		replace aux_id = temp_id1 if length_id == 1
		replace aux_id = temp_id2 if length_id == 2
		replace aux_id = temp_id3 if length_id == 3
		replace aux_id = temp_id4 if length_id == 4
		replace aux_id = temp_id5  if length_id == 5
		drop temp*
		drop aux_1 aux_2 aux_3 aux_4 aux_5
		bys workerid: egen first_year = min(year)
		bys workerid: egen first_quarter = min(quarter)
		tostring first_year, replace
		tostring first_quarter, replace
		egen first_obs = concat(first_year first_quarter)
		egen new_id_temp = concat(first_obs aux_id)
		destring new_id_temp, replace
		egen new_id = group(new_id_temp)
		drop new_id_temp first_obs first_year first_quarter
		drop length_id aux_id
		rename new_id id

		** Create important variables: number of observations by id, by id-year, etc
		order id workerid
		sort id year quarter
		by id: gen index_id = _n
		egen id_year = group(id year)

	*** Methods to calculate the CS stats:
		** L FIRST METHOD
		/// Consider any quarter that repeat in the next year
		/// Consider as different ids if different quarter in a year
		/// Annualize only with the info of one quarter
		if $first_method == 1 {

		*** A. Number of obs in each quarter
			bys year quarter: gen obs_1 = _N
			label var obs_1 "number of total quarter obs"

		*** Drop if not formal in the individual-year obs
			drop if nobs == 1
			replace labor_income = . if formal!= 1 // Turn earnings to missing if not formal
			replace formal = 0 if labor_income == . // If earnings are missing, individuals are not formal employed in that obs
			drop if formal == 0 | public == 1 | type_job != 3
			egen id_quarter = group(id quarter)
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1  // drop if individual only appeared once in that quarter

			** B. Observations after restricting to: formal appearence, >1 appearence in a quarter for two years
			bys year quarter: gen obs_2 = _N
			label var obs_2 "obs restricting to formal and panel appearence"

		*** Transform earnings in real terms
			merge m:1 year quarter using "${DTA_DIR}/arg_cpi_quarterly.dta", keep(master match) keepusing(cpi_q) nogen
			sum cpi_q if year == ${year_min}
			local cpi_${year_min} = r(mean)
			replace cpi_q = cpi_q/`cpi_${year_min}'
			rename cpi_q cpi
			gen labor_income_r = labor_income/cpi
			label var labor_income_r "Labor income (real ${year_min} ARS)"
			drop cpi

		*** Create variables for years that id appear (max 3 in 96-02 range, but mostly 2)
			sort id year quarter
			gen aux = 0
			bys id: replace aux = 1 if year != year[_n-1]
			sort id year quarter
			replace aux = 0 if index_id == 1
			by id: egen sum_aux = sum(aux)
			replace sum_aux = sum_aux + 1
			gen year_norm = 0
			replace year_norm = 1 if index_id == 1
			sort id year quarter
			by id: replace year_norm = year_norm[_n-1] + aux[_n] if index_id != 1
			drop aux
			rename sum_aux years_id
			sort id_year quarter
			label var years_id "Number of years that id appear"
			label var year_norm "Index of year by id"

		*** Create indicator for id, year, quarter level
			sort id year quarter
			bys id year: gen nobs_year = _N // number of obs by (id year)
			egen id_year_quarter = group(year quarter id)

		*** Threshold
			** Merge dta with quarterly minimum wage value
			merge m:1 quarter year using "${DTA_DIR}/arg_min_wage_quarterly.dta", keep(master match) nogen
			rename min_wage_q mw

			gen labor_income_mw = labor_income/mw
			bys id_year_quarter: gen annual_mw = labor_income_mw*12

			if $lower_thresh == 0 {
				drop if labor_income_mw < ${min_wage_mult}
			}
			if $lower_thresh == 1 {
				merge m:1 quarter year using "${DTA_DIR}/arg_thresh_quarterly.dta", keep(master match) nogen
				drop date date_q
				drop if labor_income_r/thresh_q < ${thresh_mult}
				drop thresh_q
			}

			drop nobs_id_quarter
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1

		*** Treat observations with observations in 3 years
			** Drop if appearence in a quarter in two years is not consecutive years (happens only because there are a few obs in three years in 96-02 range)
				gen aux = 0
				sort id quarter year
				by id: replace aux = 1 if year[_n] == year[_n-1] + 2
				bys id quarter: egen mean_aux = mean(aux)
				drop if mean_aux > 0
				drop aux mean_aux

				** C. Observations after bottom threshold & guaranteing consecutive year panel appearence
				bys year quarter: gen obs_3 = _N
				label var obs_3 "obs after bottom threshold & consecutive year panel appearence"
				gen method = 1
				L_obs_analysis

			** Expand and treat as different ids the ones with 3 consecutive years in same quarter
				sort nobs_id_quarter id year quarter
				if inrange(1999, ${year_min}, ${year_max}) expand 2 if year == 1999 & nobs_id_quarter == 3
				gen dup = 0
				sort id quarter year
				replace dup = 1 if (year[_n] == year[_n+1]) & (quarter[_n] == quarter[_n+1]) & (id[_n] == id[_n+1])
				replace dup = 1 if dup[_n+1] == 1
				drop id_quarter
				egen id_quarter = group(id quarter dup)
				drop dup

		*** Collapse by id_quarter & year
			gen annual_earnings = labor_income_r*12
			if $gtools gcollapse (mean) age gender annual_earnings quarter weight, by(id_quarter year)
			else collapse (mean) age gender annual_earnings quarter weight, by(id_quarter year)

			gen sec = 1
			bys id_quarter: gen nobs_id_quarter = _N

		*** Find residuals earnings, regressions run separated by gender & year
			gen ln_annual_earnings = log(annual_earnings)
			replace age = round(age)
			gen researn = .

				qui foreach yr of numlist $year_min(1)$year_max {
					reg ln_annual_earnings i.quarter i.age if gender == 1 & year == `yr' [aw=weight]
					predict temp_m if e(sample)== 1, residuals
					reg ln_annual_earnings i.quarter i.age if gender == 0 & year == `yr' [aw=weight]
					predict temp_f if e(sample)== 1, residuals
					replace researn = temp_m if year == `yr' & gender == 1
					replace researn = temp_f if year == `yr' & gender == 0
					drop temp*
				}

		*** Find residuals 1-year delta
			sort id_quarter year
			by id_quarter: gen L_researn_1y = researn[_n+1] - researn[_n]
			drop if L_researn_1y == .
			drop researn

			** D. Observations after collapsing to one-year forward delta
			bys year: gen obs_4 = _N
			label var obs_4 "obs restricting to collapsed data and 1-y delta"
			gen method = 1
			L_obs_analysis

		*** Find stats for 1-y residuals earnings change
			gen data = 1
			label var data "1 = all analysis, 2 = by sector analysis"
			rename L_researn_1y L_researn_1y_datav_m1
			mystats "L_researn_1y_datav_m1"

		*** Density figures
			if $kdensity_figs == 1 {
				local year_max_m1 = ${year_max} - 1
				kdensity_fig_2 "L_researn_1y_datav_m1" ${year_min} "{&Delta}{sup:1}{&epsilon}{sub:it}" `year_max_m1'
			}

			** Erasing temp files
			sleep 100
			erase "${FINAL_DIR}/obs/datav_L_m1_temp.dta"

		}

		** L SECOND METHOD
		/// Consider any quarter or pair of quarters that repeat in the next year
		/// Regressions with indicator of quarters: example, (q1, x) , (x, q2), (q1, q2)
		if $second_method == 1 {

		*** Create season group variable: indicator in id-year level of observation structure
			create_season_group

			*** A. Number of obs in each season group variable
			bys year season_group: gen obs_1 = _N
			label var obs_1 "number of total season_group obs"

		*** Drop if not formal in the individual-year obs
			drop if nobs == 1
			replace labor_income = . if formal!= 1 // Turn earnings to missing if not formal
			replace labor_income = . if public == 1
			replace labor_income = . if type_job != 3
			replace formal = 0 if labor_income == . // If earnings are missing, individuals are not formal employed in that obs
			egen id_quarter = group(id quarter)
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1 // drop if individual only appeared once in that quarter
			bys id_year: egen mean_formal = mean(formal)
			drop if mean_formal == 0 // drop if not formal in the individual-year level
			drop nobs_id_quarter id_quarter
			egen id_quarter = group(id quarter)
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1 // drop if individual only appeared once in that quarter

			** B. Observations after restricting to formal & panel structure
			drop first_quarter second_quarter
			rename season_group sg_obs_1
			label var sg_obs_1 "season group reference for var obs_1"
			create_season_group
			bys year season_group: gen obs_2 = _N
			label var obs_2 "obs after restricting to formal sector & panel appearences"

		*** Create variables for years that id appear (max 3 in 96-02 range, but mostly 2)
			sort id year quarter
			gen aux = 0
			bys id: replace aux = 1 if year != year[_n-1]
			sort id year quarter
			replace aux = 0 if index_id == 1
			by id: egen sum_aux = sum(aux)
			replace sum_aux = sum_aux + 1
			gen year_norm = 0
			replace year_norm = 1 if index_id == 1
			sort id year quarter
			by id: replace year_norm = year_norm[_n-1] + aux[_n] if index_id != 1
			drop aux
			rename sum_aux years_id
			sort id_year quarter
			label var years_id "Number of years that id appear"
			label var year_norm "Index of year by id"

		*** Create indicator for id, year, quarter level; variable for number of quarters in formal sector
			sort id year quarter
			bys id year: gen nobs_year = _N // number of obs by (id year); more than 1 only in 1996-2002 range
			drop nobs
			bys id: gen nobs = _N
			bys id_year: gen nobs_formal = sum(formal)
			bys id_year: egen formal_quarters = max(nobs_formal) // Variable that identifies how many quarters (out of 2) individual worked at formal sector
			drop nobs_formal

		*** Treat observations with same id in 3 years
			** Expand and treat as different ids the ones with 3 consecutive years in same quarter
			sort nobs_id_quarter id year quarter
			if inrange(1999, ${year_min}, ${year_max}) expand 2 if year == 1999 & nobs_id_quarter == 3
			gen dup = 0
			sort id quarter year
			replace dup = 1 if (year[_n] == year[_n+1]) & (quarter[_n] == quarter[_n+1]) & (id[_n] == id[_n+1])
			replace dup = 1 if dup[_n+1] == 1
			drop id_quarter
			egen id_quarter = group(id quarter dup)
			egen id_year_2 = group(id dup year)
			drop nobs_year
			bys id_year_2: gen nobs_year = _N
			drop id_year
			rename id_year_2 id_year
			sort id
			egen id_2 = group(id dup)

			** Adjust id to be consistent in year over year comparisons
			bys id_2: gen nobs_2 = _N
			sort id_2
			gen aux = 0
			replace aux = 1 if (id_2[_n] == id_2[_n+1]) & (nobs_year[_n] != nobs_year[_n+1])
			bys id_2: gen index_id_2 = _n
			gen aux_2 = 0
			replace aux_2 = 1 if (id_2[_n] == id_2[_n+1])  & (nobs_year[_n] != nobs_year[_n+1]) & (quarter[_n] == quarter[_n+1])
			gen dif = aux - aux_2
			bys id_2: egen type_four_quarter = mean(dif)
			replace type_four_quarter = 2 if type_four_quarter == .5
			drop dif
			bys id_2: egen mean_2 = mean(aux_2)
			replace type_four_quarter = 3 if (mean_2 > 0)
			drop mean_2 aux aux_2
			gen dup_2 = 0
			replace dup_2 = 1 if (type_four_quarter == 3) & (index_id_2 == 1)
			replace dup_2 = 1 if (type_four_quarter == 3) & (index_id_2 == 2)
			replace dup_2 = 1 if (type_four_quarter == 2) & (index_id_2 == 1)
			replace dup_2 = 1 if (type_four_quarter == 2) & (index_id_2 == 3)
			sort id_2
			egen id_3 = group(id_2 dup_2)
			drop dup_2

			drop id_year
			egen id_year = group(id_3 year)
			drop nobs_year
			bys id_year: gen nobs_year = _N
			drop id_quarter
			egen id_quarter = group(id_3 quarter)
			drop nobs_id_quarter
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1

			** Drop if after restrictions not formal in a id-year level
			drop mean_formal
			bys id_year: egen mean_formal = mean(formal)
			drop if mean_formal == 0
			bys id_3: gen nobs_3 = _N
			drop nobs_year
			bys id_year: gen nobs_year = _N
			drop if nobs_3 == 1
			drop formal_quarters
			bys id_year: gen nobs_formal = sum(formal)
			bys id_year: egen formal_quarters = max(nobs_formal) // Variable that identifies how many quarters (out of 2) individual worked at formal sector
			drop nobs_formal

		*** Create season group variable: indicator in id-year level of observation structure
			drop first_quarter second_quarter
			rename season_group sg_obs_2
			label var sg_obs_2 "season group reference for var obs_2"
			create_season_group

			** C. Observations after restricting to panel structure consistency
			bys year season_group: gen obs_3 = _N
			label var obs_3 "obs after restricting to panel structure consistency"

		*** Transform earnings in real terms
			merge m:1 year quarter using "${DTA_DIR}/arg_cpi_quarterly.dta", keep(master match) keepusing(cpi_q) nogen
			sum cpi_q if year == ${year_min}
			local cpi_${year_min} = r(mean)
			replace cpi_q = cpi_q/`cpi_${year_min}'
			rename cpi_q cpi
			gen labor_income_r = labor_income/cpi
			label var labor_income_r "Labor income (real ${year_min} ARS)"
			drop cpi
			bys id_year: egen mean_earnings_r = mean(labor_income_r)

		*** Threshold
			** Merge dta with quarterly minimum wage value
			merge m:1 quarter year using "${DTA_DIR}/arg_min_wage_quarterly.dta", keep(master match) nogen
			rename min_wage_q mw
			gen labor_income_mw = labor_income/mw
			gen annual_mw = .

			** Find annual wage in terms of mw
			bys id_year: gen annual_mw_1 = sum(labor_income_mw) if nobs_year == 2
			replace annual_mw_1 = annual_mw_1*6 if nobs_year == 2
			bys id_year: egen annual_mw_aux = max(annual_mw_1) if nobs_year == 2
			replace annual_mw_1 = annual_mw_aux
			drop annual_mw_aux
			bys id_year: gen annual_mw_2 = labor_income_mw*12 if nobs_year == 1
			replace annual_mw = annual_mw_1 if nobs_year == 2
			replace annual_mw = annual_mw_2 if nobs_year == 1
			drop annual_mw_1 annual_mw_2

			bys id_year: egen mean_income_mw = mean(labor_income_mw)
			if $lower_thresh == 0 {
				drop if mean_income_mw < ${min_wage_mult}
			}
			if $lower_thresh == 1 {
				merge m:1 quarter year using "${DTA_DIR}/arg_thresh_quarterly.dta", keep(master match) nogen
				drop date date_q
				gen labor_income_mw_thres = labor_income_r/thresh_q
				drop thresh_q
				bys id_year: egen mean_income_mw_thres = mean(labor_income_mw_thres)
				drop labor_income_mw_thres
				drop if mean_income_mw_thres < ${thresh_mult}
				drop mean_income_mw_thres
			}

			drop id
			rename id_3 id
			drop nobs_3
			bys id: gen nobs_3 = _N
			drop nobs_year
			bys id_year: gen nobs_year = _N
			tab nobs_3 nobs_year
			drop if nobs_3 == 1
			drop if nobs_3 == 2 & nobs_year == 2
			gen aux = 1 if nobs_year == 1 & nobs_3 == 4
			bys id: egen mean_aux = mean(aux)
			drop if mean_aux == 1
			drop aux

			drop mean_earnings_r
			bys id_year: egen mean_earnings_r = mean(labor_income_r)

			** D. Observations after restricting to bottom threshold
			bys year season_group: gen obs_4 = _N
			label var obs_4 "obs after restricting to bottom threshold"
			gen method = 2
			L_obs_analysis

		*** Find annual earnings
			sort id_year
			gen annual_earnings = .
			replace annual_earnings = mean_earnings_r*formal_quarters*3*2 if nobs_year == 2
			replace annual_earnings = labor_income_r*12 if nobs_year == 1

		*** Collapse by id & year
			if $gtools gcollapse (mean) age gender labor_income annual_earnings season_group weight, by(id year)
			else collapse (mean) age gender labor_income annual_earnings season_group weight, by(id year)

			gen sec = 1

		*** Find residuals earnings, regressions run separated by gender & year
			gen ln_annual_earnings = log(annual_earnings)
			replace age = round(age)
			gen researn = .

				qui foreach yr of numlist $year_min(1)$year_max {
					reg ln_annual_earnings i.season_group i.age if gender == 1 & year == `yr' [aw=weight]
					predict temp_m if e(sample)== 1, residuals
					reg ln_annual_earnings i.season_group i.age if gender == 0 & year == `yr' [aw=weight]
					predict temp_f if e(sample)== 1, residuals
					replace researn = temp_m if year == `yr' & gender == 1
					replace researn = temp_f if year == `yr' & gender == 0
					drop temp*
				}
			*

		*** Find residuals 1-year delta
			sort id year
			by id: gen L_researn_1y = researn[_n+1] - researn[_n]
			drop if L_researn_1y == .
			drop researn

			** E. Observations after collapsing to one-year forward delta
			bys year: gen obs_5 = _N
			label var obs_5 "obs restricting to collapsed data and 1-y delta"
			gen method = 2
			L_obs_analysis

		*** Find stats for 1-y residuals earnings change
			gen data = 1
			label var data "1 = all analysis, 2 = by sector analysis"
			rename L_researn_1y L_researn_1y_datav_m2
			mystats "L_researn_1y_datav_m2"

		*** Density figures
			if $kdensity_figs == 1 {
				local year_max_m1 = ${year_max} - 1
				kdensity_fig_2 "L_researn_1y_datav_m2" ${year_min} "{&Delta}{sup:1}{&epsilon}{sub:it}" `year_max_m1'
			}

		*** Erase temp files
			sleep 100
			erase "${FINAL_DIR}/obs/datav_L_m2_temp.dta"
			erase "${FINAL_DIR}/obs/datav_L_m2_temp_1.dta"
			erase "${FINAL_DIR}/obs/datav_L_m2_temp_2.dta"
			erase "${FINAL_DIR}/obs/datav_L_m2_temp_5.dta"

		}
}
