********************************************************************************
* DESCRIPTION: Creates cross-sectional (CS) and longitudinal (L) statistics and figures.
*
* NOTES: Sector switchers are identified and then dropped (!) as follows:
* - CS Second method:
*     lines 231-237: identify switchers
*     lines 323-326: drop the switchers for the sectoral analysis
* - L Second method:
*     lines 690-697: identify switchers with variable aux_sec
*     lines 765-781: create the variable sec that is different than 0 for only non-switchers
*     line 837: drop switchers
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************


*** housekeeping (open)
set more off
timer clear 1
timer on 1
set seed 1
set rmsg on
postutil clear
cap log close


*******************************************************
******** ALL & INFORMAL vs FORMAL  ********************
*******************************************************

if $CS == 1 {

	use "${DTA_DIR}/eph_cleaned.dta", clear

	*** Identify panel information
		gen year = year(dofq(period))
		gen quarter = quarter(dofq(period))

		** keep only relevant years
		keep if inrange(year, ${year_min}, ${year_max})

		** Reorder and rename id to be chronological
		tostring workerid, gen(aux_id)
		gen length_id = length(aux_id) // maximum length = 6
		gen aux_1 = "0"
		gen aux_2 = "00"
		gen aux_3 = "000"
		gen aux_4 = "0000"
		gen aux_5 = "00000"
		egen temp_id1 = concat(aux_5 aux_id) if length_id == 1
		egen temp_id2 = concat(aux_4 aux_id) if length_id == 2
		egen temp_id3 = concat(aux_3 aux_id) if length_id == 3
		egen temp_id4 = concat(aux_2 aux_id) if length_id == 4
		egen temp_id5 = concat(aux_1 aux_id) if length_id == 5
		replace aux_id = temp_id1 if length_id == 1
		replace aux_id = temp_id2 if length_id == 2
		replace aux_id = temp_id3 if length_id == 3
		replace aux_id = temp_id4 if length_id == 4
		replace aux_id = temp_id5  if length_id == 5
		drop temp*
		drop aux_1 aux_2 aux_3 aux_4 aux_5
		bys workerid: egen first_year = min(year)
		bys workerid: egen first_quarter = min(quarter)
		tostring first_year, replace
		tostring first_quarter, replace
		egen first_obs = concat(first_year first_quarter)
		egen new_id_temp = concat(first_obs aux_id)
		destring new_id_temp, replace
		egen new_id = group(new_id_temp)
		drop new_id_temp first_obs first_year first_quarter
		drop length_id aux_id
		rename new_id id

		** Create important variables: number of observations by id, by id-year, etc
		order id workerid
		sort id year quarter
		by id: gen nobs = _N // number of observations by id
		by id: gen index_id = _n
		egen id_year = group(id year)
		bys id_year: gen nobs_year = _N /// number of obs in each id-year level; maximum of 2 obs

		** Create season group variable: indicator in id-year level of observation structure
		create_season_group

	*** Methods to calculate the CS stats:
		** FIRST METHOD
		/// Consider any quarter in a year
		/// Consider as different ids if different quarter in a year
		/// Annualize only with the info of one quarter
		if $first_method == 1 {

		*** A. Number of obs in each quarter
			bys year quarter: gen obs_1 = _N
			label var obs_1 "number of total quarter obs"

		*** Variable to each sector in the individual-year obs
			gen sec = 0
			replace sec = 1 if formal == 1 & public != 1 & type_job == 3 & labor_income != .
			replace sec = 2 if formal == 0 & public != 1 & type_job == 3 & labor_income != .
			drop if public == 1 | type_job != 3

		*** Create indicator for id, year, quarter level
			egen id_year_quarter = group(id year quarter)
			drop season_group

		*** Drop if do not have earnings in id-year level
			bys id_year_quarter: egen mean_earnings = mean(labor_income)
			drop if mean_earnings == .

		*** B. Observations after first restricton (employed privately in the formal or informal sector & labor_income != .)
			bys year quarter sec: gen obs_2 = _N
			label var obs_2 "obs restricting to formal & informal sector"

		*** Transform earnings in real terms
			merge m:1 year quarter using "${DTA_DIR}/arg_cpi_quarterly.dta", keep(master match) keepusing(cpi_q) nogen
			sum cpi_q if year == ${year_min}
			local cpi_${year_min} = r(mean)
			replace cpi_q = cpi_q/`cpi_${year_min}'
			rename cpi_q cpi
			gen labor_income_r = labor_income/cpi
			label var labor_income_r "Labor income (real ${year_min} ARS)"
			drop cpi

		*** Threshold
			** Merge dta with quarterly minimum wage value
			merge m:1 quarter year using "${DTA_DIR}/arg_min_wage_quarterly.dta", keep(master match) nogen
			rename min_wage_q mw

			** Find annual wage in terms of mw
			gen labor_income_mw = labor_income/mw
			bys id_year_quarter: gen annual_mw = labor_income_mw*12

			if $lower_thresh == 0 {
				drop if labor_income_mw < ${min_wage_mult}
			}
			else if $lower_thresh == 1 {
				merge m:1 quarter year using "${DTA_DIR}/arg_thresh_quarterly.dta", keep(master match) nogen
				drop date date_q
				drop if labor_income_r/thresh_q < ${thresh_mult}
				drop thresh_q
			}

			** C. Observations restricting to bottom threshold
			bys year quarter sec: gen obs_3 = _N
			label var obs_3 "obs restricting to bottom threshold"
			gen method = 1
			gen analysis_type = 2
			label var analysis_type "1 = data validation, 2 = complete"
			obs_analysis

		*** Collapse information to individual & year & quarter level
			gen annual_earnings = labor_income_r*12
			collapse (mean) id age gender annual_earnings quarter weight sec year, by(id_year_quarter)

			drop id
			rename id_year_quarter id

		*** Find residuals earnings, regressions run separated by gender & year
			gen ln_annual_earnings = log(annual_earnings)
			replace age = round(age)
			gen researn = .

				foreach yr of numlist $year_min(1)$year_max {
					qui reg ln_annual_earnings i.quarter i.age if gender == 1 & year == `yr' [aw=weight]
					qui predict temp_m if e(sample)== 1, residuals
					qui reg ln_annual_earnings i.quarter i.age if gender == 0 & year == `yr' [aw=weight]
					qui predict temp_f if e(sample)== 1, residuals
					qui replace researn = temp_m if year == `yr' & gender == 1
					qui replace researn = temp_f if year == `yr' & gender == 0
					drop temp*
				}
			*

		*** Find stats for earnings
			rename ln_annual_earnings logearn_m1
			rename researn researn_m1
			gen data = 1
			label var data "1 = all, 2 = by sector"
			mystats "logearn_m1"
			mystats "researn_m1"

		*** Density figures
			if $kdensity_figs == 1 {
			kdensity_fig_2 "researn_m1" ${year_min} "{&epsilon}{sub:it}" ${year_max}
			kdensity_fig_2 "logearn_m1" ${year_min} "log y{sub:it}" ${year_max}
			}

		*** By sector analysis ***
		*** Find stats for earnings by sector
			rename logearn_m1 logearn_sec_m1
			rename researn_m1 researn_sec_m1
			drop data
			gen data = 2
			mystats "logearn_sec_m1"
			mystats "researn_sec_m1"

		*** Density figures by sector
			if $kdensity_figs == 1 {
			kdensity_fig "logearn_sec_m1" ${year_min} "log y{sub:it}"
 			kdensity_fig "researn_sec_m1" ${year_min} "{&epsilon}{sub:it}"

			kdensity_fig "logearn_sec_m1" ${year_max} "log y{sub:it}"
 			kdensity_fig "researn_sec_m1" ${year_max} "{&epsilon}{sub:it}"

			kdensity_fig_2 "researn_sec_m1" ${year_min} "{&epsilon}{sub:it}" ${year_max} 1
			kdensity_fig_2 "researn_sec_m1" ${year_min} "{&epsilon}{sub:it}" ${year_max} 2
			}
		}

		** SECOND METHOD
		/// Consider any quarter or pair of quarters
		/// Regressions with indicator of quarters: example, (q1, x) , (x, q2), (q1, q2)
		if $second_method == 1 {

		*** Variable to each sector in the individual-year obs
			gen sec = 0
			replace sec = 1 if formal == 1 & public != 1 & type_job == 3 & labor_income != .
			replace sec = 2 if formal == 0 & public != 1 & type_job == 3 & labor_income != .
			replace labor_income = . if sec == 0

		*** Drop if do not have earnings in the individual-year obs
			bys id_year: egen mean_earnings = mean(labor_income) // Average earnings in the quarters
			drop if mean_earnings == .

		*** Create variable for quarters worked in each sector
			replace formal = 1 if sec == 1
			replace formal = 0 if sec != 1
			bys id_year: gen nobs_formal = sum(formal)
			bys id_year: egen formal_quarters = max(nobs_formal) // Variable that identifies how many quarters (out of 2) individual worked at formal sector
			drop nobs_formal
			gen informal = 0
			replace informal = 1 if sec == 2
			bys id_year: gen nobs_informal = sum(informal)
			bys id_year: egen informal_quarters = max(nobs_informal) // Variable that identifies how many quarters (out of 2) individual worked at informal sector
			gen working_quarters = formal_quarters + informal_quarters
			replace sec = 4 if sec == 2
			bys id_year: egen mean_sector = mean(sec)
				// mean_sector = .5 (0,1 -> missing, formal)
				//				  1 (1,1 -> formal, formal)
				//				  2 (4,0 -> informal, mising)
				//				  2.5 (1,4 -> formal, informal)
				//				  4 (4,4 -> informal, informal)
			label var mean_sector "0.5 (.,F); 1 (F,F); 2 (I,.); 2.5 (F,I); 4 (I,I)"
			replace sec = 2 if sec == 4

		*** Transform earnings in real terms
			merge m:1 year quarter using "${DTA_DIR}/arg_cpi_quarterly.dta", keep(master match) keepusing(cpi_q) nogen
			sum cpi_q if year == ${year_min}
			local cpi_${year_min} = r(mean)
			replace cpi_q = cpi_q/`cpi_${year_min}'
			rename cpi_q cpi
			gen labor_income_r = labor_income/cpi
			label var labor_income_r "Labor income (real ${year_min} ARS)"
			drop cpi
			bys id_year: egen mean_earnings_r = mean(labor_income_r)

		*** Threshold
			** Merge dta with quarterly minimum wage value
			merge m:1 quarter year using "${DTA_DIR}/arg_min_wage_quarterly.dta", keep(master match) nogen
			rename min_wage_q mw
			gen labor_income_mw = labor_income/mw
			gen annual_mw = .

			** Find mean & annual wage in terms of mw
			bys id_year: egen mean_earnings_mw = mean(labor_income_mw)

			if $lower_thresh == 0 {
				drop if mean_income_mw < ${min_wage_mult}
			}
			if $lower_thresh == 1 {
				merge m:1 quarter year using "${DTA_DIR}/arg_thresh_quarterly.dta", keep(master match) nogen
				drop date date_q
				gen labor_income_mw_thres = labor_income_r/thresh_q
				label var labor_income_r "Labor income (real ${year_min} ARS)"
				drop thresh_q
				bys id_year: egen mean_income_mw_thres = mean(labor_income_mw_thres)
				drop labor_income_mw_thres
				drop if mean_income_mw_thres < ${thresh_mult}
				drop mean_income_mw_thres
			}

			replace annual_mw = mean_earnings_mw*working_quarters*3*2 if nobs_year == 2
			replace annual_mw = labor_income_mw*12 if nobs_year == 1

		*** Find annual earnings
			gen annual_earnings = .
			replace annual_earnings = mean_earnings_r*working_quarters*3*2 if nobs_year == 2
			replace annual_earnings = labor_income_r*12 if nobs_year == 1
			sort id_year
			gen annual_earnings_formal = .
			replace annual_earnings_formal = mean_earnings_r*formal_quarters*3*2 if nobs_year == 2 & mean_sector == 1
			replace annual_earnings_formal = labor_income_r*12 if nobs_year == 1 & mean_sector == 1
			gen annual_earnings_informal = .
			replace annual_earnings_informal = mean_earnings_r*informal_quarters*3*2 if nobs_year == 2 & mean_sector == 4
			replace annual_earnings_informal = labor_income_r*12 if nobs_year == 1 & mean_sector == 4

		*** Collapse by id & year
			collapse (mean) age gender sec annual_earnings* formal_quarters informal_quarters working_quarters season_group weight mean_sector, by(id year)

		*** Find residuals earnings, regressions run separated by gender & year
			gen ln_annual_earnings = log(annual_earnings)
			replace age = round(age)
			gen researn = .

				qui foreach yr of numlist $year_min(1)$year_max {
					reg ln_annual_earnings i.season_group i.age if gender == 1 & year == `yr' [aw=weight]
					predict temp_m if e(sample)== 1, residuals
					reg ln_annual_earnings i.season_group i.age if gender == 0 & year == `yr' [aw=weight]
					predict temp_f if e(sample)== 1, residuals
					replace researn = temp_m if year == `yr' & gender == 1
					replace researn = temp_f if year == `yr' & gender == 0
					drop temp*
				}
			*

		*** Find stats for earnings
			gen data = 1
			rename ln_annual_earnings logearn_m2
			rename researn researn_m2
			mystats "logearn_m2"
			mystats "researn_m2"

		*** Density figures
			if $kdensity_figs == 1 {
			kdensity_fig_2 "researn_m2" ${year_min} "{&epsilon}{sub:it}" ${year_max}
			kdensity_fig_2 "logearn_m2" ${year_min} "log y{sub:it}" ${year_max}
			}

		*** By sector analysis ***
		*** Drop if person changed sector within year when id-year has two quarters obs -- XXX MAY WANT TO RELAX THIS IN FUTURE ITERATION!
			drop if mean_sector == 2.5
			replace sec = 1 if mean_sector == 0.5
			replace sec = 2 if mean_sector == 4 | mean_sector == 2

		*** Find stats for earnings by sector
			rename logearn_m2 logearn_sec_m2
			rename researn_m2 researn_sec_m2
			drop data
			gen data = 2
			mystats "logearn_sec_m2"
			mystats "researn_sec_m2"

			if $kdensity_figs == 1 {
			kdensity_fig "logearn_sec_m2" ${year_min} "log y{sub:it}"
 			kdensity_fig "researn_sec_m2" ${year_min} "{&epsilon}{sub:it}"

			kdensity_fig "logearn_sec_m2" ${year_max} "log y{sub:it}"
 			kdensity_fig "researn_sec_m2" ${year_max} "{&epsilon}{sub:it}"

			kdensity_fig_2 "researn_sec_m2" ${year_min} "{&epsilon}{sub:it}" ${year_max} 1
			kdensity_fig_2 "researn_sec_m2" ${year_min} "{&epsilon}{sub:it}" ${year_max} 2
			}
}
}
*

if $L == 1 {

	use "${DTA_DIR}/eph_cleaned.dta", clear

	*** Identify panel information
		gen year = year(dofq(period))
		gen quarter = quarter(dofq(period))

		** keep only relevant years
		keep if inrange(year, ${year_min}, ${year_max})

		** tabulate number of observations per worker
		by workerid: gen nobs = _N
		tab nobs

		** Reorder and rename id to be chronological
		tostring workerid, gen(aux_id)
		gen length_id = length(aux_id) // maximum length = 6
		gen aux_1 = "0"
		gen aux_2 = "00"
		gen aux_3 = "000"
		gen aux_4 = "0000"
		gen aux_5 = "00000"
		egen temp_id1 = concat(aux_5 aux_id) if length_id == 1
		egen temp_id2 = concat(aux_4 aux_id) if length_id == 2
		egen temp_id3 = concat(aux_3 aux_id) if length_id == 3
		egen temp_id4 = concat(aux_2 aux_id) if length_id == 4
		egen temp_id5 = concat(aux_1 aux_id) if length_id == 5
		replace aux_id = temp_id1 if length_id == 1
		replace aux_id = temp_id2 if length_id == 2
		replace aux_id = temp_id3 if length_id == 3
		replace aux_id = temp_id4 if length_id == 4
		replace aux_id = temp_id5  if length_id == 5
		drop temp*
		drop aux_1 aux_2 aux_3 aux_4 aux_5
		bys workerid: egen first_year = min(year)
		bys workerid: egen first_quarter = min(quarter)
		tostring first_year, replace
		tostring first_quarter, replace
		egen first_obs = concat(first_year first_quarter)
		egen new_id_temp = concat(first_obs aux_id)
		destring new_id_temp, replace
		egen new_id = group(new_id_temp)
		drop new_id_temp first_obs first_year first_quarter
		drop length_id aux_id
		rename new_id id

		** Create important variables: number of observations by id, by id-year, etc
		order id workerid
		sort id year quarter
		by id: gen index_id = _n
		egen id_year = group(id year)
		drop if nobs == 1

	*** Methods to calculate the CS stats:
		** L FIRST METHOD
		/// Consider any quarter that repeat in the next year
		/// Consider as different ids if different quarter in a year
		/// Annualize only with the info of one quarter
		if $first_method == 1 {

		*** Drop if do not have earnings in id-year-quarter level
			drop if labor_income == . | public == 1 | type_job != 3

		*** Drop if individual only appeared once in that quarter
			egen id_quarter = group(id quarter)
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1  // drop if individual only appeared once in that quarter

		*** Create variables for years that id appear (max 3 in 96-02 range, but mostly 2)
			sort id year quarter
			gen aux = 0
			bys id: replace aux = 1 if year != year[_n-1]
			sort id year quarter
			replace aux = 0 if index_id == 1
			by id: egen sum_aux = sum(aux)
			replace sum_aux = sum_aux + 1
			gen year_norm = 0
			replace year_norm = 1 if index_id == 1
			sort id year quarter
			by id: replace year_norm = year_norm[_n-1] + aux[_n] if index_id != 1
			drop aux
			rename sum_aux years_id
			sort id_year quarter
			label var years_id "Number of years that id appear"
			label var year_norm "Index of year by id"

		*** Create indicator for id, year, quarter level
			sort id year quarter
			bys id year: gen nobs_year = _N // number of obs by (id year); maximum of 2
			egen id_year_quarter = group(year quarter id)

		*** Transform earnings in real terms
			merge m:1 year quarter using "${DTA_DIR}/arg_cpi_quarterly.dta", keep(master match) keepusing(cpi_q) nogen
			sum cpi_q if year == ${year_min}
			local cpi_${year_min} = r(mean)
			replace cpi_q = cpi_q/`cpi_${year_min}'
			rename cpi_q cpi
			gen labor_income_r = labor_income/cpi
			label var labor_income_r "Labor income (real ${year_min} ARS)"
			drop cpi

		*** Threshold
			** Merge dta with quarterly minimum wage value
			merge m:1 quarter year using "${DTA_DIR}/arg_min_wage_quarterly.dta", keep(master match) nogen
			rename min_wage_q mw

			gen labor_income_mw = labor_income/mw
			bys id_year_quarter: gen annual_mw = labor_income_mw*12

			if $lower_thresh == 0 {
				drop if labor_income_mw < ${min_wage_mult}
			}
			if $lower_thresh == 1 {
				merge m:1 quarter year using "${DTA_DIR}/arg_thresh_quarterly.dta", keep(master match) nogen
				drop date date_q
				drop if labor_income_r/thresh_q < ${thresh_mult}
				drop thresh_q
			}

			drop nobs_id_quarter
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1

		*** Treat observations with observations in 3 years
			** Drop if appearence in a quarter in two years is not consecutive years (happens only because a few have obs in three years in 96-02 range)
				gen aux = 0
				sort id quarter year
				by id: replace aux = 1 if year[_n] == year[_n-1] + 2
				bys id quarter: egen mean_aux = mean(aux)
				drop if mean_aux > 0
				drop aux mean_aux

			** Expand and treat as different ids the ones with 3 consecutive years in same quarter
				sort nobs_id_quarter id year quarter
				if inrange(1999, ${year_min}, ${year_max}) expand 2 if year == 1999 & nobs_id_quarter == 3
				gen dup = 0
				sort id quarter year
				replace dup = 1 if (year[_n] == year[_n+1]) & (quarter[_n] == quarter[_n+1]) & (id[_n] == id[_n+1])
				replace dup = 1 if dup[_n+1] == 1
				drop id_quarter
				egen id_quarter = group(id quarter dup)
				drop dup

		*** Number of observations
			///preserve
			///bys quarter year: gen nobs_year_quarter = _N
			///collapse (mean) nobs_year_quarter, by (quarter year)
			///sort year quarter
			///reshape wide nobs_year_quarter, i(year) j(quarter)
			///save "${FINAL_DIR}/obs/L1_quarter_nobs.dta", replace
			///restore

		*** Create sector variable
			// Formal -> Formal
			// Informal -> Informal
			// Formal -> Informal
			// Informal -> Formal
			gen sec_aux = 0
			replace sec_aux = 1 if formal == 1
			replace sec_aux = 2 if formal == 0
			gen sec = 0
			bys id_quarter: egen mean_sector = mean(sec_aux)
			replace sec = 1 if mean_sector == 1 // transition formal-formal
			replace sec = 2 if mean_sector == 2 // transition informal-informal
			sort id_quarter year
			by id_quarter: gen first_sec = formal[1]
			replace sec = 5 if mean_sector == 1.5 & first_sec == 1 // transition formal-informal
			replace sec = 6 if mean_sector == 1.5 & first_sec == 0 // transition informal-formal

		*** Collapse by id_quarter & year
			gen annual_earnings = labor_income_r*12
			collapse (mean) age gender annual_earnings sec quarter weight, by(id_quarter year)

			bys id_quarter: gen nobs_id_quarter = _N

		*** Find residuals earnings, regressions run separated by gender & year
			gen ln_annual_earnings = log(annual_earnings)
			replace age = round(age)
			gen researn = .

				qui foreach yr of numlist $year_min(1)$year_max {
					reg ln_annual_earnings i.quarter i.age if gender == 1 & year == `yr' [aw=weight]
					predict temp_m if e(sample)== 1, residuals
					reg ln_annual_earnings i.quarter i.age if gender == 0 & year == `yr' [aw=weight]
					predict temp_f if e(sample)== 1, residuals
					replace researn = temp_m if year == `yr' & gender == 1
					replace researn = temp_f if year == `yr' & gender == 0
					drop temp*
				}
			*

		*** Find residuals 1-year delta
			sort id_quarter year
			by id_quarter: gen L_researn_1y = researn[_n+1] - researn[_n]
			drop if L_researn_1y == .
			drop researn

		*** Find stats for 1-y residuals earnings change
			rename L_researn_1y L_researn_1y_m1
			gen data = 1
			mystats "L_researn_1y_m1"

		*** Density figures
			if $kdensity_figs == 1 {
				local year_max_m3 = ${year_max} - 3
				local year_max_m1 = ${year_max} - 1
				kdensity_fig_2 "L_researn_1y_m1" ${year_min} "{&Delta}{sup:1}{&epsilon}{sub:it}" `year_max_m3'
				kdensity_fig_2 "L_researn_1y_m1" ${year_min} "{&Delta}{sup:1}{&epsilon}{sub:it}" `year_max_m1'
			}

		*** By sector analysis ***
		*** Find stats for earnings by sector
			rename L_researn_1y_m1 L_researn_1y_sec_m1
			drop data
			gen data = 2
			mystats "L_researn_1y_sec_m1"

		*** Density figures by sector
			if $kdensity_figs == 1 {
				local year_max_m1 = ${year_max} - 1
				L_kdensity_sec_fig "L_researn_1y_sec_m1" ${year_min}
				L_kdensity_sec_fig "L_researn_1y_sec_m1" `year_max_m1'
				L_kdensity_sec_fig_2 "L_researn_1y_sec_m1" ${year_min} `year_max_m1'
			}
		}

		** L SECOND METHOD
		/// Consider any quarter or pair of quarters that repeat in the next year
		/// Regressions with indicator of quarters: example, (q1, x) , (x, q2), (q1, q2)
		if $second_method == 1 {

		*** Drop if no earnings in the individual-year obs
			egen id_quarter = group(id quarter)
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1 // drop if individual only appeared once in that quarter
			replace labor_income = . if public == 1 // disconsider public jobs
			replace labor_income = . if type_job != 3 // consider only employees
			bys id_year: egen mean_earnings = mean(labor_income)
			drop if mean_earnings == . // drop if no earnings in the individual-year level
			drop nobs_id_quarter id_quarter
			egen id_quarter = group(id quarter)
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1 // drop if individual only appeared once in that quarter

		*** Create variables for years that id appear (max 3 in 96-02 range, but mostly 2)
			sort id year quarter
			gen aux = 0
			bys id: replace aux = 1 if year != year[_n-1]
			sort id year quarter
			replace aux = 0 if index_id == 1
			by id: egen sum_aux = sum(aux)
			replace sum_aux = sum_aux + 1
			gen year_norm = 0
			replace year_norm = 1 if index_id == 1
			sort id year quarter
			by id: replace year_norm = year_norm[_n-1] + aux[_n] if index_id != 1
			drop aux
			rename sum_aux years_id
			sort id_year quarter
			label var years_id "Number of years that id appear"
			label var year_norm "Index of year by id"

		*** Create indicator for id, year, quarter level; variable for number of quarters in formal sector
			sort id year quarter
			bys id year: gen nobs_year = _N // number of obs by (id year); more than 1 only in 1996-2002 range
			drop nobs
			bys id: gen nobs = _N

		*** Treat observations with same id in 3 years
			** Expand and treat as different ids the ones with 3 consecutive years in same quarter
			sort nobs_id_quarter id year quarter
			if inrange(1999, ${year_min}, ${year_max}) expand 2 if year == 1999 & nobs_id_quarter == 3
			gen dup = 0
			sort id quarter year
			replace dup = 1 if (year[_n] == year[_n+1]) & (quarter[_n] == quarter[_n+1]) & (id[_n] == id[_n+1])
			replace dup = 1 if dup[_n+1] == 1
			drop id_quarter
			egen id_quarter = group(id quarter dup)
			egen id_year_2 = group(id dup year)
			drop nobs_year
			bys id_year_2: gen nobs_year = _N
			drop id_year
			rename id_year_2 id_year
			sort id
			egen id_2 = group(id dup)

			** Adjust id to consistent year over year comparisons
			bys id_2: gen nobs_2 = _N
			sort id_2
			gen aux = 0
			replace aux = 1 if (id_2[_n] == id_2[_n+1]) & (nobs_year[_n] != nobs_year[_n+1])
			bys id_2: gen index_id_2 = _n
			gen aux_2 = 0
			replace aux_2 = 1 if (id_2[_n] == id_2[_n+1])  & (nobs_year[_n] != nobs_year[_n+1]) & (quarter[_n] == quarter[_n+1])
			gen dif = aux - aux_2
			bys id_2: egen type_four_quarter = mean(dif)
			replace type_four_quarter = 2 if type_four_quarter == .5
			drop dif
			bys id_2: egen mean_2 = mean(aux_2)
			replace type_four_quarter = 3 if (mean_2 > 0)
			drop mean_2 aux aux_2
			gen dup_2 = 0
			replace dup_2 = 1 if (type_four_quarter == 3) & (index_id_2 == 1)
			replace dup_2 = 1 if (type_four_quarter == 3) & (index_id_2 == 2)
			replace dup_2 = 1 if (type_four_quarter == 2) & (index_id_2 == 1)
			replace dup_2 = 1 if (type_four_quarter == 2) & (index_id_2 == 3)
			sort id_2
			egen id_3 = group(id_2 dup_2)
			drop dup_2

			drop id_year
			egen id_year = group(id_3 year)
			drop nobs_year
			bys id_year: gen nobs_year = _N
			drop id_quarter
			egen id_quarter = group(id_3 quarter)
			drop nobs_id_quarter
			bys id_quarter: gen nobs_id_quarter = _N
			drop if nobs_id_quarter == 1

			** Drop if after restrictions missing earnings in a id-year level
			drop mean_earnings
			bys id_year: egen mean_earnings = mean(labor_income)
			drop if mean_earnings == .
			bys id_3: gen nobs_3 = _N
			drop nobs_year
			bys id_year: gen nobs_year = _N
			drop if nobs_3 == 1 | nobs_3 == 5

		*** Create variables with working quarters in each sector and overall
			gen aux_sec = 0
			replace aux_sec = 1 if formal == 1 & public != 1 & type_job == 3 & labor_income != .
			replace aux_sec = 2 if formal == 0 & public != 1 & type_job == 3 & labor_income != .
			replace formal = 1 if aux_sec == 1
			replace formal = 0 if aux_sec != 1
			bys id_year: gen nobs_formal = sum(formal)
			bys id_year: egen formal_quarters = max(nobs_formal) // Variable that identifies how many quarters (out of 2) individual worked at formal sector
			drop nobs_formal
			gen informal = 0
			replace informal = 1 if aux_sec == 2
			bys id_year: gen nobs_informal = sum(informal)
			bys id_year: egen informal_quarters = max(nobs_informal) // Variable that identifies how many quarters (out of 2) individual worked at informal sector
			drop nobs_informal
			gen working_quarters = formal_quarters + informal_quarters
			replace aux_sec = 4 if aux_sec == 2
			bys id_year: egen mean_sector_year = mean(aux_sec)
				// mean_sector = .5 (0,1 -> missing, formal)
				//				  1 (1,1 -> formal, formal)
				//				  2 (4,0 -> informal, mising)
				//				  2.5 (1,4 -> formal, informal)
				//				  4 (4,4 -> informal, informal)
			label var mean_sector_year "0.5 (.,F); 1 (F,F); 2 (I,.); 2.5 (F,I); 4 (I,I)"
			replace aux_sec = 2 if aux_sec == 4

		*** Create season group variable: indicator in id-year level of observation structure
			sort id_year quarter
			by id_year: gen first_quarter = quarter[1]
			by id_year: gen second_quarter = quarter[2]
			gen season_group = 0
			replace season_group = 1 if first_quarter == 1 & second_quarter == 2
			replace season_group = 2 if first_quarter == 2 & second_quarter == 3
			replace season_group = 3 if first_quarter == 3 & second_quarter == 4
			replace season_group = 4 if first_quarter == 2 & second_quarter == 4
			replace season_group = 5 if first_quarter == 1 & second_quarter == 4
			replace season_group = 6 if first_quarter == 1 & second_quarter == .
			replace season_group = 7 if first_quarter == 2 & second_quarter == .
			replace season_group = 8 if first_quarter == 3 & second_quarter == .
			replace season_group = 9 if first_quarter == 4 & second_quarter == .
			label var season_group "1 q1,q2; 2 q2,q3; 3 q3,q4; 4 q2,q4; 5 q1,q4; 6 q1,.; 7 q2,.; 8 q3,.; 9 q4,."
			// season group >6 only appeared once in a quarter

		*** Transform earnings in real terms
			merge m:1 year quarter using "${DTA_DIR}/arg_cpi_quarterly.dta", keep(master match) keepusing(cpi_q) nogen
			sum cpi_q if year == ${year_min}
			local cpi_${year_min} = r(mean)
			replace cpi_q = cpi_q/`cpi_${year_min}'
			rename cpi_q cpi
			gen labor_income_r = labor_income/cpi
			label var labor_income_r "Labor income (real ${year_min} ARS)"
			drop cpi
			bys id_year: egen mean_earnings_r = mean(labor_income_r)

		*** Threshold
			** Merge dta with quarterly minimum wage value
			merge m:1 quarter year using "${DTA_DIR}/arg_min_wage_quarterly.dta", keep(master match) nogen
			rename min_wage_q mw
			gen labor_income_mw = labor_income/mw
			gen annual_mw = .

			** Find mean & annual wage in terms of mw
			bys id_year: egen mean_earnings_mw = mean(labor_income_mw)
			replace annual_mw = mean_earnings_mw*working_quarters*3*2 if nobs_year == 2
			replace annual_mw = labor_income_mw*12 if nobs_year == 1

			if $lower_thresh == 0 {
				drop if mean_income_mw < ${min_wage_mult}
			}
			if $lower_thresh == 1 {
				merge m:1 quarter year using "${DTA_DIR}/arg_thresh_quarterly.dta", keep(master match) nogen
				drop date date_q
				gen labor_income_mw_thres = labor_income_r/thresh_q
				drop thresh_q
				bys id_year: egen mean_income_mw_thres = mean(labor_income_mw_thres)
				drop labor_income_mw_thres
				drop if mean_income_mw_thres < ${thresh_mult}
				drop mean_income_mw_thres
			}

			drop id
			rename id_3 id
			drop nobs_3
			bys id: gen nobs_3 = _N
			drop nobs_year
			bys id_year: gen nobs_year = _N
			tab nobs_3 nobs_year
			drop if nobs_3 == 1
			drop if nobs_3 == 2 & nobs_year == 2
			gen aux = 1 if nobs_year == 1 & nobs_3 == 4
			bys id: egen mean_aux = mean(aux)
			drop if mean_aux == 1
			drop aux

		*** Number of observations
			///preserve
			///bys season_group year: gen nobs_year_season = _N
			///collapse (mean) nobs_year_season, by (season_group year)
			///sort year season_group
			///reshape wide nobs_year_season, i(year) j(season_group)
			///save "${FINAL_DIR}/obs/L2_season_nobs.dta", replace
			///restore

		*** Create sector variable
			// Formal -> Formal
			// Informal -> Informal
			// Formal -> Informal
			// Informal -> Formal
			gen sec = 0
			sort id year quarter
			by id: gen first_mean_sec = mean_sector_year[1]
			by id: gen second_mean_sec_aux = mean_sector_year[2] if nobs_year == 1
			by id: gen second_mean_sec_aux2 = mean_sector_year[3] if nobs_year == 2
			gen second_mean_sec = second_mean_sec_aux if nobs_year == 1
			replace second_mean_sec = second_mean_sec_aux2 if nobs_year == 2
			drop second_mean_sec_aux second_mean_sec_aux2
			replace sec = 1 if (first_mean_sec == 0.5 | first_mean_sec == 1) & (second_mean_sec == 0.5 | second_mean_sec == 1) // transition formal-formal
			replace sec = 2 if (first_mean_sec == 2 | first_mean_sec == 4) & (second_mean_sec == 2 | second_mean_sec == 4) // transition informal-informal
			replace sec = 5 if (first_mean_sec == 0.5 | first_mean_sec == 1) & (second_mean_sec == 2 | second_mean_sec == 4) // transition formal-informal
			replace sec = 6 if (first_mean_sec == 2 | first_mean_sec == 4) & (second_mean_sec == 0.5 | second_mean_sec == 1) // transition informal-formal

		*** Find annual earnings
			sort id_year
			gen annual_earnings = .
			replace annual_earnings = mean_earnings_r*working_quarters*3*2 if nobs_year == 2
			replace annual_earnings = labor_income_r*12 if nobs_year == 1

		*** Collapse by id & year
			collapse (mean) age gender labor_income annual_earnings working_quarters formal_quarters informal_quarters sec season_group weight, by(id year)

		*** Find residuals earnings, regressions run separated by gender & year
			gen ln_annual_earnings = log(annual_earnings)
			replace age = round(age)
			gen researn = .

				qui foreach yr of numlist $year_min(1)$year_max {
					reg ln_annual_earnings i.season_group i.age if gender == 1 & year == `yr' [aw=weight]
					predict temp_m if e(sample)== 1, residuals
					reg ln_annual_earnings i.season_group i.age if gender == 0 & year == `yr' [aw=weight]
					predict temp_f if e(sample)== 1, residuals
					replace researn = temp_m if year == `yr' & gender == 1
					replace researn = temp_f if year == `yr' & gender == 0
					drop temp*
				}
			*

		*** Find residuals 1-year delta
			sort id year
			by id: gen L_researn_1y = researn[_n+1] - researn[_n]
			drop if L_researn_1y == .
			drop researn

		*** Find stats for 1-y residuals earnings change
			gen data = 1
			rename L_researn_1y L_researn_1y_m2
			mystats "L_researn_1y_m2"

		*** Density figures
			if $kdensity_figs == 1 {
				local year_max_m3 = ${year_max} - 3
				local year_max_m1 = ${year_max} - 1
				kdensity_fig_2 "L_researn_1y_m2" ${year_min} "{&Delta}{sup:1}{&epsilon}{sub:it}" `year_max_m3'
				kdensity_fig_2 "L_researn_1y_m2" ${year_min} "{&Delta}{sup:1}{&epsilon}{sub:it}" `year_max_m1'
			}

		*** By sector analysis ***
		*** Find stats for earnings by sector
			drop if sec == 0 // drop switchers -- XXX MAY WANT TO RELAX THIS IN FUTURE ITERATION!
			rename L_researn_1y_m2 L_researn_1y_sec_m2
			drop data
			gen data = 2
			mystats "L_researn_1y_sec_m2"

		*** Density figures by sector
			if $kdensity_figs == 1 {
				local year_max_m1 = ${year_max} - 1
				L_kdensity_sec_fig "L_researn_1y_sec_m2" ${year_min}
				L_kdensity_sec_fig "L_researn_1y_sec_m2" `year_max_m1'
				L_kdensity_sec_fig_2 "L_researn_1y_sec_m2" ${year_min} `year_max_m1'
			}
		}
}
*
