********************************************************************************
* DESCRIPTION: Produces descriptive statistics for cross-sectional (CS) and longitudinal (L) data.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************


*************************************************
******** Data comparison ************************
*************************************************

* check / create directory
foreach folder in ///
	"descriptive_stats" {
	if $dir_delete {
		!rm -r "${FIG_DIR}/`folder'"
	}
	cap confirm file "${FIG_DIR}/`folder'/"
	if _rc mkdir "${FIG_DIR}/`folder'/" // if folder does not exist
}

* load data
use "${DTA_DIR}/eph_cleaned.dta", clear

* format data
rename workerid id
label var id "household ID"
label var period "Period (year-quarter combination)"
gen int year = year(dofq(period))
label var year "Year"
gen byte quarter = quarter(dofq(period))
label var quarter "Quarter"
label define qtr_l 1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4", replace
label val quarter qtr_l
label var gender "Ind: Male?"
label define gdr_l 0 "Female" 1 "Male" 2 "Pooled", replace
label val gender gdr_l
label var age "Age"
label var formal "Ind: formal job?"
label define frm_l 0 "Informal (incl. bus owners & self-emp)" 1 "Formal", replace
label val formal frm_l
rename type_job job
label var job "Type of job"
label define job_l 1 "Business owner" 2 "Self-employed" 3 "Employee", replace
label val job job_l
rename public_private public
label var public "Ind: public sector?"
label define pbl_l 0 "Private" 1 "Public", replace
label val public pbl_l
rename labor_income inc_n
label var inc_n "Labor income (current ARS)"
label var weight "Survey weight"
order id period year gender age formal job public inc_n weight

* merge in quarterly CPI data
merge m:1 year quarter using "${DTA_DIR}/arg_cpi_quarterly.dta", keep(master match) keepusing(cpi_q) nogen
sum cpi_q if year == ${year_min}
local cpi_${year_min} = r(mean)
replace cpi_q = cpi_q/`cpi_${year_min}'
rename cpi_q cpi

// * merge in annual CPI data
// merge m:1 year using "${DTA_DIR}/_original/cpis.dta", keep(master match) keepusing(cpi) nogen

* generate real income
gen float inc_r = inc_n/cpi
label var inc_r "Labor income (${year_min}Q1 ARS)"

* generate log real income
gen float inc_lnr = ln(inc_r)
label var inc_lnr "Labor income (log ${year_min}Q1 ARS)"

* create top income quantile by period
if $gtools == 1 gquantiles inc_lnr_q=inc_lnr, pctile p(${inc_q_wins}) by(period) strict
else {
	bys period: egen N_nonmiss_per_period = total(inc_lnr < .)
	bys period (inc_lnr): gen float inc_lnr_q = inc_lnr if _n/N_nonmiss_per_period > ${inc_q_wins}/100
	drop N_nonmiss_per_period
}
bys period (inc_lnr_q): replace inc_lnr_q = inc_lnr_q[1]

* winsorize top incomes
replace inc_lnr = inc_lnr_q if inc_lnr > inc_lnr_q & inc_lnr < .
drop inc_lnr_q

* merge in quarterly minimum wage data
merge m:1 year quarter using "${DTA_DIR}/arg_min_wage_quarterly.dta", keep(master match) keepusing(min_wage_q) nogen
rename min_wage_q min_wage

* merge in quarterly income threshold data
merge m:1 year quarter using "${DTA_DIR}/arg_thresh_quarterly.dta", keep(master match) keepusing(thresh_q) nogen
rename thresh_q thresh

* summarize observations violating selection criteria
if $lower_thresh == 0 {
	gen byte ind_below_mw = (inc_n < ${min_wage_mult}*min_wage)				if 										  inc_r > 0	& inc_r < .	& inrange(age, ${age_min}, ${age_max})	& inrange(gender, ${gender_min}, ${gender_max})	& inrange(formal, ${formal_min}, ${formal_max})	& inrange(job, ${job_min}, ${job_max})	& inrange(public, ${public_min}, ${public_max})
}
else if $lower_thresh == 1 {
	gen byte ind_below_thresh = (inc_r < ${thresh_mult}*thresh)				if 										  inc_r > 0	& inc_r < .	& inrange(age, ${age_min}, ${age_max})	& inrange(gender, ${gender_min}, ${gender_max})	& inrange(formal, ${formal_min}, ${formal_max})	& inrange(job, ${job_min}, ${job_max})	& inrange(public, ${public_min}, ${public_max})
}
gen byte ind_zero_inc = (inc_r <= 0) 										if inc_n >= ${min_wage_mult}*min_wage 				& inc_r < .	& inrange(age, ${age_min}, ${age_max})	& inrange(gender, ${gender_min}, ${gender_max})	& inrange(formal, ${formal_min}, ${formal_max}) & inrange(job, ${job_min}, ${job_max})	& inrange(public, ${public_min}, ${public_max})
gen byte ind_miss_inc = (inc_r == .) 										if inc_n >= ${min_wage_mult}*min_wage 	& inc_r > 0 			& inrange(age, ${age_min}, ${age_max})	& inrange(gender, ${gender_min}, ${gender_max})	& inrange(formal, ${formal_min}, ${formal_max}) & inrange(job, ${job_min}, ${job_max}) 	& inrange(public, ${public_min}, ${public_max})
gen byte ind_non_prime = (!inrange(age, ${age_min}, ${age_max})) 			if inc_n >= ${min_wage_mult}*min_wage	& inc_r > 0 & inc_r < . 										& inrange(gender, ${gender_min}, ${gender_max})	& inrange(formal, ${formal_min}, ${formal_max}) & inrange(job, ${job_min}, ${job_max}) 	& inrange(public, ${public_min}, ${public_max})
gen byte ind_informal = (!inrange(formal, ${formal_min}, ${formal_max}))	if inc_n >= ${min_wage_mult}*min_wage	& inc_r > 0 & inc_r < . & inrange(age, ${age_min}, ${age_max}) 	& inrange(gender, ${gender_min}, ${gender_max})													& inrange(job, ${job_min}, ${job_max}) 	& inrange(public, ${public_min}, ${public_max})
gen byte ind_not_empl = (!inrange(job, ${job_min}, ${job_max})) 			if inc_n >= ${min_wage_mult}*min_wage	& inc_r > 0 & inc_r < . & inrange(age, ${age_min}, ${age_max}) 	& inrange(gender, ${gender_min}, ${gender_max})	& inrange(formal, ${formal_min}, ${formal_max}) 										& inrange(public, ${public_min}, ${public_max})
gen byte ind_public = (!inrange(public, ${public_min}, ${public_max}))		if inc_n >= ${min_wage_mult}*min_wage	& inc_r > 0 & inc_r < . & inrange(age, ${age_min}, ${age_max}) 	& inrange(gender, ${gender_min}, ${gender_max})	& inrange(formal, ${formal_min}, ${formal_max}) & inrange(job, ${job_min}, ${job_max})
foreach var of varlist ind_* {
	tab year, sum(`var')
}
drop ind_*

* impose sample selection criteria
if $lower_thresh == 0 local inc_crit = "inc_n >= ${min_wage_mult}*min_wage"
else if $lower_thresh == 1 local inc_crit = "inc_r >= ${thresh_mult}*thresh"
keep if ///
	  `inc_crit' ///
	& inc_r > 0 ///
	& inc_r < . ///
	& inrange(gender, ${gender_min}, ${gender_max}) ///
	& inrange(age, ${age_min}, ${age_max}) /// & inrange(formal, ${formal_min}, ${formal_max}) ///
	& inrange(job, ${job_min}, ${job_max}) ///
	& inrange(public, ${public_min}, ${public_max}) ///
	& inrange(year, ${year_min}, ${year_max})

* generate expanded gender variable
expand 2, generate(dupl)
clonevar gender_pooled = gender
label var gender_pooled "Gender (pooled)"
replace gender_pooled = 2 if dupl == 1
drop dupl

* compute formality shares
if $gtools gcollapse (mean) formal_share=formal [fw=weight], by(period gender_pooled) fast
else collapse (mean) formal_share=formal [fw=weight], by(period gender_pooled) fast
label var formal_share "Share in formal employment"
format %3.2f formal_share
gen float formal_share_perc = formal_share*100
label var formal_share_perc "Share in formal employment (%)"
format %3.0f formal_share_perc

* fill in missing dates in quarterly format
sum period, meanonly
local period_min = r(min)
local period_max = r(max)
forval p = `period_min'/`period_max' {
	qui count if period == `p'
	if r(N) == 0 {
		qui count
		set obs `= r(N) + 1'
		replace period = `p' if _n == _N
	}
}
replace gender_pooled = 2 if gender_pooled == .

* merge in recession dates
rename period date_yq
merge m:1 date_yq using "${MAIN_DIR}/InputData/recession_dates_quarterly.dta", nogen keep(master match)
rename date_yq period

* plot
gen int year = year(dofq(period))
label var year "Year"
gen byte quarter = quarter(dofq(period))
label var quarter "Quarter"
gen float year_quarter = year + (quarter - 1)/4
sort period
forval g = 0/2 {
	count if gender_pooled == `g'
	assert r(N) > 0
}
global year_min_plot = ${year_min}
global year_max_plot = ${year_max}
graph set eps fontface Arial
save "${MACRO_DIR}/formal_share.dta", replace
tw ///
	(bar rece period if gender_pooled == 2 & inrange(year, ${year_min_plot}, ${year_max_plot}), yaxis(1) ylabel(,nogrid axis(1)) color(gs14) lwidth(thick) yscale(off)) ///
	(connected formal_share_perc period if gender_pooled == 2 & inrange(year, ${year_min_plot}, ${year_max_plot}), yaxis(2) ylabel(,grid axis(2)) yscale(alt axis(2)) msymbol(o) msize(medium) lwidth(thin)lcolor(maroon) mcolor(maroon)) ///
	, title("") xtitle("Quarter") ytitle("% of Formal Jobs", axis(2)) legend(off) xlabel(, grid gmin gmax) ylabel(56(2)72, grid axis(2)) graphregion(color(white)) ///
	name(formal_share, replace)
graph export "${FIG_DIR}/descriptive_stats/formal_share.eps", replace
graph export "${MACRO_DIR}/formal_share.pdf", replace
tw ///
	(connected formal_share year_quarter if gender_pooled == 2 & inrange(year, ${year_min_plot}, ${year_max_plot}), lcolor(blue) mcolor(blue) msymbol(O) msize(medium) lwidth(medthick) lpattern(solid)) ///
	(connected formal_share year_quarter if gender_pooled == 1 & inrange(year, ${year_min_plot}, ${year_max_plot}), lcolor(red) mcolor(red) msymbol(D) msize(medium) lwidth(medthick) lpattern(longdash)) ///
	(connected formal_share year_quarter if gender_pooled == 0 & inrange(year, ${year_min_plot}, ${year_max_plot}), lcolor(green) mcolor(green) msymbol(T) msize(medium) lwidth(medthick) lpattern(dash)) ///
	, title("") legend(order(1 "Pooled" 2 "Male" 3 "Female") cols(3) region(lcolor(white))) xtitle("") ytitle("Share of all jobs that are formal") xlabel(${year_min_plot}(2)${year_max_plot}, grid gstyle(dot) gmin gmax) ylabel(.45(.05).8, grid gstyle(dot) gmin gmax) graphregion(color(white)) plotregion(lcolor(black) margin(l=0 r=0 b=0 t=0)) ///
	name(formal_share_by_gender, replace)
graph export "${FIG_DIR}/descriptive_stats/formal_share_by_gender.eps", replace
