********************************************************************************
* DESCRIPTION: Applies similar data filters to the household survey in Argentina.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

clear all
set more off

********************
* SET PATHS
global pathinit "XXXX"
global data "$pathinit/Data"
global log "$pathinit/Log"

capture log close
log using "$log/CleaningCode_GID_log.txt", replace text

/*---------------------------------*/
/*                                 */
/* Merge EPH BUA y CONTINUA        */
/*                                 */
/*---------------------------------*/

use "$data/eph_bua.dta", clear
replace onda = 2 if onda == 1
replace onda = 4 if onda == 3
gen source = "eph_bua"

append using "$data/eph_cont.dta", force
replace source = "eph_cont" if source == ""
rename onda quarter
rename ano year

* Drop small cities that were added over time
drop if aglomerado == 38 | aglomerado == 91 | aglomerado == 93

* Keep workers that are employed, unemployed, or out of labor force
keep if inrange(estado_actividad,1,3)

* Define additional variables
gen emp               = (estado_actividad == 1 & plan_empleo == 0)
gen unemp             = (estado_actividad == 2 | plan_empleo == 1)
gen nonpart           = (estado_actividad == 3)

* Define type of job
gen type_job     = 1 if emp == 1 & categocup == 1
replace type_job = 2 if emp == 1 & categocup == 2
replace type_job = 3 if emp == 1 & categocup == 3

label variable type_job "Type of job"
label define type_job 1 "Business owner/Boss" 2 "Self-employed" 3 "Employee"
label values type_job type_job

* Define employees by formality status
gen formal_salaried   = 1 if emp == 1 & categocup == 3 & aportesjubilatorios == 1
gen informal_salaried = 1 if emp == 1 & categocup == 3 & aportesjubilatorios == 0

* Define variable for public/private employment
gen public_private     = 1 if tipo_establecimiento_ocup == 1
replace public_private = 0 if tipo_establecimiento_ocup == 2

label define public_private 0 "Private" 1 "Public"
label values public_private public_private

* Define sample
keep if inrange(year,1996,2017) /* Sample period */
keep if inrange(edad,25,55) /* Age restriction */
keep if formal_salaried == 1 | informal_salaried == 1 | inrange(type_job,1,3) /* Salaried informal/formal workers, self-employed, business owners */
keep if inrange(public_private,0,1) /* Employed in the private or public sector */

* Define panel
replace nro_hogar = 1 if nro_hogar == .
egen hhid         = group(aglomerado codusu nro_hogar)
egen workerid     = group(hhid componente)
gen period        = yq(year,quarter)
format period %tq
move workerid codusu
move period codusu
drop if workerid == .
bysort workerid: egen minper = min(period)
bysort workerid: egen maxper = max(period)
gen difper = maxper-minper
drop if difper > 8 /* very few individuals show up more than 8 periods apart */
drop difper
xtset workerid period

* Data cleaning
unique hombre, by(workerid) generate(aux)
bysort workerid: egen unique_gender = max(aux)
keep if unique_gender == 1
drop aux unique_gender

* Drop invalid income observations
replace ingreso_ocup_prin = . if ingreso_ocup_prin == 9 & source == "eph_bua"
replace ingreso_ocup_prin = . if ingreso_ocup_prin == -9 & source == "eph_cont"

* Rename and keep variables
rename edad age
rename hombre gender
rename ingreso_ocup_prin labor_income
label variable labor_income "Monthly nominal labor income in main occupation"
rename aportesjubilatorios formal
rename pondera weight

keep workerid age gender labor_income formal period weight type_job public_private

save "$data/eph_cleaned.dta", replace

capture log close
