********************************************************************************
* DESCRIPTION: Merges and Cleans household survey in Argentina.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************


*****************************************
*****************************************
* DATA CLEANING: EPH
*****************************************
*****************************************

clear all
capture clear matrix

set more off

*Add New sections

global add_new = 0

global pathinit "XXXX"
global data "$pathinit/Data_Cleaning/Input/"
global temp "$pathinit/Data_Cleaning/Temp"
global results "$pathinit/Data_Cleaning/Output"

capture log close _all
log using "$temp/CleaningEPH.txt", replace text

/*--------------------------*/
/*                          */
/* EPH CONTINUA: 2003-2018  */
/*                          */
/*--------------------------*/

* Clean EPH continua
cd "$data/EPH/2003_2011_EPH_Continua/Datos"

if $add_new == 1{

    forvalues y = 16/18{

        forvalues t = 1/4{

            if "`t'`y'" != "116" & "`t'`y'" != "318" & "`t'`y'" != "418"{

                import delimited "usu_individual_t`t'`y'.txt", delimiter(";") clear

                gen CODUSU = substr(codusu, -8,.)
                drop codusu

                gen aux = date(ch05, "DMY")
                drop ch05
                rename aux ch05

                rename pp04b_cod pp04b_caes

                tostring pp04b_caes, replace

                save "eph_`t'`y'.dta", replace

            }
        }
    }
clear
}


forvalues y = 3/15{

    local y_alt = "`y'"
    if `y' < 10 local y_alt = "0`y'"

    forvalues t = 1/4{

        if "`t'`y_alt'" != "103" & "`t'`y_alt'" != "203" & "`t'`y_alt'" != "307" & "`t'`y_alt'" != "315" & "`t'`y_alt'" != "415"{

            append using "t`t'`y_alt'_dta/Individual_t`t'`y_alt'.dta"
        }


    }
}
forvalues y = 16/18{

    forvalues t = 1/4{

        if "`t'`y'" != "116" & "`t'`y'" != "318" & "`t'`y'" != "418"{

            append using "eph_`t'`y'.dta", force
        }
    }
}

* Standardize variables

* Survey
rename ano4 ano
rename trimestre onda
rename h15 realizada
rename CODUSU codusu

* Demographics
recode ch03 (1 = 1 "Jefe/a") (2 = 2 "Conyuge/Pareja") (3 = 3 "Hijo/Hijastro") (4 = 4 "Yerno/Nuera") (5 = 5 "Nieto/a") (6 7 = 6 "Madre/Padre o Suegro/a") (8 = 8 "Hermano/a") (9 = 9 "Otros familiares") (10 = 10 "No familiares")  (12 = -1 "Ns./Nr."), gen (parentesco) label(newparentesco)
label var parentesco "Relacion de parentesco"

rename ch07 estado_civil
label var estado_civil "Estado Civil"

recode ch04 (1 = 1 "Varon") (2 = 0 "Mujer"), gen(hombre) label(hombre)
recode ch06 (-1 = -1 "Menos de 1 a�o") (98 = 98 "98 y mas") (99 = -2 "Ns./Nr.") , gen(edad) label(edad)
rename nivel_ed edulevel

recode ch15 (1 = 1 "En esta localidad") (2 = 2 "En otra localidad de esta provincia") (3 = 3 "En otra provincia") (4  5 = 4 "En otro pais") (0 9 = 9 "Ns./Nr."), gen(lugarnac) label(lugarnac)
label var lugarnac "Lugar de Nacimiento"

* Labor Market Status
recode estado (0 = 0 "Entrevista individual no realizada") (1 = 1 "Ocupado") (2 = 2 "Desocupado") (3 = 3 "Inactivo") (4 = 4 "Menor de 10 a�os"), gen (estado_actividad) label(estado_actividad)
recode cat_ocup (1 = 1 "Patron") (2 = 2 "Cuenta Propia") (3 = 3 "Obrero o empleado") (4 = 4 "Trabajador familiar sin remuneracion") (9 = 9 "Ns./Nr."), gen(categocup) label(categocup)
label var categocup "Categoria ocupacional (para ocupados y desocupados con ocupacion anterior)"
drop cat_ocup
rename cat_inac categinact

gen plan_empleo = (pp07e==1)
label var plan_empleo "Es un ocupado con plan de empleo"

* Characteristics of Employed Workers

recode pp3e_tot (999 = -1 "Ns./Nr."), gen(horas_ocup_prin) label(horas_ocup_prin)
label var horas_ocup_prin "Horas trabajadas en la ocupacion principal en la semana de referencia"
recode pp3f_tot (999 = -1 "Ns./Nr."), gen(horas_otras_ocup) label(horas_otras_ocup)
label var horas_otras_ocup "Horas trabajadas en otras ocupaciones en la semana de referencia"

recode pp07a (1 = 1 "Menos de 1 mes") (2 = 2 "1 a 3 meses") (3 = 3 "Mas de 3 a 6 meses") (4 = 4 "Mas de 6 a 12 meses") (5 = 5 " Mas de 1 a 5 anios") (6 = 6 "Mas de 5 anios") (9 = 9 "Ns./Nr."), gen(tenure_ocup_prin) label(tenure_ocup_prin)
label var tenure_ocup_prin "Tenure en ocupacion principal"

recode pp03c (1 = 1 "...un solo empleo/ocupacion/actividad?") (2 = 2 "...mas de un empleo/ocupacion/actividad?") (3 = 0) (9 = 9 "Ns./Nr."), gen(numero_ocupaciones) label(numero_ocupaciones)
label var numero_ocupaciones "Numero de ocupaciones que el ocupado tuvo en la semana de referencia"

recode pp04a (1 = 1 "Publico") (2 = 2 "Privado") (3 = 3 "Otro") (9 = 9 "Ns./Nr."), gen(tipo_establecimiento_ocup) label(tipo_establecimiento_ocup)
label var tipo_establecimiento_ocup "Tipo de establecimiento del ocupado (ocup. prin.)"

gen serviciodomestico = 1 if pp04b1 == 1
label var serviciodomestico "Individuo prestar servicio domestico en hogares particulares (ocup. prin.)"

recode pp04c (1 = 1 "1 persona") (2/5 = 2 "de 2 a 5 personas") (6 7 = 3 "de 6 a 25 personas") (8 9 = 4 "de 26 a 100 personas") (10 11 = 5 "de 101 a 500 personas") (12 = 6 "mas de 500 personas") (99 = 9 "Ns./Nr."), gen (tamano_establecimiento) label(tamano_establecimiento)
label var tamano_establecimiento "Cuantas personas trabajan en el establecimiento (ocup. prin.)"

rename pp04d_cod cod_ocupacion_prin_ocup

gen aportesjubilatorios = (pp07h == 1 | pp07i == 1)
label var aportesjubilatorios "El trabajador asalariado recibe descuento jubilatorio o aporta a un sistema jubilatorio (ocup. prin.)"

gen aux1 = substr(pp04b_cod,1,2)
destring(aux1), gen(aux2)
replace aux2 = 9999 if pp04b_cod == "9999" | pp04b_cod == "9999 "
recode aux2 (9999 = -1 "Ns./Nr."), gen(industria_ocup_prin_cod) label(industria_ocup_prin_cod)
drop aux*

label var industria_ocup_prin_cod "Industria Ocupados - CIIU Rev 3 a 2 digitos"

replace pp04b_caes = "10" if pp04b_caes == "C   "
replace pp04b_caes = "" if pp04b_caes == "Z   "
gen aux1 = substr(pp04b_caes,1,2)
destring(aux1), gen(aux2)
replace aux2 = 9999 if pp04b_caes == "9999" | pp04b_caes == "9999 "
recode aux2 (9999 = -1 "Ns./Nr."), gen(industria_ocup_prin_caes) label(industria_ocup_prin_caes)
drop aux*

label var industria_ocup_prin_caes "Industria Ocupados - CIIU Rev 3 a 2 digitos"


* Characteristics of Unemployed Workers

gen aux1 = substr(pp11b_cod,1,2)
destring(aux1), gen(aux2)
replace aux2 = 9999 if pp11b_cod == "9999" | pp11b_cod == "9999 "
recode aux2 (9999 = -1 "Ns./Nr."), gen(desoc_industria_prin_cod) label(desoc_industria_prin_cod)
drop aux*
label var desoc_industria_prin_cod "Desocupados: Industria de la ultima ocupaciontab - CIIU Rev 3 a 2 digitos"

rename pp11d_cod cod_ocupacion_prin_desocup_cod

replace pp11b_caes = "" if pp11b_caes == "V   "
replace pp11b_caes = "" if pp11b_caes == "Z   "
gen aux1 = substr(pp11b_caes,1,2)
destring(aux1), gen(aux2)
replace aux2 = 9999 if pp11b_caes == "9999" | pp11b_caes == "9999 "
recode aux2 (9999 = -1 "Ns./Nr."), gen(desoc_industria_prin_caes) label(desoc_industria_prin_caes)
drop aux*
label var desoc_industria_prin_caes "Desocupados: Industria de la ultima ocupaciontab - CIIU Rev 3 a 2 digitos"

recode pp11a (1 = 1 "Publico") (2 = 2 "Privado") (3 = 3 "Otro") (9 = 9 "Ns./Nr."), gen(desocup_tipo_establecimiento) label(desocup_tipo_establecimiento)
label var desocup_tipo_establecimiento "Desocupados: tipo de establecimiento en la ultima ocupacion"

recode pp10a (1 = 1 "Menos de 1 mes") (2 = 2 "1 a 3 meses") (3 = 3 "Mas de 3 a 6 meses") (4 = 4 "Mas de 6 a 12 meses") (5 = 5 " Mas de 1 anio") (9 = 9 "Ns./Nr."), gen(desoc_durationunemployed) label(desoc_durationunemployed)
label var desoc_durationunemployed "Periodo de Desempleo"

gen desoc_aportesjubilatorios = (pp11n == 1) if pp11n == 1 | pp11n == 2 | pp11n == 9
label var desoc_aportesjubilatorios "Desocupados: en la ultima ocupacion le hacian descuento jubilatorio"

gen desoc_plan_empleo = (pp11m==1) if pp11m == 1 | pp11m == 2 | pp11m == 3 | pp11m == 9
label var desoc_plan_empleo "Desocupados: la ultima ocupacion era un plan de empleo"

gen desoc_tuvoocupant = pp10d
label var desoc_tuvoocupant "Desocupados: el desocupado tuvo empleo anterior"

* Income of Employers (independientes, patron, empleado)
rename itf ingreso_tot_fam
rename ipcf ingreso_percapita_fam
rename p47t ingreso_tot_indiv
generate ingreso_horario_ocup_prin = p21/(pp3e_tot*4)
replace ingreso_horario_ocup_prin = . if pp3e_tot == 999
label var ingreso_horario_ocup_prin "Ingreso horario de la ocupacion principal"
rename p21 ingreso_ocup_prin /* gen p21 = pp06c + pp06d + pp08d1 + pp08f1 +  pp08f2 */

* Create a variable indicating industry for employed/unemployed
* 1- Agricultura, caza, silvicultura y pesca
* 2- Explotacion de minas y canteras
* 3- Industrias manufactureras
* 4- Electricidad, gas y agua
* 5- Construccion
* 6- Comercio al por mayor y al por menor, restaurantes y hoteles
* 7- Transporte, almacenaje y comunicaciones
* 8- Establecimientos financieros, seguros, bienes inmuebles y servicios
*    prestados a las empresas
* 9- Servicios comunales, sociales y personales
* 0- Actividades no bien especificadas y desconocidas

gen industry = .
* Employed
replace industry = 1 if industry == . & inrange(industria_ocup_prin_cod,1,5) & industria_ocup_prin_cod != . & ano <= 2011
replace industry = 1 if industry == . & inrange(industria_ocup_prin_caes,1,3) & industria_ocup_prin_caes != . & ano > 2011

replace industry = 2 if industry == . & inrange(industria_ocup_prin_cod,10,14) & industria_ocup_prin_cod != . & ano <= 2011
replace industry = 2 if industry == . & inrange(industria_ocup_prin_caes,5,9) & industria_ocup_prin_caes != . & ano > 2011

replace industry = 3 if industry == . & inrange(industria_ocup_prin_cod,15,37) & industria_ocup_prin_cod != . & ano <= 2011
replace industry = 3 if industry == . & inrange(industria_ocup_prin_caes,10,33) & industria_ocup_prin_caes != . & ano > 2011
replace industry = 3 if industry == . & inrange(industria_ocup_prin_caes,58,59) & industria_ocup_prin_caes != . & ano > 2011

replace industry = 4 if industry == . & inrange(industria_ocup_prin_cod,40,41) & industria_ocup_prin_cod != . & ano <= 2011
replace industry = 4 if industry == . & inrange(industria_ocup_prin_caes,35,39) & industria_ocup_prin_caes != . & ano > 2011

replace industry = 5 if industry == . & inrange(industria_ocup_prin_cod,45,45) & industria_ocup_prin_cod != . & ano <= 2011
replace industry = 5 if industry == . & inrange(industria_ocup_prin_caes,40,40) & industria_ocup_prin_caes != . & ano > 2011

replace industry = 6 if industry == . & inrange(industria_ocup_prin_cod,50,55) & industria_ocup_prin_cod != . & ano <= 2011
replace industry = 6 if industry == . & inrange(industria_ocup_prin_caes,45,48) & industria_ocup_prin_caes != . & ano > 2011
replace industry = 6 if industry == . & inrange(industria_ocup_prin_caes,55,56) & industria_ocup_prin_caes != . & ano > 2011

replace industry = 7 if industry == . & inrange(industria_ocup_prin_cod,60,64) & industria_ocup_prin_cod != . & ano <= 2011
replace industry = 7 if industry == . & inrange(industria_ocup_prin_caes,49,53) & industria_ocup_prin_caes != . & ano > 2011
replace industry = 7 if industry == . & inrange(industria_ocup_prin_caes,61,61) & industria_ocup_prin_caes != . & ano > 2011

replace industry = 8 if industry == . & inrange(industria_ocup_prin_cod,65,74) & industria_ocup_prin_cod != . & ano <= 2011
replace industry = 8 if industry == . & inrange(industria_ocup_prin_caes,62,63) & industria_ocup_prin_caes != . & ano > 2011
replace industry = 8 if industry == . & inrange(industria_ocup_prin_caes,64,82) & industria_ocup_prin_caes != . & ano > 2011

replace industry = 9 if industry == . & inrange(industria_ocup_prin_cod,75,99) & industria_ocup_prin_cod != . & ano <= 2011
replace industry = 9 if industry == . & inrange(industria_ocup_prin_caes,60,60) & industria_ocup_prin_caes != . & ano > 2011
replace industry = 9 if industry == . & inrange(industria_ocup_prin_caes,83,99) & industria_ocup_prin_caes != . & ano > 2011

replace industry = 0 if industry == . & inrange(industria_ocup_prin_cod,99,99) & industria_ocup_prin_cod != . & ano <= 2011

* Unemployed
replace industry = 1 if industry == . & inrange(desoc_industria_prin_cod,1,5) & desoc_industria_prin_cod != . & ano <= 2011
replace industry = 1 if industry == . & inrange(desoc_industria_prin_caes,1,3) & desoc_industria_prin_caes != . & ano > 2011

replace industry = 2 if industry == . & inrange(desoc_industria_prin_cod,10,14) & desoc_industria_prin_cod != . & ano <= 2011
replace industry = 2 if industry == . & inrange(desoc_industria_prin_caes,5,9) & desoc_industria_prin_caes != . & ano > 2011

replace industry = 3 if industry == . & inrange(desoc_industria_prin_cod,15,37) & desoc_industria_prin_cod != . & ano <= 2011
replace industry = 3 if industry == . & inrange(desoc_industria_prin_caes,10,33) & desoc_industria_prin_caes != . & ano > 2011
replace industry = 3 if industry == . & inrange(desoc_industria_prin_caes,58,59) & desoc_industria_prin_caes != . & ano > 2011

replace industry = 4 if industry == . & inrange(desoc_industria_prin_cod,40,41) & desoc_industria_prin_cod != . & ano <= 2011
replace industry = 4 if industry == . & inrange(desoc_industria_prin_caes,35,39) & desoc_industria_prin_caes != . & ano > 2011

replace industry = 5 if industry == . & inrange(desoc_industria_prin_cod,45,45) & desoc_industria_prin_cod != . & ano <= 2011
replace industry = 5 if industry == . & inrange(desoc_industria_prin_caes,40,40) & desoc_industria_prin_caes != . & ano > 2011

replace industry = 6 if industry == . & inrange(desoc_industria_prin_cod,50,55) & desoc_industria_prin_cod != . & ano <= 2011
replace industry = 6 if industry == . & inrange(desoc_industria_prin_caes,45,48) & desoc_industria_prin_caes != . & ano > 2011
replace industry = 6 if industry == . & inrange(desoc_industria_prin_caes,55,56) & desoc_industria_prin_caes != . & ano > 2011

replace industry = 7 if industry == . & inrange(desoc_industria_prin_cod,60,64) & desoc_industria_prin_cod != . & ano <= 2011
replace industry = 7 if industry == . & inrange(desoc_industria_prin_caes,49,53) & desoc_industria_prin_caes != . & ano > 2011
replace industry = 7 if industry == . & inrange(desoc_industria_prin_caes,61,61) & desoc_industria_prin_caes != . & ano > 2011

replace industry = 8 if industry == . & inrange(desoc_industria_prin_cod,65,74) & desoc_industria_prin_cod != . & ano <= 2011
replace industry = 8 if industry == . & inrange(desoc_industria_prin_caes,62,63) & desoc_industria_prin_caes != . & ano > 2011
replace industry = 8 if industry == . & inrange(desoc_industria_prin_caes,64,82) & desoc_industria_prin_caes != . & ano > 2011

replace industry = 9 if industry == . & inrange(desoc_industria_prin_cod,75,99) & desoc_industria_prin_cod != . & ano <= 2011
replace industry = 9 if industry == . & inrange(desoc_industria_prin_caes,60,60) & desoc_industria_prin_caes != . & ano > 2011
replace industry = 9 if industry == . & inrange(desoc_industria_prin_caes,83,99) & desoc_industria_prin_caes != . & ano > 2011

replace industry = 0 if industry == . & inrange(desoc_industria_prin_cod,99,99) & desoc_industria_prin_cod != . & ano <= 2011

replace industry = -1 if industry == . & inrange(industria_ocup_prin_cod,0,0) & industria_ocup_prin_cod != .
replace industry = -1 if industry == . & industria_ocup_prin_cod == -1
replace industry = -1 if industry == . & inrange(desoc_industria_prin_cod,0,0) & desoc_industria_prin_cod != .
replace industry = -1 if industry == . & desoc_industria_prin_cod == .

compress
save "$results/eph_cont.dta", replace

/*--------------------------*/
/*                          */
/* EPH BUA: 1995-2003       */
/*                          */
/*--------------------------*/

cd "$data/EPH/1995_2003_EPH_Base_Usuaria_Ampliada/Datos/EPHBUACompleta"

* Scan output directory and store a list of all directories containing "_dta"
! ls | grep Bua | grep -v .txt | grep -v .zip > dirlist.txt
cap file close dirlist
file open dirlist using dirlist.txt, read
file read dirlist line
while r(eof) == 0 {
    local dirname "`line'"
    cd "$data/EPH/1995_2003_EPH_Base_Usuaria_Ampliada/Datos/EPHBUACompleta/`dirname'"
    di "`line'" // Print what you just read in from the file
    import delimited "HOG_BUA.csv", encoding(ISO-8859-1) clear
    saveold HOG_BUA.dta, replace
    import delimited "PER_BUA.csv", encoding(ISO-8859-1) clear
    saveold PER_BUA.dta, replace
    file read dirlist line
}

cd "$data/EPH/1995_2003_EPH_Base_Usuaria_Ampliada/Datos/EPHBUACompleta"

* Clean some variables before merging all datasets
use Bua45100/PER_BUA.dta, clear
replace ano4 = 2000 if ano4 != 2000
saveold Bua45100/PER_BUA.dta, replace

use Bua45101/PER_BUA.dta, clear
replace ano4 = 2001 if ano4 != 2001
saveold Bua45101/PER_BUA.dta, replace

use Bua45198/PER_BUA.dta, clear
replace ano4 = 1998 if ano4 != 1998
saveold Bua45198/PER_BUA.dta, replace

use Bua45300/PER_BUA.dta, clear
replace ano4 = 2000 if ano4 != 2000
saveold Bua45300/PER_BUA.dta, replace

use Bua45301/PER_BUA.dta, clear
replace ano4 = 2001 if ano4 != 2001
saveold Bua45301/PER_BUA.dta, replace

use Bua45302/PER_BUA.dta, clear
replace ano4 = 2002 if ano4 != 2002
saveold Bua45302/PER_BUA.dta, replace

use Bua45398/PER_BUA.dta, clear
replace ano4 = 1998 if ano4 != 1998
saveold Bua45398/PER_BUA.dta, replace

use Bua45399/PER_BUA.dta, clear
replace ano4 = 1999 if ano4 != 1999
saveold Bua45399/PER_BUA.dta, replace

* Destring some variables before merging all datasets
use Bua45101/PER_BUA.dta, clear
tab p13aus
destring p13aus, replace
saveold Bua45101/PER_BUA.dta, replace

use Bua45102/PER_BUA.dta, clear
tab p13aus
destring p13aus, replace
saveold Bua45102/PER_BUA.dta, replace

use Bua45103/PER_BUA.dta, clear
tab p13aus
destring p13aus, replace
saveold Bua45103/PER_BUA.dta, replace

use Bua45301/PER_BUA.dta, clear
tab p13aus
destring p13aus, replace
saveold Bua45301/PER_BUA.dta, replace

use Bua45302/PER_BUA.dta, clear
tab p13aus
destring p13aus, replace
saveold Bua45302/PER_BUA.dta, replace

use Bua13195/PER_BUA.dta, clear
destring p56, replace force
saveold Bua13195/PER_BUA.dta, replace

use Bua29395/PER_BUA.dta, clear
destring p56, replace force
saveold Bua29395/PER_BUA.dta, replace

use Bua30195/PER_BUA.dta, clear
destring p20, replace force
destring p56, replace force
saveold Bua30195/PER_BUA.dta, replace

use Bua02195/PER_BUA.dta, clear
destring p56, replace force
saveold Bua02195/PER_BUA.dta, replace

use Bua30395/PER_BUA.dta, clear
destring p56, replace force
saveold Bua30395/PER_BUA.dta, replace

use Bua45101/PER_BUA.dta, clear
tostring imputa, replace
tostring areasnue, replace
saveold Bua45101/PER_BUA.dta, replace

use Bua45103/PER_BUA.dta, clear
tostring imputa, replace
saveold Bua45103/PER_BUA.dta, replace

use Bua45196/PER_BUA.dta, clear
tostring p57, replace
tostring imputa, replace
tostring areasnue, replace
saveold Bua45196/PER_BUA.dta, replace

use Bua45197/PER_BUA.dta, clear
tostring p57, replace
tostring imputa, replace
tostring areasnue, replace
destring p21, replace force
saveold Bua45197/PER_BUA.dta, replace

use Bua45198/PER_BUA.dta, clear
tostring areasnue, replace
saveold Bua45198/PER_BUA.dta, replace

use Bua45301/PER_BUA.dta, clear
tostring imputa, replace
tostring areasnue, replace
destring p15p, replace force
saveold Bua45301/PER_BUA.dta, replace

use Bua45302/PER_BUA.dta, clear
tostring imputa, replace
tostring areasnue, replace
destring p21, replace force
saveold Bua45302/PER_BUA.dta, replace

use Bua45396/PER_BUA.dta, clear
tostring p57, replace
tostring imputa, replace
tostring areasnue, replace
saveold Bua45396/PER_BUA.dta, replace

use Bua45397/PER_BUA.dta, clear
tostring p57, replace
tostring imputa, replace
tostring areasnue, replace
saveold Bua45397/PER_BUA.dta, replace

* Merge all datasets
use Bua01195/PER_BUA.dta, clear

* Scan output directory and store a list of all directories containing "_dta"
! ls | grep Bua | grep -v Bua01195 | grep -v .txt | grep -v .zip > dirlist.txt
cap file close dirlist
file open dirlist using dirlist.txt, read
file read dirlist line
while r(eof) == 0 {
    local dirname "`line'"
    cd "$data/EPH/1995_2003_EPH_Base_Usuaria_Ampliada/Datos/EPHBUACompleta/`dirname'"
    di "`line'" // Print what you just read in from the file
    append using PER_BUA.dta, force
    file read dirlist line
}

* Standardize variables

* Survey
replace ano = . if ano4 != .
replace ano4 = 1995 if ano == 95
drop ano
rename ano4 ano

replace agloreal = aglomerado if ano == 1995
drop aglomerado
rename agloreal aglomerado
rename h15 realizada

* Demographics
recode h08 (1 = 1 "Jefe/a") (2 = 2 "Conyuge/Pareja") (3 = 3 "Hijo/Hijastro") (4 = 4 "Yerno/Nuera") (5 = 8 "Hermano/a") (6 = 5 "Nieto/a") (8 = 6 "Madre/Padre o Suegro/a") (7 9 = 9 "Otros familiares") (10 11 = 10 "No familiares") (12 = -1 "Ns./Nr."), gen (parentesco) label(newparentesco)
label var parentesco "Relacion de parentesco"

recode h14 (2 = 1 "Unido") (3 = 2 "Casado") (4 = 3 "Separado o divorciado") (5 = 4 "Viudo") (1 = 5 "Soltero") (0 6 9 = 9 "Ns./Nr."), gen(estado_civil) label(estado_civil)
replace estado_civil = 9  if estado_civil == .
label var estado_civil "Estado Civil"

recode h13 (1 = 1 "Varon") (2 = 0 "Mujer"), gen(hombre) label(hombre)
recode h12 (0 = -1 "Menos de 1 a�o") (98 = 98 "98 y mas") (99 = -2 "Ns./Nr.") , gen(edad) label(edad)
gen fecha_nac = h11
replace edad = -2 if edad == .

gen edulevel = .
replace edulevel = 1 if (p56 == 1 & p58 == 2)
replace edulevel = 2 if (p56 == 1 & p58 == 1)
replace edulevel = 3 if (p56 >= 2 & p56 <= 6) & p58 == 2
replace edulevel = 4 if (p56 >= 2 & p56 <= 6) & p58 == 1
replace edulevel = 5 if (p56 == 7 | p56 == 8) & p58 == 2
replace edulevel = 6 if (p56 == 7 | p56 == 8) & p58 == 1
replace edulevel = 7 if p55 == 3
replace edulevel = 7 if p56 == . & inrange(edad,-1,6)
replace edulevel = 9 if edulevel == .
label define educ 1 "Primaria Incompleta (incluye educaci�n especial)" 2 "Primaria Completa" 3 "Secundaria Incompleta" 4 "Secundaria Completa" 5 "Superior Universitaria Incompleta" 6 "Superior Universitaria Completa" 7 "Sin instrucci�n" 9 "Ns./Nr."
label values edulevel educ

recode p59 (1 = 1 "En esta localidad") (2 = 2 "En otra localidad de esta provincia") (3 = 3 "En otra provincia") (4 = 4 "En otro pais") (0 9 = 9 "Ns./Nr."), gen(lugarnac) label(lugarnac)
replace lugarnac = 9 if lugarnac == .
label var lugarnac "Lugar de Nacimiento"

* Labor Market Status
recode estado (0 = 0 "Entrevista individual no realizada") (1 = 1 "Ocupado") (2 = 2 "Desocupado") (3 = 3 "Inactivo") (4 = 4 "Menor de 10 a�os"), gen (estado_actividad) label(estado_actividad)
replace estado_actividad = 4 if inrange(edad, -1,9)
replace estado_actividad = 0 if realizada != 1

egen cat_ocup = rowtotal(p17 p38)
recode cat_ocup (1 = 1 "Patron") (2 = 2 "Cuenta Propia") (3 = 3 "Obrero o empleado") (4 = 4 "Trabajador familiar sin remuneracion") (9 = 9 "Ns./Nr."), gen(categocup) label(categocup)
label var categocup "Categoria ocupacional (para ocupados y desocupados con ocupacion anterior)"
drop cat_ocup
recode p11 (1 = 1 "Jubilado/pensionado") (2 = 2 "Rentista") (3 = 3 "Estudiante") ( 4 = 4 "Ama de casa") (5 = 5 "Menor de 6 a�os") (6 = 6 "Discapacitado") (8 = 7 "Otros") (9 = 9 "Ns./Nr."), gen(categinact) label(categ_inact)

gen plan_empleo = (p18a == 1)
label var plan_empleo "Es un ocupado con plan de empleo"

* Characteristics of Employed Workers

recode p15p (999 999.9 = -1 "Ns./Nr."), gen(horas_ocup_prin) label(horas_ocup_prin)
label var horas_ocup_prin "Horas trabajadas en la ocupacion principal en la semana de referencia"
gen aux = p15s + p15o
replace aux = 999 if p15s == 999 | p15s == 999.9 | p15o == 999 | p15o == 999.9
recode aux (999 999.9 = -1 "Ns./Nr."), gen(horas_otras_ocup) label(horas_otras_ocup)
label var horas_otras_ocup "Horas trabajadas en otras ocupaciones en la semana de referencia"
drop aux

gen aux = p22*12 + p22m if p22 != 99 & p22 >= 0 & p22 != . & p22m != 99 & p22m >= 0 & p22m != .
gen aux2 = .
replace aux2 = 1 if aux == 1 & p22 != 99 & p22 >= 0 & p22 != . & p22m != 99 & p22m >= 0 & p22m != .
replace aux2 = 2 if aux > 1 & aux <= 3 & p22 != 99 & p22 >= 0 & p22 != . & p22m != 99 & p22m >= 0 & p22m != .
replace aux2 = 3 if aux > 3 & aux <= 6 & p22 != 99 & p22 >= 0 & p22 != . & p22m != 99 & p22m >= 0 & p22m != .
replace aux2 = 4 if aux > 6 & aux <= 12 & p22 != 99 & p22 >= 0 & p22 != . & p22m != 99 & p22m >= 0 & p22m != .
replace aux2 = 5 if aux > 12 & aux <= 60 & p22 != 99 & p22 >= 0 & p22 != . & p22m != 99 & p22m >= 0 & p22m != .
replace aux2 = 6 if aux > 60 & p22 != 99 & p22 >= 0 & p22 != . & p22m != 99 & p22m >= 0 & p22m != .
replace aux2 = 5 if p22 >=1 & p22 <= 5 & aux2 == .
replace aux2 = 6 if p22 > 5 & p22 != 99 & aux2 == .

recode aux2 (1 = 1 "Menos de 1 mes") (2 = 2 "1 a 3 meses") (3 = 3 "Mas de 3 a 6 meses") (4 = 4 "Mas de 6 a 12 meses") (5 = 5 " Mas de 1 a 5 anios") (6 = 6 "Mas de 5 anios") (9 = 9 "Ns./Nr."), gen(tenure_ocup_prin) label(tenure_ocup_prin)
label var tenure_ocup_prin "Tenure en ocupacion principal"
replace aux = p22*12 if p22 != 99 & p22 >= 0 & p22 !=. & aux == .
gen tenure_ocup_prin_detailed = aux
label var tenure_ocup_prin_detailed "Tenure (meses) en ocupacion principal hasta 2003"
drop aux*

recode  p12 (1 = 1 "...un solo empleo/ocupacion/actividad?") (2/8 = 2 "...mas de un empleo/ocupacion/actividad?") (9 = 9 "Ns./Nr."), gen(numero_ocupaciones) label(numero_ocupaciones)
label var numero_ocupaciones "Numero de ocupaciones que el ocupado tuvo en la semana de referencia"

recode p18b (1 = 1 "Publico") (2 = 2 "Privado") (3 = 3 "Otro") (9 = 9 "Ns./Nr."), gen(tipo_establecimiento_ocup) label(tipo_establecimiento_ocup)
label var tipo_establecimiento_ocup "Tipo de establecimiento del ocupado"

recode p19 (1 = 1 "1 persona") (2 = 2 "de 2 a 5 personas") (3 4 = 3 "de 6 a 25 personas") (5 6 = 4 "de 26 a 100 personas") (7 = 5 "de 101 a 500 personas") (8 = 6 "mas de 500 personas") (9 = 9 "Ns./Nr."), gen (tamano_establecimiento) label(tamano_establecimiento)
label var tamano_establecimiento "Cuantas personas trabajan en el establecimiento"

rename p20 cod_ocupacion_prin_ocup

gen aportesjubilatorios = (benef2 == 11 | benef2 == 12 | benef2 == 14)
label var aportesjubilatorios "El trabajador asalariado recibe descuento jubilatorio o aporta a un sistema jubilatorio (ocup. prin.)"

tostring p18, gen(aux1)
gen aux2 = substr(aux1,1,2)
replace aux2 = "999" if p18 == 999
replace aux2 = "0" if aux2 == "."
destring aux2, gen(aux3)
recode aux3 (999 = -1 "Ns./Nr."), gen(industria_ocup_prin) label(industria_ocup_prin)
label var industria_ocup_prin "Industria Ocupados - CIIU Rev 3 a 2 digitos"
drop aux*

* Characteristics of Unemployed Workers

tostring p39, gen(aux1)
gen aux2 = substr(aux1,1,2)
replace aux2 = "999" if p39 == 999
replace aux2 = "0" if aux2 == "."
destring aux2, gen(aux3)
recode aux3 (999 = -1 "Ns./Nr."), gen(desoc_industria_prin) label(desoc_industria_prin)
label var desoc_industria_prin "Desocupados: Industria de la ultima ocupaciontab - CIIU Rev 3 a 2 digitos"
drop aux*

rename p41 cod_ocupacion_prin_desocup

recode p39b (1 = 1 "Publico") (2 = 2 "Privado") (3 = 3 "Otro") (9 = 9 "Ns./Nr."), gen(desocup_tipo_establecimiento) label(desocup_tipo_establecimiento)
label var desocup_tipo_establecimiento "Desocupados: tipo de establecimiento en la ultima ocupacion"

gen fractionmunemployed = p32d / 31 if p32d != 99
gen monthsunemployed = p32 if estado == 2
replace monthsunemployed = monthsunemployed + fractionmunemployed if inrange(fractionmunemployed,0,1) & estado == 2

gen aux = .
replace aux = 1 if monthsunemployed != . & monthsunemployed >= 0 & monthsunemployed < 1 & estado == 2
replace aux = 2 if monthsunemployed != . & monthsunemployed >= 1 & monthsunemployed <= 3 & estado == 2
replace aux = 3 if monthsunemployed != . & monthsunemployed >  3 & monthsunemployed <= 6 & estado == 2
replace aux = 4 if monthsunemployed != . & monthsunemployed >  6 & monthsunemployed <= 12 & estado == 2
replace aux = 5 if monthsunemployed != . & monthsunemployed > 12 & estado == 2
replace aux = 9 if monthsunemployed != . & monthsunemployed >= 99 & estado == 2

recode aux (1 = 1 "Menos de 1 mes") (2 = 2 "1 a 3 meses") (3 = 3 "Mas de 3 a 6 meses") (4 = 4 "Mas de 6 a 12 meses") (5 = 5 " Mas de 1 anio") (9 = 9 "Ns./Nr."), gen(desoc_durationunemployed) label(desoc_durationunemployed)
label var desoc_durationunemployed "Periodo de Desempleo"
drop aux

gen desoc_aportesjubilatorios = (p38b_3 == 1) if p38b_3 == 1 | p38b_3 == 2 | p38b_3 == 9
label var desoc_aportesjubilatorios "Desocupados: en la ultima ocupacion le hacian descuento jubilatorio"

gen desoc_cat_ocup = p38
label var desoc_cat_ocup "Desocupados: categoria ocupacion en la ultima ocupacion"

gen desoc_tuvoocupant = p37
label var desoc_tuvoocupant "Desocupados: el desocupado tuvo empleo anterior"

* Income of Employers (independientes, patron, empleado)
rename itf ingreso_tot_fam
rename ipcf ingreso_percapita_fam
rename p47t ingreso_tot_indiv
rename inghora ingreso_horario_ocup_prin
label var ingreso_horario_ocup_prin "Ingreso horario de la ocupacion principal"
rename p21 ingreso_ocup_prin

* Create a variable indicating industry for employed/unemployed
* 1- Agricultura, caza, silvicultura y pesca
* 2- Explotacion de minas y canteras
* 3- Industrias manufactureras
* 4- Electricidad, gas y agua
* 5- Construccion
* 6- Comercio al por mayor y al por menor, restaurantes y hoteles
* 7- Transporte, almacenaje y comunicaciones
* 8- Establecimientos financieros, seguros, bienes inmuebles y servicios
*    prestados a las empresas
* 9- Servicios comunales, sociales y personales
* 0- Actividades no bien especificadas y desconocidas

gen industry = .
* Employed
replace industry = 1 if industry == . & inrange(p18,01,05) & p18 != .
replace industry = 2 if industry == . & inrange(p18,100,149) & p18 != .
replace industry = 3 if industry == . & inrange(p18,150,379) & p18 != .
replace industry = 4 if industry == . & inrange(p18,400,419) & p18 != .
replace industry = 5 if industry == . & inrange(p18,450,459) & p18 != .
replace industry = 6 if industry == . & inrange(p18,500,559) & p18 != .
replace industry = 7 if industry == . & inrange(p18,600,649) & p18 != .
replace industry = 8 if industry == . & inrange(p18,650,749) & p18 != .
replace industry = 9 if industry == . & inrange(p18,750,990) & p18 != .
replace industry = 0 if industry == . & inrange(p18,991,999) & p18 != .
replace industry = 0 if industry == . & inrange(p18,11,50) & p18 != .
* Unemployed
replace industry = 1 if industry == . & inrange(p39,01,05) & p39 != .
replace industry = 2 if industry == . & inrange(p39,100,149) & p39 != .
replace industry = 3 if industry == . & inrange(p39,150,379) & p39 != .
replace industry = 4 if industry == . & inrange(p39,400,419) & p39 != .
replace industry = 5 if industry == . & inrange(p39,450,459) & p39 != .
replace industry = 6 if industry == . & inrange(p39,500,559) & p39 != .
replace industry = 7 if industry == . & inrange(p39,600,649) & p39 != .
replace industry = 8 if industry == . & inrange(p39,650,749) & p39 != .
replace industry = 9 if industry == . & inrange(p39,750,990) & p39 != .
replace industry = 0 if industry == . & inrange(p39,991,999) & p39 != .
replace industry = 0 if industry == . & inrange(p39,11,50) & p39 != .

replace industry = -1 if industry == . & inrange(p18,0,0) & p18 != .
replace industry = -1 if industry == . & p18 == .
replace industry = -1 if industry == . & inrange(p39,0,0) & p39 != .
replace industry = -1 if industry == . & p39 == .

replace industry = 0 if rama == 89  // 89 equivale a "nuevos trabajadores", los considero como si no supiese el codigo CIIU

compress
saveold "$results/eph_bua.dta", replace
erase "$data/EPH/1995_2003_EPH_Base_Usuaria_Ampliada/Datos/EPHBUACompleta/dirlist.txt"

log close

