********************************************************************************
* DESCRIPTION: This code produces the year by year files from the random sample
* for the code 002_Build_Dataset.do
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

/*

 - input: "Muestra Longitudinal Empleo Registrado_13.dta"

		VARIABLES IN THE INPUT FILE

		ide_trabajador        = worker id
		relation              = match worker id-firm id
		sexo		  		  = gender
		fnac_anu              = year of birth
		provi		  		  = firm’s state
		letra		  		  = Economic activity code
		r32			  		  = 2-digits economic activity code
		r34 		          = 4-digits economic activity code
		tr_anio_ini           = firm’s start date by bracket of years
		tr_0496               = firm’s size by workers in 96
		rtyyyymm	          = total labor by year (yyyy) and month (mm)

 - output: GID_RSample_CleanRandomSample_x.dta with x=1996,...,2015

	   VARIABLES IN THE OUTPUT FILE

	   date 				 = date in stata format
	   cuil_trab             = worker id
	   cuit_empl             = firm id (record new firms in workers life cycle)
	   remuner_total         = Nominal labor income
	   gender				 = female,male
	   public_worker 		 = workers in state and federal government generated for compatibility, only in  SIPA data not in random sample
	   modalidad   			 = Type of contract generated for compatibility, only in  SIPA data not in random sample
	   ciiu_4                = Economic Activity code disaggregated up to four digits
	   DOB					 = Date of birth in years, months are random

	   * additional variables deleted before saving the data

	   rel_lab               = Worker-job match ID
	   COD_PROVINCIA         = state code
	   letra                 = Economic Activity code
	   r32                   = Economic activiy code disaggregated up to two digits
	   ano_inicio            = Firm's start date by brakets
	   age					 = age in years

*/

*-------------------------------------------------------------------------------
*Housekeeping
*-------------------------------------------------------------------------------
clear
set more off
set scheme s2color

*-------------------------------------------------------------------------------
* Options in the code
*-------------------------------------------------------------------------------

* add here your path to the random sample folder
global pathinit ""

* run a subsample to verify that the code is working
global R = "Y" /* run over a subsample Y=Yes N=No*/

*Folder where the Argentina_Clean files are saved
global name = "GID_RSample_"

*-------------------------------------------------------------------------------
*Paths and Logs
*-------------------------------------------------------------------------------

*Original data
global original_data "$pathinit/input"

*Temp folder
global temp = "$pathinit/Temp"

*Output folder
global output = "$pathinit/Output"

*Folder where the Argentina_Clean files are saved
global files_by_year = "$pathinit/Output/001_output"

*-------------------------------------------------------------------------------
*If you want to use a random subsample (this is just to test the code)
*-------------------------------------------------------------------------------

if "$R" == "Y" global name = "Subsample"

*-------------------------------------------------------------------------------
*-------------------------------------------------------------------------------

*Log
capture log close
log using "$temp/001_DataCleaning_RandomSample.txt", replace text

*-------------------------------------------------------------------------------
*-------------------------------------------------------------------------------
*-------------------------------------------------------------------------------
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
*Load original dataset
*-------------------------------------------------------------------------------

use "$original_data/Muestra Longitudinal Empleo Registrado_13.dta", clear

* drop not used variables
drop pondera

set seed 92

***************************
* Generate Unique identifying
* number for employee-job match.
***************************

if "$R" == "Y"{ /*keep only a few observations to test the code using a subsample*/

    gen random=runiform()
    keep if random<0.001
    drop random
}

gen double rel_lab=ide_trabajador*1000+relacion
format rel_lab %20.0g
label var rel_lab "Worker-Job Match ID"

***************************
*Homogeneize variable names
*************************

*This is needed in order to run reshape
*The idea is to get rid of "_"
forvalues y = 96/99{

    rename tr_04`y' tr19`y'12

}

forvalues y = 0/9{

    rename tr_040`y' tr200`y'12
}

forvalues y = 10/15{
    rename tr_04`y' tr20`y'12
}

rename tr_anio_ini ano_inicio

*-------------------------------------------------------------------------------
* Reshape the Data to long format (takes a long time)
*-------------------------------------------------------------------------------

reshape long rt tr, i(rel_lab) j(PERIODO) string

*-------------------------------------------------------------------------------
*Fill in annual tr data
*-------------------------------------------------------------------------------

*PERIODO is a string variable such as 199611 for year 1996 month 11
label var PERIODO "Date YYYYMM"

*Gen year
gen year = substr(PERIODO,1,4)
destring year, replace

*Gen month
gen month=substr(PERIODO,5,.)
destring month, replace
label define meses 1 "January" 2 "February" 3 "March" 4 "April" 5 "May" 6 "June" 7 "July" 8 "August" 9 "September" 10 "October" 11 "November" 12 "December"
label value month meses

*Gen date
gen date=ym(year, month)
format date %tm

* generate the firm size
bysort rel_lab year: egen temp = max(tr)
label values temp tramo
drop tr
rename temp tr
drop month
drop PERIOD

*-------------------------------------------------------------------------------
*Rename variables to match Full Data
*-------------------------------------------------------------------------------

rename rt remuner_total
rename provi COD_PROVINCIA
gen gender = 3 if sexo == 2
replace gender = 2 if sexo == 1
drop sexo
label define  gender 2 "Female" 3 "Male"
label values gender gender
rename r34 ciiu_4

*-------------------------------------------------------------------------------
*Drop extra variables
*-------------------------------------------------------------------------------

rename relacion cuit_empl
rename ide_trabajador cuil_trab
drop tr

*-------------------------------------------------------------------------------
*English Var Labels
*-------------------------------------------------------------------------------

label var fnac_anu 			"Year of birth"
label var COD_PROVINCIA 	"State code"
label var letra 			"Economic activity code"
label var r32 				"Economic activity code disaggregated up to two digits"
label var ciiu_4 			"Economic activity code disaggregated up to four digits"
label var remuner_total 	"Nominal labor income"

*-------------------------------------------------------------------------------
*Gen Age Variable
*-------------------------------------------------------------------------------
bysort cuil_trab (date): gen month_birth =  floor(12*runiform() + 1) if _n == 1
carryforward month_birth, replace

gen DOB = ym(fnac_anu, month_birth)

gen age = floor((date - DOB)/12)
drop month_birth
drop fnac_anu

*-------------------------------------------------------------------------------
*Gen some variables we do not have in RSample to make it similar to SIPA data
*-------------------------------------------------------------------------------

* There are no public workers in the random sample
gen public_worker = 0

drop if cuit_empl == .

* Fixed the seed for random variables
set seed 92

*-------------------------------------------------------------------------------
* generate label to variables
*-------------------------------------------------------------------------------

label var DOB             "Date of birth "
label var gender          "Cathegorical variable male, female"
label var date            "Date in stata format"
label var public_worker   "Workers in state and federal government"
label var cuil_trab       "Worker identifier"
label var cuit_empl       "Firm identifier"

*-------------------------------------------------------------------------------
*Drop unnecesary obs and save
*-------------------------------------------------------------------------------

drop if  remuner_total == .
drop age

compress

*Divide into years:
forvalues y = 1996/2015{

    preserve
    keep if year == `y'
	drop year rel_lab COD_PROVINCIA letra r32 ano_inicio
    save "$files_by_year/${name}CleanRandomSample_`y'.dta", replace
    restore
}

log close
