********************************************************************************
* DESCRIPTION: This code produces the regular wage from the random sample
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

/*
 - input: Random Sample "CleanRandomSample_1996.dta"

 - output: CleanRandomSample_x.dta with x=1996,...,2015

	   variables for the next tep
	   date 				 = date in stata format
	   cuil_trab             = worker id
	   cuit_empl             = firm id (record new firms in workers life cycle)
	   wage                  = Nominal labor income
	   gender				 = female,male
	   ciiu_4                = 4-digits Economic Activity code
	   sector                = 2-digits Economic Activity code
	   _spell                = job spells with gaps
	   year_age              = Age in years


*/

*-------------------------------------------------------------------------------
*Housekeeping
*-------------------------------------------------------------------------------
clear
set more off
set scheme s2color

*-------------------------------------------------------------------------------
* Options in the code
*-------------------------------------------------------------------------------

*Dataset to use
global dataset = "RSample"

* Add here your path to the random sample folder
global pathinit ""

*-------------------------------------------------------------------------------
*Paths and Logs
*-------------------------------------------------------------------------------

*Temp folder
global temp = "$pathinit/Temp"

*Input folder (to read the minimum wage file!)
global input = "$pathinit/input"

*Folder where the Argentina_Clean files are located
global output = "$pathinit/Output/002_output"

*Folder where the built_dataset is saved
global built_dataset = "$pathinit/Output/001_output"

*Datasets
if "$dataset" == "RSample"{

	*First and last year
	global last_year = 2015
	global first_year = 1996

	*Name of the Argentina_Clean files
	global filename = "GID_RSample_CleanRandomSample_"

	*So that files start with "GID_" on its name
	global name = "GID_RSample_"

}

capture log close
log using "$temp/002_Build_Dataset_$dataset.txt", replace text
capture file close drop_obs

*Open and save file to track the dropped observations
file open drop_obs using "$output/${name}Dropped_Obs.txt", replace write
file write drop_obs "Year NWorkers NFirms OBS Age Temp_Duplicates Duplicates" _n

*This loop opens each of the annual files and clean them independently
*For the Random Sample these files are called CleanRandomSample_
forvalues  y = $first_year/$last_year {

	use date cuil_trab cuit_empl remuner_total gender public_worker ciiu_4 DOB `temp_duplicate'  using "$built_dataset/${filename}`y'", clear

	*Count Firms and Workers------------------------------------------------
	bysort cuil_trab: gen worker_count = _n == 1
	bysort cuit_empl: gen firm_count = _n == 1
	gcollapse (sum) worker_count firm_count, merge replace fast

	summ worker_count, mean
	local NWorkers = `r(mean)'

	summ firm_count, mean
	local NFirms = `r(mean)'

	drop worker_count firm_count

	*-----------------------------------------------------------------------

	*Drop if gender is missing

	quietly count
	local n_before = `r(N)'
	drop if gender == .
	quietly count
	local n_gender = `n_before' - `r(N)'
	local n_int = `r(N)'

	*Filter age-------------------------------------------------------------
	gen age = date - DOB
	drop DOB
	*Drop if younger than 25 years or older than 55 years
	drop if age < 25*12
	drop if age >= 56*12

	quietly count
	local n_age = `n_before' - `n_gender' - `r(N)'

	quietly count
	local n_int = `r(N)'

	*-----------------------------------------------------------------------

	quietly count
	local n_tdupli = `n_int' - `r(N)'

	*-----------------------------------------------------------------------

	*Remove duplicates------------------------------------------------------
	local n_int =  `r(N)'
	bysort cuil_trab date (remuner_total): keep if _n == _N
	qui count
	local n_dupli = `n_int' - `r(N)'

	file write drop_obs "`y' `NWorkers' `NFirms' `n_before' `n_gender' `n_age' `n_tdupli' `n_dupli' "  _n

	*-----------------------------------------------------------------------


	*Save temp file of that year--------------------------------------------
	gen wage = remuner_total
	keep date cuil_trab cuit_empl wage age gender ciiu_4 public_worker
	compress
	save "$temp/${name}Prepped_Dataset_`y'.dta", replace

}

*Close file that tracks dropped observations
file close drop_obs

clear

*Append files-----------------------------------------------------------
forvalues y = $first_year/$last_year {

	append using "$temp/${name}Prepped_Dataset_`y'.dta"
	erase "$temp/${name}Prepped_Dataset_`y'.dta"

}

*-----------------------------------------------------------------------

*generate firm-worker id with <=3 months gap and first and last wage

gegen new_id=group(cuil_trab cuit_empl)
qui gsort new_id date

gen gap=0
by new_id:replace gap=1  if date-date[_n-1]>=4 & date~=. & date[_n-1]~=.
by new_id:replace gap=sum(gap)

gegen new_id2=group(new_id gap)
drop new_id gap
rename new_id2 new_id

qui gsort new_id date

gen first_or_last_obs =0
replace first_or_last_obs=1 if new_id~= new_id[_n+1]
replace first_or_last_obs=1 if new_id~= new_id[_n-1]

*-----------------------------------------------------------------------

*Gen Sector Variable----------------------------------------------------
gen ciiu_2 = floor(ciiu_4/100)
gen letra = "A" if ciiu_2 < 5
replace letra = "B" if ciiu_2 == 5
replace letra = "C" if inlist(ciiu_2,10,11,12,13,14)
replace letra = "D" if inrange(ciiu_2,15,37)
replace letra = "E" if inlist(ciiu_2, 40,41)
replace letra = "F" if ciiu_2 == 45
replace letra = "G" if inrange(ciiu_2,50,52)
replace letra = "H" if ciiu_2 == 55
replace letra = "I" if inrange(ciiu_2,60,64)
replace letra = "J" if inrange(ciiu_2,65,67)
replace letra = "K" if inrange(ciiu_2,70,74)
replace letra = "L" if ciiu_2 == 75
replace letra = "M" if ciiu_2 == 80
replace letra = "N" if ciiu_2 == 85
replace letra = "O" if inrange(ciiu_2,90,93)
replace letra = "P" if ciiu_2 == 95
replace letra = "Q" if ciiu_2 == 99
encode letra, gen(sector)
drop ciiu_2

*-----------------------------------------------------------------------

*Gen age in years-------------------------------------------------------
gen year_age = floor(age/12)

*Drop letra veriable since letra and sector are the same
drop letra

*Minimum wage-----------------------------------------------------------

merge m:1 date using "$input/MW.dta", keepusing(MW)
drop if _merge == 2
tab _merge, missing
drop _merge
gen min_wage_ind = 1 if (wage <= MW / 2)
replace min_wage_ind = 0 if (wage > MW / 2)
drop MW

*List the variables and count the number of missing to check
ds
foreach var of varlist `r(varlist)' {

	di "Number of `var' missing"
	count if `var' == .
	di "Number of `var' nonmissing"
	count if `var' != .

}

*-------------------------------------------------------------------------------
* Drop workers in the federal or state government
*-------------------------------------------------------------------------------

drop if public_worker==1
drop public_worker age

*-------------------------------------------------------------------------------
* generate label to variables
*-------------------------------------------------------------------------------

label var wage               "Total nominal labor income"
label var first_or_last_obs  "Dummy first and last month in job spell"
label var sector             "Sector"
label var min_wage_ind       "Dummy below 0.5 min wage"
label var year_age           "Age in years"
label var new_id             "New id:worker-firm id"

*Compress and save------------------------------------------------------
compress
save "$output/${name}Prepped_Dataset.dta", replace
