********************************************************************************
* DESCRIPTION: This code computes the regular wage from the random sample
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

/*

 - input: Random Sample GID_RSample_Prepped_Dataset.dta
		  SIPA          SIPA_GID_RSample_Prepped_Dataset.dta

 - output: the panel with teh regular wage under different filters

	   variables for the next tep
	   new_id 				 = worker-mathc id
	   date                  = date in stata format
	   w_r                   = regular wage


*/

*-------------------------------------------------------------------------------
*-------------------------------------------------------------------------------

********************
*Housekeeping
********************
clear
set more off
set scheme s2color

*Dataset to use
global dataset = "RSample"

* add here your path to the random sample folder
global pathinit ""

*test code with 10% of original sample
global test_code = 0      /* 0=original sample, 1=subsample 10\% \%*/

* filter for regular wages
global filter_reguw = 4    /* 1=KehoeMidrigan, 2=Blanco , 3=Nakamura Steinsson, 4=Stevens*/

* If it generates a random sample
global r_sample_size = 0.1

* Fixed the seed for random variables
set seed 92

********************************************************************************
*** Parameters
********************************************************************************
if $filter_reguw == 1{

* Midrigan-Kehoe filter parameters
global mk_a = .5
global mk_c = 0.3
global mk_l = 3

}

if $filter_reguw == 2{

*Blanco filters parameters
global bl_tiny  = 0.01
global bl_l     = 4                   //number of period for price to come back
global bl_a     = 2
global bl_large = 0.2

}

if $filter_reguw == 3{

* Nakamura and Steinsson filter parameters
global ns_l = 3         // number of months wages must be stable for unsymmetric v shaped
global ns_j = 8         // number of months that can take for the wage to return to it's reference value

}

if $filter_reguw == 4{

* Steven filter parameters
global st_L   = 6              // minimum level of months to apply the filter

global st_Ka   = 0.4168          // K param for sector a or 1
global st_Kb   = 0.3915          // K param for sector b or 2
global st_Kc   = 0.3828          // K param for sector c or 3
global st_Kd   = 0.4737          // K param for sector d or 4
global st_Ke   = 0.4996          // K param for sector e or 5
global st_Kf   = 0.4097          // K param for sector f or 6
global st_Kg   = 0.4989          // K param for sector g or 7
global st_Kh   = 0.4868          // K param for sector h or 8
global st_Ki   = 0.4895          // K param for sector i or 9
global st_Kj   = 0.5164          // K param for sector j or 10
global st_Kk   = 0.4744          // K param for sector k or 11
global st_Kl   = 0.4010          // K param for sector l or 12
global st_Km   = 0.4811          // K param for sector m or 13
global st_Kn   = 0.4309          // K param for sector n or 14
global st_Ko   = 0.5010          // K param for sector 0 or 15

}

********************
*Paths and Logs
********************

global sample = ""

*Folder with filters
global pathfilter = "$pathinit/do/FiltersRegular"

*Figures folder
global intput = "$pathinit/output/002_output"

*Output folder
global output = "$pathinit/output/003_output"

*temporary folder folder
global temp      = "$pathinit/temp"

global sample = ""

if "$dataset" == "RSample"{

    global name          = "GID_RSample_"

}

if $test_code == 0{

    use cuil_trab cuit_empl ciiu_4 gender date wage  first_or_last_obs /*
    */ sector year_age min_wage_ind   new_id /*
    */ using "$intput/${name}Prepped_Dataset.dta"
}

else if $test_code == 1{

    use cuil_trab cuit_empl ciiu_4 gender date wage first_or_last_obs /*
    */ sector year_age min_wage_ind  new_id/*
    */ using "$intput/${name}Prepped_Dataset.dta"

    xtset cuil_trab date
    gsort cuil_trab date

    bysort cuil_trab: gen aux = runiform() if _n == 1
    *replace aux = (aux <$r_sample_size) if aux !=.
	replace aux = (aux <0.1) if aux !=.
    bysort cuil_trab:  egen aux2 = max(aux)
    keep if aux2==1
    drop aux aux2

	save  "$temp/${name}Prepped_Dataset_small.dta", replace
}

********************************************************************************
***************  Save the log file       ***************************************
********************************************************************************

capture log close
if $filter_reguw == 1{

    log using "$temp/${name}_Freq_Agg_MK_ParaL${mk_l}a${mk_a}c${mk_c}.txt", replace text

}
else if $filter_reguw == 2{

     log using "$temp/${name}_Freq_Agg_BL_ParaT${bl_tiny}L${bl_l}.txt", replace text

}
else if $filter_reguw == 3{

     log using "$temp/${name}_Freq_Agg_NS_ParaT${ns_l}J${ns_j}.txt", replace text

}
else if $filter_reguw == 4{

     log using "$temp/${name}_Freq_Agg_ST_ParaK${st_Ka}.txt", replace text

}

********************************************************************************
***************  Step 1 of cleaning                               **************
********************************************************************************

qui xtset new_id date
qui gsort new_id date

* round wages to pesos (no cents)
qui gen w_t = round(wage ,1)

* drop first and last wage due to time aggregation
qui replace w_t =. if first_or_last_obs==1 | min_wage_ind==1

* replace June and December
qui by new_id: replace w_t =0.5*l.w_t+0.5*f.w_t if  (month(dofm(date))==6 | month(dofm(date))==12) & (w_t~=l.w_t & w_t~=f.w_t) & (l.w_t ==f.w_t) & l.w_t~=. & f.w_t~=.

if $filter_reguw == 1{

    do "$pathfilter/KM_filter"

    keep  new_id date w_r

	label var w_r               "regular wage"

    compress
    save "$output/${name}MK_ParaL${mk_l}a${mk_a}c${mk_c}_w_r.dta", replace

}
else if $filter_reguw == 2{

    do "$pathfilter/BC_filter"

    keep  new_id date w_r

	label var w_r               "regular wage"

    compress
    save "$output/${name}BL_ParaT${bl_tiny}L${bl_l}_w_r.dta", replace

}
else if $filter_reguw == 3{

    do "$pathfilter/NS_filter"

    keep  new_id date w_r

	label var w_r               "regular wage"

    compress
    save "$output/${name}NS_ParaT${ns_l}J${ns_j}_w_r.dta", replace

}

else if $filter_reguw == 4{

	* generate the parameter by sector

	gen K_par=.

	replace K_par=$st_Ka if sector==1
	replace K_par=$st_Kb if sector==2
	replace K_par=$st_Kc if sector==3
	replace K_par=$st_Kd if sector==4
	replace K_par=$st_Ke if sector==5
	replace K_par=$st_Kf if sector==6
	replace K_par=$st_Kg if sector==7
	replace K_par=$st_Kh if sector==8
	replace K_par=$st_Ki if sector==9
	replace K_par=$st_Kj if sector==10
	replace K_par=$st_Kk if sector==11
	replace K_par=$st_Kl if sector==12
	replace K_par=$st_Km if sector==13
	replace K_par=$st_Kn if sector==14
	replace K_par=$st_Ko if sector==15

	* these workers do not have a sector
	drop if K_par==.

    * prepare the data for matlab
    keep new_id date w_t K_par
    drop if w_t==.
    gsort new_id date
    gen date_num = date
    by new_id: gen count=_N
    drop if count < $st_L
    drop count

    gquantiles decile = new_id, xtile nquantiles(10)

    global st_Ka=$st_Ka*100

    forvalues dec = 1(1)10 {

        export delimited new_id w_t date_num K_par using "$temp/${name}Data_KS_test_K${st_Ka}_L${st_L}_`dec'.csv"  if decile==`dec', novarnames replace

    }

}
