********************************************************************************
* DESCRIPTION: This code produces the excel tables for the main text
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

/*

 - input: data with the regular wage, e.g.,  "GID_RSample_Data_KS_test_K51_L6_w_r.dta"

 - output: Figures of the wages before and after the filters
		   Excel files in results

*/

*Dataset to use
global dataset = "RSample"

* add here your path to the random sample folder
global pathinit ""

* add here the name with the options
global file_name "GID_RSample_KS_test_K41.68_L6_w_r"   // with steavens (2020)
*global file_name "GID_RSample_KS_R1_test_K40.03_L6_w_r"   // with steavens (2020) and two K for diff. level of inflation
*global file_name "GID_RSample_BL_ParaT.01L4_w_r"      //with Blanco (2020)
*global file_name "GID_RSample_MK_ParaL3a.5c.3_w_r"    // with Kehoe and Midrigan method (2015)
*global file_name "GID_RSample_NS_ParaT3J8_w_r"        // with Nakamura and Steinsson method (2008)

*test code with 10% of original sample
global test_code = 0      /* 0=original sample, 1=subsample 10\% \%*/

********************************************************************************
*** graph options for individual labor income
********************************************************************************
global graph_nid   = 50
global graph_ntime = 5*12

********************
*Paths and Logs
********************

*input folder for data
global intput = "$pathinit/output/002_output"

*input folder for regular wagepaths
global intput_wr = "$pathinit/output/003_output"

*results folder
global results = "$pathinit/results"

*temporary folder folder
global temp = "$pathinit/temp"

global sample = ""

if "$dataset" == "RSample"{

    global name          = "GID_RSample_"

}

if $test_code == 0{

    use cuil_trab cuit_empl ciiu_4 gender date wage first_or_last_obs /*
    */ sector year_age min_wage_ind new_id /*
    */ using "$intput/${name}Prepped_Dataset.dta", replace

}
else if $test_code == 1{

    use cuil_trab cuit_empl ciiu_4 gender date wage first_or_last_obs /*
    */ sector year_age min_wage_ind new_id/*
    */ using "$temp/${name}Prepped_Dataset_small.dta", replace


}

********************************************************************************
***************  Save the log file       ***************************************
********************************************************************************

capture log close
log using "$temp/004_Compute_state.txt", replace text

merge 1:1 date new_id using "$intput_wr/$file_name.dta"
drop _merge

********************************************************************************
***************  Generate path for 20 workers       ****************************
********************************************************************************

preserve

qui gsort  cuil_trab date

gen count=1   if w_r~=.
by cuil_trab: gegen aux=sum(count)
replace aux=. if aux< $graph_ntime & aux~=.
replace aux=1 if aux>1 & aux~=.
drop count

gegen new_id2=group(cuil_trab) if aux==1
drop aux
keep if new_id2<=$graph_nid & new_id2~=.
gen lw_r=ln(w_r) if w_r>0
gen lw  =ln(wage) if wage>0

export delimited cuil_trab cuit_empl new_id  date lw_r lw using "$results/paths/$file_name.csv", novarnames replace

restore

********************************************************************************
***************  Compute statistics wage changes      **************************
********************************************************************************

* Sort dataset by job id
qui xtset new_id date
qui gsort new_id date

* round wages to pesos (no cents)
qui gen w_t = round(wage ,1)

* drop first and last wage due to time aggregation
qui replace w_t =. if first_or_last_obs==1 | min_wage_ind==1

* replace June and December
qui by new_id: replace w_t =0.5*l.w_t+0.5*f.w_t if  (month(dofm(date))==6 | month(dofm(date))==12) & (w_t~=l.w_t & w_t~=f.w_t) & (l.w_t ==f.w_t) & l.w_t~=. & f.w_t~=.

* Generate frequency
by new_id : gen     freq_dw=1 if w_r~=l.w_r & w_r~=. & l.w_r~=.
by new_id : replace freq_dw=0 if w_r==l.w_r & w_r~=. & l.w_r~=.

* Generate frequency robustness
by new_id : gen     freq_dw_rob=1 if w_t~=l.w_t & w_t~=. & l.w_t~=.
by new_id : replace freq_dw_rob=0 if w_t==l.w_t & w_t~=. & l.w_t~=.

* Generate frequency up
by new_id : gen     freq_dw_up=1 if w_r>l.w_r & w_r~=. & l.w_r~=.
by new_id : replace freq_dw_up=0 if w_r<=l.w_r & w_r~=. & l.w_r~=.

* Generate frequency down
by new_id : gen     freq_dw_down=1 if w_r<l.w_r & w_r~=. & l.w_r~=.
by new_id : replace freq_dw_down=0 if w_r>=l.w_r & w_r~=. & l.w_r~=.

* Generate mean change up
by new_id : gen     mean_dw_up=.
by new_id : replace mean_dw_up=log(w_r)-log(l.w_r) if w_r>l.w_r & w_r~=. & l.w_r~=.

* Generate mean change down
by new_id : gen     mean_dw_down=.
by new_id : replace mean_dw_down=log(w_r)-log(l.w_r) if w_r<l.w_r & w_r~=. & l.w_r~=.

* Generate mean change
by new_id : gen     mean_dw=.
by new_id : replace mean_dw=log(w_r)-log(l.w_r) if w_r~=. & l.w_r~=.

* Generate 12-m frequency
by new_id : gen     freq_dw_12=1 if w_r~=l12.w_r & w_r~=. & l12.w_r~=.
by new_id : replace freq_dw_12=0 if w_r==l12.w_r & w_r~=. & l12.w_r~=.

* Generate 12-m frequency for wage
by new_id : gen     freq_dw_12_rob=1 if w_t~=l12.w_t & w_t~=. & l12.w_t~=.
by new_id : replace freq_dw_12_rob=0 if w_t==l12.w_t & w_t~=. & l12.w_t~=.

* Generate 12-m frequency up
by new_id : gen     freq_dw_up_12=1 if w_r>l12.w_r & w_r~=. & l12.w_r~=.
by new_id : replace freq_dw_up_12=0 if w_r<=l12.w_r & w_r~=. & l12.w_r~=.

* Generate 12-m frequency down
by new_id : gen     freq_dw_down_12=1 if w_r<l12.w_r & w_r~=. & l12.w_r~=.
by new_id : replace freq_dw_down_12=0 if w_r>=l12.w_r & w_r~=. & l12.w_r~=.

* Generate 12-m mean change up
by new_id : gen     mean_dw_up_12=.
by new_id : replace mean_dw_up_12=log(w_r)-log(l12.w_r) if w_r>l12.w_r & w_r~=. & l12.w_r~=.

* Generate 12-m mean change down
by new_id : gen     mean_dw_down_12=.
by new_id : replace mean_dw_down_12=log(w_r)-log(l12.w_r) if w_r<l12.w_r & w_r~=. & l12.w_r~=.

* Generate 12-m mean change
by new_id : gen     mean_dw_12=.
by new_id : replace mean_dw_12=log(w_r)-log(l12.w_r) if w_r~=. & l12.w_r~=.

* Gen counters
gen counter = 1
gen missing_wage         =0
replace  missing_wage    =1   if first_or_last_obs==1 | min_wage_ind==1
gen missing_regular_wage = (w_r == .)
gen regular_wage_equals_wage =.
replace   regular_wage_equals_wage=1 if freq_dw~=. & w_t==w_r
replace   regular_wage_equals_wage=0 if freq_dw~=. & w_t~=w_r

********************************************************************************
***************  Compute frequency of wage changes      ************************
********************************************************************************

preserve

    gcollapse (mean) freq_dw freq_dw_rob freq_dw_up freq_dw_down mean_dw_up mean_dw_down mean_dw freq_dw_12 freq_dw_12_rob freq_dw_up_12 freq_dw_down_12 mean_dw_up_12 mean_dw_down_12 mean_dw_12 regular_wage_equals_wage (count) number_of_workers = counter  (sum) missing_wage missing_regular_wage, by(date) fast unsorted

export delimited "$results/frequency_stat/Freq_Agg_$file_name.csv", replace

restore

*By ciiu4
preserve

    gcollapse (mean) freq_dw freq_dw_up freq_dw_down mean_dw_up mean_dw_down freq_dw_12 freq_dw_up_12 freq_dw_down_12 mean_dw_up_12 mean_dw_down_12 regular_wage_equals_wage (count) number_of_workers = counter  (sum) missing_wage missing_regular_wage, by(date ciiu_4) fast unsorted

export delimited "$results/frequency_stat/Freq_ciiu4_$file_name.csv", replace

restore

*By sector
preserve

    gcollapse (mean) freq_dw freq_dw_up freq_dw_down mean_dw_up mean_dw_down freq_dw_12 freq_dw_up_12 freq_dw_down_12 mean_dw_up_12 mean_dw_down_12 regular_wage_equals_wage (count) number_of_workers = counter  (sum) missing_wage missing_regular_wage, by(date sector) fast unsorted

export delimited "$results/frequency_stat/Freq_Sector_$file_name.csv", replace

restore

*By gender
preserve

    gcollapse (mean) freq_dw freq_dw_up freq_dw_down mean_dw_up mean_dw_down freq_dw_12 freq_dw_up_12 freq_dw_down_12 mean_dw_up_12 mean_dw_down_12 regular_wage_equals_wage (count) number_of_workers = counter  (sum) missing_wage missing_regular_wage , by(date gender) fast unsorted

export delimited "$results/frequency_stat/Freq_gender_$file_name.csv", replace

restore

*By age (in years)
preserve

    gcollapse (mean) freq_dw freq_dw_up freq_dw_down mean_dw_up mean_dw_down freq_dw_12 freq_dw_up_12 freq_dw_down_12 mean_dw_up_12 mean_dw_down_12 regular_wage_equals_wage (count) number_of_workers = counter  (sum) missing_wage missing_regular_wage , by(date year_age) fast unsorted

export delimited "$results/frequency_stat/Freq_age_$file_name.csv", replace

restore

*Gen tenure
bysort cuil_trab new_id (date): gen tenure = _n

*By tenure group (four groups)
preserve

    *Gen tenure groups
    gen tenure_group =  1 if tenure < 13
    replace tenure_group = 2 if tenure > 12 & tenure < 25
    replace tenure_group = 3 if tenure > 24 & tenure < 37
    replace tenure_group = 4 if tenure > 36

    label define tenure_group 1 "Less than one year" 2 "Between one and two years" 3 "Between two and three years" 4 "Four or more years"

    gcollapse (mean) freq_dw freq_dw_up freq_dw_down mean_dw_up mean_dw_down freq_dw_12 freq_dw_up_12 freq_dw_down_12 mean_dw_up_12 mean_dw_down_12 regular_wage_equals_wage (count) number_of_workers = counter  (sum) missing_wage missing_regular_wage , by(date tenure_group) fast unsorted

export delimited "$results/frequency_stat/Freq_tenure_group_$file_name.csv", replace

restore

*By tenure
preserve

    gcollapse (mean) freq_dw freq_dw_up freq_dw_down mean_dw_up mean_dw_down freq_dw_12 freq_dw_up_12 freq_dw_down_12 mean_dw_up_12 mean_dw_down_12 regular_wage_equals_wage (count) number_of_workers = counter  (sum) missing_wage missing_regular_wage , by(date tenure) fast unsorted

export delimited "$results/frequency_stat/Freq_tenure_$file_name.csv", replace

restore

drop tenure

*By permanent income
preserve

    replace wage =.     if first_or_last_obs==1 | min_wage_ind==1
    replace counter =.  if first_or_last_obs==1 | min_wage_ind==1

    *Gen cumulative income since the beggining to date
    bysort cuil_trab (date): gen cumulative_income = sum(wage)

    *Gen cumulative months we see her in the dataset
    bysort cuil_trab (date): gen cumulative_number_of_months = sum(counter)

    *Xtset
    xtset, clear
    xtset cuil_trab date

    *Gen total income from two years ago to date
    bysort cuil_trab (date): gen past_two_years_total_income = cumulative_income - l24.cumulative_income

    *Gen number of wages from two years ago to date (if the person never left, this number will be 24!)
    bysort cuil_trab (date): gen past_two_years_number_obs = cumulative_number_of_months - l24.cumulative_number_of_months

    *Gen average
    gen average_income = past_two_years_total_income / past_two_years_number_obs

    *************
    xtset, clear
    drop past_two_years_total_income cumulative_income past_two_years_number_obs cumulative_number_of_months

    *Foreach date, classify worker in deciles
    gquantiles decile = average_income, xtile nquantiles(10) by(date)

    gcollapse (mean) freq_dw freq_dw_up freq_dw_down mean_dw_up mean_dw_down freq_dw_12 freq_dw_up_12 freq_dw_down_12 mean_dw_up_12 mean_dw_down_12 regular_wage_equals_wage (count) number_of_workers = counter  (sum) missing_wage missing_regular_wage , by(date decile) fast unsorted

   export delimited "$results/frequency_stat/Freq_income_$file_name.csv", replace

restore

********************************************************************************
***************  Compute distribution of # of changes                   ********
********************************************************************************

* Changes per year
preserve

gen year = year(dofm(date))

bysort new_id year: gegen n_changes = total(freq_dw)
bysort new_id year: gegen n_months = count(w_r)
bysort new_id year: gen n_obs = _n

gen aux = n_changes/n_months

keep if n_obs == 1

gcollapse (mean) share_months_changes = aux, by(year) fast unsorted

export delimited "$results/frequency_stat/Share_months_with_change_$file_name.csv", replace

restore

********************************************************************************
***************  ANOVA analysis of freq_dw_12                           ********
********************************************************************************

preserve

gen year = year(dofm(date))

gen inflation_period     = 1 if inrange(year,1997,2001)
replace inflation_period = 2 if inrange(year,2007,2015)
keep if inrange(inflation_period,1,2)

*Gen tenure
bysort cuil_trab new_id (date): gen tenure = _n

*Gen permanent income
replace wage =.     if first_or_last_obs==1 | min_wage_ind==1
replace counter =.  if first_or_last_obs==1 | min_wage_ind==1

*Gen cumulative income since the beggining to date
bysort cuil_trab (date): gen cumulative_income = sum(wage)

*Gen cumulative months we see her in the dataset
bysort cuil_trab (date): gen cumulative_number_of_months = sum(counter)

xtset, clear
xtset cuil_trab date

*Gen total income from two years ago to date
bysort cuil_trab (date): gen past_two_years_total_income = cumulative_income - l24.cumulative_income

*Gen number of wages from two years ago to date (if the person never left, this number will be 24!)
bysort cuil_trab (date): gen past_two_years_number_obs = cumulative_number_of_months - l24.cumulative_number_of_months

*Gen average
gen average_income = past_two_years_total_income / past_two_years_number_obs

xtset, clear
drop past_two_years_total_income cumulative_income past_two_years_number_obs cumulative_number_of_months

*Foreach date, classify worker in deciles
gquantiles decile = average_income, xtile nquantiles(10) by(date)

* Run anova analysis
glevelsof inflation_period, local(period_list) c
foreach t in `period_list' {

  * Fixed effects regression: seller and categories
  reghdfe freq_dw_12 if inflation_period == `t' , absorb(sector_fe_`t' = sector gender_fe_`t' = gender age_fe_`t' = year_age tenure_fe_`t' = tenure decile_fe_`t' = decile)

  sum freq_dw_12 if e(sample)
  local var_freq_dw_12_`t' = r(Var)

  sum sector_fe_`t' if e(sample)
  local var_sector_fe_`t' = r(Var)

  sum gender_fe_`t' if e(sample)
  local var_gender_fe_`t' = r(Var)

  sum age_fe_`t' if e(sample)
  local var_age_fe_`t' = r(Var)

  sum tenure_fe_`t' if e(sample)
  local var_tenure_fe_`t' = r(Var)

  sum decile_fe_`t' if e(sample)
  local var_decile_fe_`t' = r(Var)


}

* Set dataset to store results
clear
local i            = 0
gen period         = .
gen var_freq_dw_12 = .
gen var_sector_fe  = .
gen var_gender_fe  = .
gen var_age_fe     = .
gen var_tenure_fe  = .
gen var_decile_fe  = .

foreach t in `period_list' {
  local i = `i' + 1
  set obs `i'
  replace period         = `t' if _n==_N
  replace var_freq_dw_12 = `var_freq_dw_12_`t'' if _n==_N
  replace var_sector_fe  = `var_sector_fe_`t'' if _n==_N
  replace var_gender_fe  = `var_gender_fe_`t'' if _n==_N
  replace var_age_fe     = `var_age_fe_`t'' if _n==_N
  replace var_tenure_fe  = `var_tenure_fe_`t'' if _n==_N
  replace var_decile_fe  = `var_decile_fe_`t'' if _n==_N
}

export delimited "$results/frequency_stat/anova_freq_dw_12.csv", replace

tempname anova
file open anova using "$results/frequency_stat/anova_freq_dw_12.tex", write replace
file write anova "\begin{tabular}{lcc}" _n "\hline \hline" _n
file write anova "Variable & Low Inflation & High Inflation \\ \hline " _n
file write anova " & (1997-2001) & (2007-2015) \\ \hline " _n

sum var_freq_dw_12 if period == 1
local var_freq_dw_12_1 = r(mean)
sum var_freq_dw_12 if period == 2
local var_freq_dw_12_2 = r(mean)

file write anova "Sector & "
sum var_sector_fe if period == 1
local relvar = r(mean)/`var_freq_dw_12_1'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\% & "
sum var_sector_fe if period == 2
local relvar = r(mean)/`var_freq_dw_12_2'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\\ "_n

file write anova "Gender & "
sum var_gender_fe if period == 1
local relvar = r(mean)/`var_freq_dw_12_1'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\% & "
sum var_gender_fe if period == 2
local relvar = r(mean)/`var_freq_dw_12_2'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\\ "_n

file write anova "Age & "
sum var_age_fe if period == 1
local relvar = r(mean)/`var_freq_dw_12_1'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\% & "
sum var_age_fe if period == 2
local relvar = r(mean)/`var_freq_dw_12_2'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\\ "_n

file write anova "Tenure & "
sum var_tenure_fe if period == 1
local relvar = r(mean)/`var_freq_dw_12_1'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\% & "
sum var_tenure_fe if period == 2
local relvar = r(mean)/`var_freq_dw_12_2'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\\ "_n

file write anova "Income dec. & "
sum var_decile_fe if period == 1
local relvar = r(mean)/`var_freq_dw_12_1'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\% & "
sum var_decile_fe if period == 2
local relvar = r(mean)/`var_freq_dw_12_2'
file write anova (substr(string(`relvar'*100,"%5.0f"),1,5)) "\\ "_n

file write anova "\hline \hline" _n "\end{tabular}"
file close anova

restore

********************************************************************************
***************  Compute variance decomposition over time               ********
********************************************************************************

preserve

qui xtset new_id date
qui gsort new_id date

by new_id : gen lw_r   = log(w_r) if w_t~=. & w_r~=.
by new_id : gen lw_t   = log(w_t) if w_t~=. & w_r~=.
by new_id : gen lresid = lw_t - lw_r

by new_id : gen dlw_r   = log(w_r)-log(l12.w_r) if w_t~=. & l12.w_t~=. & w_r~=. & l12.w_r~=.
by new_id : gen dlw_t   = log(w_t)-log(l12.w_t) if w_t~=. & l12.w_t~=. & w_r~=. & l12.w_r~=.
by new_id : gen dlresid = dlw_t - dlw_r

gcollapse (var) var_lw_t = lw_t var_lw_r = lw_r var_lresid = lresid var_dlw_t = dlw_t var_dlw_r = dlw_r var_dlresid = dlresid, by(date) fast unsorted
export delimited "$results/frequency_stat/Var_decomp_lw_$file_name.csv", replace

restore

********************************************************************************
***************  Compute 1- and 12- monthly wage change distribution    ********
********************************************************************************

bysort new_id (date): gen wage_change_1  = (ln(w_r) - ln(l1.w_r)) /*current wage minus the previous ***observed*** one*/
bysort new_id (date): gen wage_change_12 = (ln(w_r) - ln(l12.w_r)) /*current wage minus the previous ***observed*** one*/
replace wage_change_1 = . if (wage_change_1 == 0)
replace wage_change_12 = . if (wage_change_12 == 0)
gen  aux = 1 if (wage_change_12 ~=. & wage_change_12==l.wage_change_12)
replace wage_change_12 = . if (wage_change_12 ~= . & aux==1)
drop aux

*By year, winsorize observations above 99th percentile
gen year = year(dofm(date))
replace wage_change_1   =-1 if wage_change_1<=-1 & wage_change_1~=.
replace wage_change_12  =-1 if wage_change_12<=-1 & wage_change_12~=.

winsor2 wage_change_1 wage_change_12, cuts(0 99) by(year) replace

*Creates a histogram per year starting at -1 and the width is 0.01
summ year
forvalues i = `r(min)'(1)`r(max)' {

    preserve
    twoway__histogram_gen wage_change_1 if (year == `i'), start(-1) width(0.01) fraction gen(freq_`i' bin, replace)
    keep if freq_`i' != .
    keep freq_`i' bin
    save "$temp/${name}_Histogram1_`i'.dta", replace
    restore

    preserve
    twoway__histogram_gen wage_change_12 if (year == `i'), start(-1) width(0.01) fraction gen(freq_`i' bin, replace)
    keep if freq_`i' != .
    keep freq_`i' bin
    save "$temp/${name}_Histogram12_`i'.dta", replace
    restore

}

*Combine and erase files
preserve
summ year
local startloop = `r(min)' + 1
local first = `r(min)'
forvalues i = `startloop'(1)`r(max)' {

    use "$temp/${name}_Histogram1_`first'.dta", clear
    merge 1:1 bin using "$temp/${name}_Histogram1_`i'.dta", nogen
    sleep 1000
    save "$temp/${name}_Histogram1_`first'.dta", replace
    sleep 1000
    erase "$temp/${name}_Histogram1_`i'.dta"

}

*Final save

save "$results/frequency_stat/Raw_Histogram1_$file_name.dta", replace

sleep 1000
erase "$temp/${name}_Histogram1_`first'.dta"

restore

preserve
summ year
local startloop = `r(min)' + 1
local first = `r(min)'
forvalues i = `startloop'(1)`r(max)' {

    use "$temp/${name}_Histogram12_`first'.dta", clear
    merge 1:1 bin using "$temp/${name}_Histogram12_`i'.dta", nogen
    sleep 1000
    save "$temp/${name}_Histogram12_`first'.dta", replace
    sleep 1000
    erase "$temp/${name}_Histogram12_`i'.dta"

}

*Final save
save "$results/wage_change_stat/Raw_Histogram12_$file_name.dta", replace

sleep 1000
erase "$temp/${name}_Histogram12_`first'.dta"

restore
