%{
* DESCRIPTION: This code computes the objective function in the Calvo-Taylor model for a
given set of parameters and moments in the data

* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
%}


function [GMM_obj,mom_m] = GMM_objfun(x,d,mom_d,GMMweight,shock,p)

% Unpack parameters
par.T_taylor    = ceil(x(1));
par.sigma_eta   = x(2);
par.w_lb        = x(3);
par.w_ub        = x(4);
par.sigma_phi   = x(5);
par.m_phi       = x(6);
par.sigma_gamma = x(7);
par.beta        = x(8);

% Simulate model
simdata = simulate(d,par,shock);

%% Compute moments from simulated data
income_var    = simdata.w_total;
wagechange_1y = nan(size(d.lw_t));
for t = 13:size(d.lw_t,2)
    wagechange_1y(:,t) = income_var(:,t) - income_var(:,t-12);
end

wagechange_1m = nan(size(d.lw_t));
for t = 2:size(d.lw_t,2)
    wagechange_1m(:,t) = income_var(:,t) - income_var(:,t-1);
end

% moments in the model

mom_m = nanstd(wagechange_1y(wagechange_1y~=0),0);             %std 1-yr wage change
mom_m = [mom_m;nanstd(wagechange_1m(wagechange_1m~=0 & (d.month==4 | d.month==5 | d.month==9 | d.month==10)),0)];     %std 1-mo wage change
mom_m = [mom_m;sum(wagechange_1y==0)/sum(~isnan(wagechange_1y))];   % share of 1-yr changes that are zero
mom_m = [mom_m;sum(wagechange_1m==0)/sum(~isnan(wagechange_1m))];   % share of 1-mo changes that are zero
mom_m = [mom_m;sum(wagechange_1m>0)/sum(~isnan(wagechange_1m))];    % share of 1-mo changes that are positive
mom_m = [mom_m;nanmean(wagechange_1m(d.agui==1))];             % mean of 1-mo changes when aguinaldo == 1
mom_m = [mom_m;nanstd(wagechange_1m(d.agui==1),0)];            % std of 1-mo changes when aguinaldo == 1
mom_m = [mom_m;nanmean(wagechange_1y(wagechange_1y~=0).^3)/(nanmean(wagechange_1y(wagechange_1y~=0))^3)-1];
mom_m = [mom_m;nanmean(wagechange_1y(wagechange_1y~=0))^2];

% Construct GMM objective function
e       = (mom_m./mom_d-1);
GMM_obj = (e')*(GMMweight)*(e);

if or(or(GMM_obj<0,isnan(GMM_obj)),isinf(GMM_obj))
    GMM_obj = 1.0e100;
end

if p.print==1

    fprintf('---------------------------------------------------------------------\n');
    fprintf('---------------------------------------------------------------------\n');
    fprintf('Std 1-yr wage change                    = %9.3f  %9.3f \n', [mom_d(1),mom_m(1)]);
    fprintf('Std 1-mo wage change                    = %9.3f  %9.3f \n', [mom_d(2),mom_m(2)]);
    fprintf('Share of 1-yr changes that are zero     = %9.3f  %9.3f \n', [mom_d(3),mom_m(3)]);
    fprintf('Share of 1-mo changes that are zero     = %9.3f  %9.3f \n', [mom_d(4),mom_m(4)]);
    fprintf('Share of 1-mo changes that are positive = %9.3f  %9.3f \n', [mom_d(5),mom_m(5)]);
    fprintf('Mean of 1-mo changes when agui == 1     = %9.3f  %9.3f \n', [mom_d(6),mom_m(6)]);
    fprintf('Std of 1-mo changes when agui == 1      = %9.3f  %9.3f \n', [mom_d(7),mom_m(7)]);
    fprintf('CV3 of 1-yr wage change                 = %9.3f  %9.3f \n', [mom_d(8),mom_m(8)]);
    fprintf('Mean 1-yr wage change squared           = %9.3f  %9.3f \n', [mom_d(9),mom_m(9)]);

    fprintf('\n');
    fprintf('par.T_taylor    = %9.3f ;\n', [par.T_taylor]);
    fprintf('par.sigma_eta   = %9.3f ;\n', [par.sigma_eta]);
    fprintf('par.w_lb        = %9.3f ;\n', [par.w_lb]);
    fprintf('par.w_ub        = %9.3f ;\n', [par.w_ub]);
    fprintf('par.sigma_phi   = %9.3f ;\n', [par.sigma_phi]);
    fprintf('par.m_phi       = %9.3f ;\n', [par.m_phi]);
    fprintf('par.sigma_gamma = %9.3f ;\n', [par.sigma_gamma]);
    fprintf('par.beta        = %9.3f ;\n', [par.beta]);

    fprintf('\n');
    fprintf('GMM objective function = %9.3f\n', GMM_obj);
    fprintf('\n');

end

end