********************************************************************************
* DESCRIPTION: This code computes the regular wage from the random sample
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************


/*

 - input: Random Sample GID_RSample_Prepped_Dataset.dta
		  SIPA          SIPA_GID_RSample_Prepped_Dataset.dta

 - output: the panel with teh regular wage under different filters

	   VARIABLES FOR NEXT STEP

	   cuil_trab    		 = Worker identification
	   new_id2 				 = Worker-firm identification (starts from 1)
	   date_num              = Numerical dates in month
	   agui             	 = Dummy variables =1 if months are June and December


*/

*-------------------------------------------------------------------------------
*-------------------------------------------------------------------------------

********************
*Housekeeping
********************
clear
set more off
set scheme s2color

*Dataset to use
global dataset = "RSample"

* add here your path to the random sample folder
global pathinit ""

*test code with 10% of original sample
global test_code = 0      /* 0=original sample, 1=subsample 10\% \%*/

* filter for regular wages
global filter_reguw = 3    /* 1=KehoeMidrigan, 2=Blanco , 3=Nakamura Steinsson, 4=Stevens*/

* If it generates a random sample
global r_sample_size = 0.1

* Fixed the seed for random variables
set seed 92

* Steven filter parameters
global st_L   = 6             // number of sample to apply algorithm

********************
*Paths and Logs
********************

*Folder with filters
global pathfilter = "$pathinit/do/FiltersRegular"

*Figures folder
global intput = "$pathinit/output/002_output"

*Output folder
global output = "$pathinit/output/esti_output"

*temporary folder folder
global temp      = "$pathinit/temp"

global sample = ""

if "$dataset" == "RSample"{

    global filename      = "${sample}CleanRandomSample_"
    global last_year     = 2015
    local convencionado  = "convencionado"
    local basic_wage     = "basic_wage"
    global name          = "GID_RSample_"

}

use cuil_trab cuit_empl ciiu_4 gender date wage  first_or_last_obs /*
*/ sector year_age min_wage_ind   new_id /*
*/ using "$intput/${name}Prepped_Dataset.dta"


********************************************************************************
***************  Save the log file       ***************************************
********************************************************************************

capture log close
log using "$temp/${name}_generate_data_estimation.txt", replace text

********************************************************************************
***************  Generate input for matlab     					  **************
********************************************************************************

* generate wage inflation without monthly seasonality

qui xtset cuil_trab date
qui gsort cuil_trab date

* wage inflation

qui by cuil_trab: gen dwage = ln(wage)-ln(l.wage)

* monthly inflation

gen  month = month(dofm(date))
reg dwage ibn.month , noconstant
capture drop hat_w_sa
predict dwage_r if e(sample),xb

* wage without monthly inflation

gen aux = dwage-dwage_r
bys date: gen weight = 1/_N if dwage~=.
sum aux [ aw=weight]
replace aux = aux-`r(mean)'
sum dwage_r [aw=weight]
replace aux = aux+`r(mean)'
replace dwage = aux
drop aux

* generate predicted inflation by sectors
reg dwage i.date i.sector i.gender i.year_age
capture drop dwage_r
predict dwage_r if e(sample),xb

* generate ids by job spell

qui xtset new_id date
qui gsort new_id date

* round wages to pesos (no cents)
qui gen w_t = round(wage ,1)

* drop first and last wage due to time aggregation
qui replace w_t =. if first_or_last_obs==1 | min_wage_ind==1

* replace June and December
qui by new_id: replace w_t =0.5*l.w_t+0.5*f.w_t if  (month(dofm(date))==6 | month(dofm(date))==12) & (w_t~=l.w_t & w_t~=f.w_t) & (l.w_t ==f.w_t) & l.w_t~=. & f.w_t~=.

* generate log wage
gen lw_t=ln(w_t)

* flag months with aguinaldo
gen agui = (month(dofm(date))==6) | (month(dofm(date))==12)

* prepare the data for matlab

drop if w_t == .
gsort new_id date

* generate numerical date and sector for matlab
gen date_num = date
gen sector_num =sector

* drop job spell with less than $st_L months
by new_id: gen count = _N
drop if count < $st_L
drop count

/* recompute ID to have consecutive numbers starting from 1 */

compress

forvalues dec = 1(1)15 {

	preserve

	keep if sector_num==`dec'

	gegen new_id2 = group(new_id)
	qui gsort new_id2 date
	export delimited cuil_trab new_id2 date_num agui lw_t dwage_r using "$output/CrossValidation_`dec'.csv" if sector_num==`dec', novarnames replace

	restore
}

