%{
* DESCRIPTION: This code estimates the Calvo-Taylor model with SMM and computes the optimal K

* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
%}


function mom_m=estimate_income_process(sector,p,Inputfolder,currentFolder,par_int)

% Sector
p.sect_num       =sector;


%% Upload the data
cd(Inputfolder)

% order in the variables are cuil_trab, new_id, date, agui, lw_t, dwage

data = csvread(strcat('CrossValidation_',num2str(p.sect_num,'%.1i'),'.csv'),0,0);

% Change date to start from 1
data(:,3) = data(:,3) - min(data(:,3)) + 1;

cd(currentFolder)

%% Reshape data

data(:,end+1)    = 999;

d.spellid        = full(sparse(data(:,2),data(:,3),data(:,2)));
d.agui           = full(sparse(data(:,2),data(:,3),data(:,4)));
d.lw_t           = full(sparse(data(:,2),data(:,3),data(:,5)));
d.dwage_r        = full(sparse(data(:,2),data(:,3),data(:,6)));
d.month          = full(sparse(data(:,2),data(:,3),data(:,3)+1-(ceil((data(:,3)+1)/12)-1)*12));
aux              = full(sparse(data(:,2),data(:,3),data(:,3)));
aux(aux==0)      = size(aux,2)+1;
d.min_date       = min(aux,[],2);
d.max_date       = max(full(sparse(data(:,2),data(:,3),data(:,3))),[],2);
d.lw_t_com       = d.lw_t;

for t=2:size(d.lw_t_com,2)

    aux              =d.lw_t_com(:,t)==0 & t<=d.max_date & t>=d.min_date;

    d.lw_t_com(aux,t)=d.lw_t_com(aux,t-1);

end

isdata           = full(sparse(data(:,2),data(:,3),data(:,end)));
d.flag             =isdata ~=999;

d.spellid(d.flag) = nan;
d.agui(d.flag) = nan;
d.lw_t(d.flag) = nan;
d.dwage_r(d.flag) = nan;
d.lw_t_com(d.lw_t_com==0) = nan;

% generate auxiliary variables

ddate       = data(:,3);
mystats2    = @(x)[min(x) max(x) numel(x)];
Group_spell = findgroups(data(:,2));
Group_spell = splitapply(mystats2,ddate,Group_spell);
start_spell = repelem(Group_spell(:,1),Group_spell(:,3));
end_spell   = repelem(Group_spell(:,2),Group_spell(:,3));

tenaux      = data(2:end,1)-data(1:(end-1),1);
tenaux      = [0;find(tenaux);size(data,1)];
tenaux      = tenaux(2:end)-tenaux(1:end-1);
tenure      = repelem(tenaux,tenaux);

d.tenure      = full(sparse(data(:,2),data(:,3),tenure));
d.start_spell = full(sparse(data(:,2),data(:,3),start_spell));
d.end_spell   = full(sparse(data(:,2),data(:,3),end_spell));
d.ddate       = full(sparse(data(:,2),data(:,3),ddate));

d.tenure(d.flag)        = nan;
d.start_spell(d.flag)   = nan;
d.end_spell(d.flag)     = nan;
d.ddate(d.flag)         = nan;

clear tenure tenaux t start_spell mystats2 flag isdata dates  ddate  Group_spell  end_spell aux

%% Parameters

% initial parameters for the SMM

par.T_taylor    = par_int(1) ;
par.sigma_eta   = par_int(2) ;
par.w_lb        = par_int(3) ;
par.w_ub        = par_int(4) ;
par.sigma_phi   = par_int(5) ;
par.m_phi       = par_int(6) ;
par.sigma_gamma = par_int(7) ;
par.beta        = par_int(8) ;


%% Random number generator for the distributions

shock.phi     = randn(size(d.lw_t));
shock.gamma   = randn(size(d.lw_t));
shock.eta     = randn(size(d.lw_t));
shock.gamma_i = rand(size(d.lw_t));
shock.br      = rand(size(d.lw_t));

%% Compute moments from the data

income_var    = d.lw_t;
wagechange_1y = nan(size(d.lw_t));

for t = 13:size(d.lw_t,2)
    wagechange_1y(:,t) = income_var(:,t) - income_var(:,t-12);
end

% drop wage change outliears

Y = prctile(wagechange_1y(:),[2,98]);
I = wagechange_1y<=Y(1) |  wagechange_1y>=Y(2);
wagechange_1y(I)=nan;

wagechange_1m = nan(size(d.lw_t));

for t = 2:size(d.lw_t,2)
    wagechange_1m(:,t) = income_var(:,t) - income_var(:,t-1);
end

% drop wage change outliears
Y = prctile(wagechange_1m(:),[2,98]);
I = wagechange_1m<=Y(1) |  wagechange_1m>=Y(2);
wagechange_1m(I)=nan;

% Source directory for tables
mom_d = nanstd(wagechange_1y(wagechange_1y~=0),0);                         %std 1-yr wage change
mom_d = [mom_d;nanstd(wagechange_1m(wagechange_1m~=0 & (d.month==4 | d.month==5 | d.month==9 | d.month==10)),0)]; %std 1-mo wage change
mom_d = [mom_d;sum(wagechange_1y==0)/sum(~isnan(wagechange_1y))];          % share of 1-yr changes that are zero
mom_d = [mom_d;sum(wagechange_1m==0)/sum(~isnan(wagechange_1m))];          % share of 1-mo changes that are zero
mom_d = [mom_d;sum(wagechange_1m>0)/sum(~isnan(wagechange_1m))];           % share of 1-mo changes that are positive
mom_d = [mom_d;nanmean(wagechange_1m(d.agui==1))];                         % mean of 1-mo changes when aguinaldo == 1
mom_d = [mom_d;nanstd(wagechange_1m(d.agui==1),0)];                        % std of 1-mo changes when aguinaldo == 1
mom_d = [mom_d;nanmean(wagechange_1y(wagechange_1y~=0).^3)/(nanmean(wagechange_1y(wagechange_1y~=0))^3)-1]; % CV of 1-year changes
mom_d = [mom_d;nanmean(wagechange_1y(wagechange_1y~=0))^2];                % mean of 1-year changes 2 when

clear Y I wagechange_1m wagechange_1y income_var


%%   the model
if (p.calibratemodel == 1)

    calibpar = calibrate(par,shock,d,mom_d,p);

else

    cd(Inputfolder)
    load(strcat('calibpar_',num2str(p.sect_num,'%.1i')))
    cd(currentFolder)

end


fprintf('Sector :        %2.0i\n', p.sect_num);
[~,mom_m]=GMM_objfun(calibpar,d,mom_d,eye(size(mom_d,1)),shock,p);


par.T_taylor    = calibpar(1);
par.sigma_eta   = calibpar(2);
par.w_lb        = calibpar(3);
par.w_ub        = calibpar(4);
par.sigma_phi   = calibpar(5);
par.m_phi       = calibpar(6);
par.sigma_gamma = calibpar(7);
par.beta        = calibpar(8);

%% Simulate data and store it for cross-validation exercise
parbackup = par;

for version = 1:1

    if (p.version == 1)

        par             = parbackup;

    elseif (p.version == 2)

        par             = parbackup;
        par.sigma_gamma = 0;

    elseif (p.version == 3)

        par             = parbackup;
        par.m_phi       = 0;

    elseif (p.version == 4)

        par             = parbackup;
        par.sigma_phi   = 0;
        par.m_phi       = 0;

    elseif (p.version == 5)

        par             = parbackup;
        par.sigma_gamma = 0;
        par.sigma_phi   = 0;
        par.m_phi       = 0;

    end

    mom               = simulate(d,par,shock);


end

clear  data_name_out

%% Plot the time series of the simulated wages
% nplots   = 0;
% i        = 0;
% totplots = 20;
%
% figure(1)
% while (nplots < totplots)
%
%     i = i+1;
%
%     nplots = nplots + 1;
%     subplot(ceil(totplots/5),5,nplots)
%     bar(mom.break_point(d.spellid == i),'FaceAlpha',0.2)
%     hold on;
%     plot(mom.w_total(d.spellid == i),'Linewidth',2)
%
%
% end
%
% clear nplots i  totplots
%% Apply Stevens filter to the simulated wage series

% Compute breaks and regular wage for each value of K_grid

new_id                = reshape(d.spellid',numel(d.spellid),1);
new_id(isnan(new_id)) = [];
lw_t                  = reshape(mom.w_total',numel(mom.w_total),1);
filter                = (isnan(lw_t));
lw_t(filter)          = [];

sim_data = [new_id lw_t ];

mystats      = @(x)[median(x) numel(x)];
dates        = sim_data(2:end,1)-sim_data(1:(end-1),1);
dates        = [0;find(dates);size(sim_data,1)];


% Storage variables
breaks_cv = nan(size(sim_data,1),p.nvalsK);
lregw_t   = nan(size(sim_data,1),p.nvalsK);


for kk = 1:p.nvalsK

    K_par = p.K_grid(kk);

    if p.print==1

        fprintf('number completed : %6.2f \n', K_par );
    end

    aux_var      = 0;

     for tt = 2:size(dates,1)

     	wage         = sim_data((dates(tt-1)+1):dates(tt),2);
        [brks,SnVals] = break_test_basic(wage,1,K_par);

        breaks_cv((dates(tt-1)+1):dates(tt),kk) = brks;

        brks         = cumsum(brks);
        Group_sector = findgroups(brks);
        Group_sector = splitapply(mystats,wage,Group_sector);

        lregw_t((dates(tt-1)+1):dates(tt),kk)   = repelem(Group_sector(:,1),Group_sector(:,2));

        if floor(tt/size(dates,1)*100) > aux_var
            if p.print==1
                fprintf('number completed :        %6.2f percent \n', floor( tt/size(dates,1)*100) );
            end
            aux_var = aux_var+10;
        end
    end
end

clear aux_var brks Group_sector K_par kk  new_id lw_t

%% compute moments for the choise of K

% Reshape into array to make comparisons easier
testbreaks = nan([size(mom.break_point),p.nvalsK]);
testwage   = nan([size(mom.break_point),p.nvalsK]);

for kk = 1:p.nvalsK
    testbreaks(:,:,kk) = full(sparse(data(:,2),data(:,3),breaks_cv(:,kk)));
    testwage(:,:,kk) = full(sparse(data(:,2),data(:,3),lregw_t(:,kk)));
end


% Change non-data entries to nan

truebreaks(d.flag)       = nan;
testwage(d.flag)         = nan;

flag           = (d.tenure >= 1 & d.start_spell >= 1 );
type_1_error   = zeros(p.nvalsK,1);
type_2_error3  = zeros(p.nvalsK,1);
freq           = zeros(p.nvalsK,1);
freq_same_reg  = zeros(p.nvalsK,1);

for kk = 1:p.nvalsK

    auxtrue            = mom.break_point;
    auxtrue(~flag)     = nan;
    auxtest            = testbreaks(:,:,kk);
    auxtest(~flag)     = nan;

    auxtrueregw        = mom.w_perm;
    auxtrueregw(~flag) = nan;
    auxtestregw        = testwage(:,:,kk);
    auxtestregw(~flag) = nan;

    type_1_error(kk)   = sum((auxtrue == 0 & auxtest == 1),'all')/sum((auxtrue == 0) & ~isnan(auxtest),'all');
    aux_variable       = (movsum(auxtest,5,2,'omitnan')>0 )*1;
    aux_variable(~flag)= nan;
    type_2_error3(kk)   = sum((auxtrue == 1 & aux_variable == 0),'all')/sum((auxtrue == 1) & ~isnan(aux_variable),'all');

    freq(kk)           = sum(~isnan(auxtestregw(:,2:end)) & ~isnan(auxtestregw(:,1:end-1)) & auxtestregw(:,2:end) ~= auxtestregw(:,1:end-1),'all')/sum(~isnan(auxtestregw(:,2:end)) & ~isnan(auxtestregw(:,1:end-1)),'all');
    freq_same_reg(kk)  = sum(~isnan(auxtestregw) & ~isnan(auxtrueregw) & auxtestregw == auxtrueregw,'all')/sum(~isnan(auxtestregw) & ~isnan(auxtrueregw),'all');

    % Delete exact synchronizations

end

% Compute aggregate moments
truefreq    = sum(~isnan(mom.w_perm(:,2:end)) & ~isnan(mom.w_perm(:,1:end-1)) & mom.w_perm(:,2:end) ~= mom.w_perm(:,1:end-1))/sum(~isnan(mom.w_perm(:,2:end)) & ~isnan(mom.w_perm(:,1:end-1)));


figure(2)
subplot(2,2,1)
set(gcf,'DefaultLineLineWidth', 5);
h=plot(p.K_grid,repmat(truefreq,size(p.K_grid))*100,p.K_grid,freq*100);
set(h(1),'color','m','LineStyle','-' ,'linewidth',5);
set(h(2),'color','k','LineStyle','--','linewidth',5);
title('Frequency')
set(gca, 'FontSize', 12);
ylim([0,30])
pbaspect([1 1 1])
grid on
subplot(2,2,2)
set(gcf,'DefaultLineLineWidth', 5);
h=plot(p.K_grid,100-freq_same_reg*100);
set(h(1),'color','k','LineStyle','--','linewidth',5);
title('Wage diff. regular')
set(gca, 'FontSize', 12);
%ylim([0,30])
pbaspect([1 1 1])
grid on
subplot(2,2,3)
set(gcf,'DefaultLineLineWidth', 5);
h=plot(p.K_grid,type_1_error*100);
set(h(1),'color','k','LineStyle','--','linewidth',5);
title('Pr(break in t|no break t)')
set(gca, 'FontSize', 12);
ylim([0,30])
pbaspect([1 1 1])
grid on
subplot(2,2,4)
set(gcf,'DefaultLineLineWidth', 5);
h=plot(p.K_grid,type_2_error3*100);
set(h(1),'color','k','LineStyle','--','linewidth',5);
title('Pr(no break between t-2,t+2 |break t)')
set(gca, 'FontSize', 12);
ylim([0,90])
pbaspect([1 1 1])
grid on

freq_K   =  freq-truefreq;

[~,ind_K]=min(abs(freq_K));

x_1            =p.K_grid(ind_K-1);
x_2            =p.K_grid(ind_K);
x_3            =p.K_grid(ind_K+1);

f_1            =freq_K(ind_K-1);
f_2            =freq_K(ind_K);
f_3            =freq_K(ind_K+1);


% Apply Lagrange Interpolation formula for F(K) outside the grid
k_grid2        = linspace(x_1,x_3,100)';
w_1             =(k_grid2-x_2).*(k_grid2-x_3)./(x_1-x_2)./(x_1-x_3);
w_2             =(k_grid2-x_1).*(k_grid2-x_3)./(x_2-x_1)./(x_2-x_3);
w_3             =(k_grid2-x_1).*(k_grid2-x_2)./(x_3-x_1)./(x_3-x_2);

f_K            = f_1.*w_1+f_2.*w_2+f_3.*w_3;

[~,ind_K2]=min(abs(f_K));

K_opt    =k_grid2(ind_K2);

%% compute the moments in the optimal K

% Storage variables
breaks_cv_opt = nan(size(sim_data,1),1);
lregw_t_opt   = nan(size(sim_data,1),1);



for tt = 2:size(dates,1)

	wage         = sim_data((dates(tt-1)+1):dates(tt),2);
    [brks,SnVals] = break_test_basic(wage,1,K_opt);

    breaks_cv_opt((dates(tt-1)+1):dates(tt)) = brks;

    brks         = cumsum(brks);
    Group_sector = findgroups(brks);
    Group_sector = splitapply(mystats,wage,Group_sector);

    lregw_t_opt((dates(tt-1)+1):dates(tt))   = repelem(Group_sector(:,1),Group_sector(:,2));


end


% Reshape into array to make comparisons easier
testbreaks_opt = full(sparse(data(:,2),data(:,3),breaks_cv_opt));
testwage_opt   = full(sparse(data(:,2),data(:,3),lregw_t_opt));


moments        =zeros(6,1);
moments(5)     =truefreq;
moments(6)     =size(mom.break_point,1);

auxtrue            = mom.break_point;
auxtrue(~flag)     = nan;
auxtest            = testbreaks_opt;
auxtest(~flag)     = nan;

auxtrueregw        = mom.w_perm;
auxtrueregw(~flag) = nan;
auxtestregw        = testwage_opt ;
auxtestregw(~flag) = nan;

moments(1)      = sum((auxtrue == 0 & auxtest == 1),'all')/sum((auxtrue == 0) & ~isnan(auxtest),'all');
aux_variable    = (movsum(auxtest,5,2,'omitnan')>0 )*1;
aux_variable(~flag)= nan;
moments(2)      = sum((auxtrue == 1 & aux_variable == 0),'all')/sum((auxtrue == 1) & ~isnan(aux_variable),'all');

moments(3)      = sum(~isnan(auxtestregw(:,2:end)) & ~isnan(auxtestregw(:,1:end-1)) & auxtestregw(:,2:end) ~= auxtestregw(:,1:end-1),'all')/sum(~isnan(auxtestregw(:,2:end)) & ~isnan(auxtestregw(:,1:end-1)),'all');
moments(4)      = sum(~isnan(auxtestregw) & ~isnan(auxtrueregw) & auxtestregw == auxtrueregw,'all')/sum(~isnan(auxtestregw) & ~isnan(auxtrueregw),'all');


% Compute aggregate moments

cd(Inputfolder)
save(strcat('calibpar_',num2str(p.sect_num,'%.1i')),'calibpar','mom_m','mom_d','K_opt','moments')
cd(currentFolder)

return