********************************************************************************
* DESCRIPTION: This code computes the regular wage from the random sample
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

/*

 - input: Random Sample GID_RSample_Prepped_Dataset.dta
		  SIPA          SIPA_GID_RSample_Prepped_Dataset.dta

 - output: the panel with teh regular wage under different filters

	   variables for the next tep
	   new_id 				 = worker-mathc id
	   date                  = date in stata format
	   w_r                   = regular wage


*/

*-------------------------------------------------------------------------------
*-------------------------------------------------------------------------------

********************
*Housekeeping
********************
clear
set more off
set scheme s2color

*Dataset to use
global dataset = "RSample"


* add here your path to the random sample folder
global pathinit ""

*test code with 10% of original sample
global test_code = 0      /* 0=original sample, 1=subsample 10\% \%*/

* If it generates a random sample
global r_sample_size = 0.1

* Fixed the seed for random variables
set seed 92

********************************************************************************
*** Parameters
********************************************************************************

* Steven filter parameters
global st_L   = 6              // minimum level of months to apply the filter

global st_Ka_h   = 0.4003          // K param for sector a or 1
global st_Kb_h   = 0.3909          // K param for sector b or 2
global st_Kc_h   = 0.3814          // K param for sector c or 3
global st_Kd_h   = 0.4622          // K param for sector d or 4
global st_Ke_h   = 0.4962         // K param for sector e or 5
global st_Kf_h   = 0.4104          // K param for sector f or 6
global st_Kg_h   = 0.4989          // K param for sector g or 7
global st_Kh_h   = 0.4730          // K param for sector h or 8
global st_Ki_h   = 0.4750          // K param for sector i or 9
global st_Kj_h   = 0.4690         // K param for sector j or 10
global st_Kk_h   = 0.4777          // K param for sector k or 11
global st_Kl_h   = 0.3915          // K param for sector l or 12
global st_Km_h   = 0.4515          // K param for sector m or 13
global st_Kn_h   = 0.4289          // K param for sector n or 14
global st_Ko_h   = 0.5003          // K param for sector 0 or 15

global st_Ka_l   = 0.4589          // K param for sector a or 1
global st_Kb_l   = 0.3989          // K param for sector b or 2
global st_Kc_l   = 0.3861          // K param for sector c or 3
global st_Kd_l   = 0.4582          // K param for sector d or 4
global st_Ke_l   = 0.5057          // K param for sector e or 5
global st_Kf_l   = 0.4097          // K param for sector f or 6
global st_Kg_l   = 0.4535          // K param for sector g or 7
global st_Kh_l   = 0.4188          // K param for sector h or 8
global st_Ki_l   = 0.4222          // K param for sector i or 9
global st_Kj_l   = 0.4730          // K param for sector j or 10
global st_Kk_l   = 0.4494          // K param for sector k or 11
global st_Kl_l   = 0.3737          // K param for sector l or 12
global st_Km_l   = 0.4336          // K param for sector m or 13
global st_Kn_l   = 0.4616          // K param for sector n or 14
global st_Ko_l   = 0.4670          // K param for sector 0 or 15



********************
*Paths and Logs
********************


*Folder with filters
global pathfilter = "$pathinit/do/FiltersRegular"

*Figures folder
global intput = "$pathinit/output/002_output"

*Output folder
global output = "$pathinit/output/003_output"

*temporary folder folder
global temp      = "$pathinit/temp"

global sample = ""


if "$dataset" == "RSample"{

    global filename      = "${sample}CleanRandomSample_"
    global last_year     = 2015
    local convencionado  = "convencionado"
    local basic_wage     = "basic_wage"
    global name          = "GID_RSample_"

}

if $test_code == 0{

    use cuil_trab cuit_empl ciiu_4 gender date wage  first_or_last_obs /*
    */ sector year_age min_wage_ind   new_id /*
    */ using "$intput/${name}Prepped_Dataset.dta"


}

else if $test_code == 1{

    use cuil_trab cuit_empl ciiu_4 gender date wage first_or_last_obs /*
    */ sector year_age min_wage_ind  new_id/*
    */ using "$intput/${name}Prepped_Dataset.dta"

    xtset cuil_trab date
    gsort cuil_trab date

    bysort cuil_trab: gen aux = runiform() if _n == 1
    *replace aux = (aux <$r_sample_size) if aux !=.
	replace aux = (aux <0.1) if aux !=.
    bysort cuil_trab:  egen aux2 = max(aux)
    keep if aux2==1
    drop aux aux2

	save  "$temp/${name}Prepped_Dataset_small.dta", replace
}


********************************************************************************
***************  Save the log file       ***************************************
********************************************************************************

capture log close
log using "$temp/${name}_Freq_Agg_ST_ParaK${st_Ka}_robust.txt", replace text


********************************************************************************
***************  Step 1 of cleaning                           **************
********************************************************************************

qui xtset new_id date
qui gsort new_id date

* round wages to pesos (no cents)
qui gen w_t = round(wage ,1)

* drop first and last wage due to time aggregation
qui replace w_t =. if first_or_last_obs==1 | min_wage_ind==1

* replace June and December
qui by new_id: replace w_t =0.5*l.w_t+0.5*f.w_t if  (month(dofm(date))==6 | month(dofm(date))==12) & (w_t~=l.w_t & w_t~=f.w_t) & (l.w_t ==f.w_t) & l.w_t~=. & f.w_t~=.

* divide the sample before and after 2003 (high/low inflation)

by new_id: egen cut_value=min(date)
gen dummy_cut=.
replace dummy_cut=1 if year(dofm(date)) > 2003
replace dummy_cut=0 if year(dofm(date)) <= 2003
drop cut_value

* genera the parameter by sector

gen K_par=.

replace K_par=$st_Ka_h if sector==1 &  dummy_cut==1
replace K_par=$st_Kb_h if sector==2 &  dummy_cut==1
replace K_par=$st_Kc_h if sector==3 &  dummy_cut==1
replace K_par=$st_Kd_h if sector==4 &  dummy_cut==1
replace K_par=$st_Ke_h if sector==5 &  dummy_cut==1
replace K_par=$st_Kf_h if sector==6 &  dummy_cut==1
replace K_par=$st_Kg_h if sector==7 &  dummy_cut==1
replace K_par=$st_Kh_h if sector==8 &  dummy_cut==1
replace K_par=$st_Ki_h if sector==9 &  dummy_cut==1
replace K_par=$st_Kj_h if sector==10 &  dummy_cut==1
replace K_par=$st_Kk_h if sector==11 &  dummy_cut==1
replace K_par=$st_Kl_h if sector==12 &  dummy_cut==1
replace K_par=$st_Km_h if sector==13 &  dummy_cut==1
replace K_par=$st_Kn_h if sector==14 &  dummy_cut==1
replace K_par=$st_Ko_h if sector==15 &  dummy_cut==1

replace K_par=$st_Ka_l if sector==1 &  dummy_cut==0
replace K_par=$st_Kb_l if sector==2 &  dummy_cut==0
replace K_par=$st_Kc_l if sector==3 &  dummy_cut==0
replace K_par=$st_Kd_l if sector==4 &  dummy_cut==0
replace K_par=$st_Ke_l if sector==5 &  dummy_cut==0
replace K_par=$st_Kf_l if sector==6 &  dummy_cut==0
replace K_par=$st_Kg_l if sector==7 &  dummy_cut==0
replace K_par=$st_Kh_l if sector==8 &  dummy_cut==0
replace K_par=$st_Ki_l if sector==9 &  dummy_cut==0
replace K_par=$st_Kj_l if sector==10 &  dummy_cut==0
replace K_par=$st_Kk_l if sector==11 &  dummy_cut==0
replace K_par=$st_Kl_l if sector==12 &  dummy_cut==0
replace K_par=$st_Km_l if sector==13 &  dummy_cut==0
replace K_par=$st_Kn_l if sector==14 &  dummy_cut==0
replace K_par=$st_Ko_l if sector==15 &  dummy_cut==0

	* these workers do not have a sector
	drop if K_par==.

    * prepare the data for matlab

    keep new_id date w_t K_par
    drop if w_t==.
    gsort new_id date
    gen date_num = date
    by new_id: gen count=_N
    drop if count < $st_L
    drop count

    gquantiles decile = new_id, xtile nquantiles(10)

    global st_Ka_h=$st_Ka_h*100

    forvalues dec = 1(1)10 {

        export delimited new_id w_t date_num K_par using "$temp/${name}Data_KS_R1_test_K${st_Ka_h}_L${st_L}_`dec'.csv"  if decile==`dec', novarnames replace

    }
